function [leg, PC, T0, TOFS] = porkChops(pl1, pl2, T0, tstep, Nrev, dvtol, TOF_LIM, indl)

if nargin == 3
    tstep   = 2;
    Nrev    = [0 0];
    dvtol   = 2;
    TOF_LIM = [];
    indl    = [];
elseif nargin == 4
    Nrev    = [0 0];
    dvtol   = 2;
    TOF_LIM = [];
    indl    = [];
elseif nargin == 5
    dvtol   = 2;
    TOF_LIM = [];
    indl    = [];
elseif nargin == 6
    TOF_LIM = [];
    indl    = [];
end

if pl1 < 11
    set = 1; % --> PC
else
    set = 0; % --> CP
end

mu = 132724487690;

% --> generate TOF for the given leg
[TOFS] = wrap_TOFs(pl1, pl2, Nrev, tstep, TOF_LIM, indl);

PC     = nan(length(T0),length(TOFS));
leg    = zeros(length(T0)*length(TOFS) , 20 );
indl   = 1;
if set == 1 % --> PC
    
    for indi = 1:length(T0)
       
        t0         = T0(indi);
        [rr1, vv1] = EphSS_cartesian(pl1, t0); % --> this is the planet
        
        for indj = 1:length(TOFS)
            
            t1         = t0 + TOFS(indj);
            [rr2, vv2] = EphSS_cartesian(pl2, t1); % --> this is the comet
            
            [rv1_dot, rv2_dot] = lambertMR(rr1, rr2, TOFS(indj)*86400, mu, Nrev(1), Nrev(2));
            
            dv            = norm(rv2_dot - vv2);
            PC(indi,indj) = dv; % --> DV to rendezvous with the comet
            leg(indl,:)   = [rr1 [NaN NaN NaN] pl1 t0  norm(rv1_dot - vv1) NaN,...
                             rr2 rv2_dot       pl2  t1   dv NaN];
            indl = indl + 1;
            
        end
        
    end
    
else % --> CP
    
    for indi = 1:length(T0)
       
        t0         = T0(indi);
        [rr1, vv1] = EphSS_cartesian(pl1, t0); % --> this is the comet
        
        for indj = 1:length(TOFS)
            
            t1         = t0 + TOFS(indj);
            [rr2, vv2] = EphSS_cartesian(pl2, t1); % --> this is the planet
            
            [rv1_dot, rv2_dot] = lambertMR(rr1, rr2, TOFS(indj)*86400, mu, Nrev(1), Nrev(2));
            
            dv           = norm(rv1_dot - vv1);
            PC(indi,indj) = dv; % --> DV to rendezvous with the comet
            leg(indl,:)   = [rr1 rv1_dot pl1 t0      dv             0,...
                             rr2 rv2_dot pl2 t1 norm(rv2_dot - vv2) 0];
            indl = indl + 1;
            
        end
        
    end

end

% --> prune
if pl1 < 11
    set = 1;
else
    set = 0;
end
if set == 1 % --> PC
    indxs = find( leg(:,19) > dvtol );
    leg(indxs,:) = [];
else
    indxs = find( leg(:,9) > dvtol );
    leg(indxs,:) = [];
end

end