function [struc] = wrap_PCP(seq, T0, tst, Nrev, tols)

dvtol   = tols.dvtol   ;
staytol = tols.staytol ;
tofytol = tols.tofytol ;

struc = struct( 'comet', [], 'PCP', [], 'LEGu', [], 'legub', [], 'leguf', [] );

% --> PC
pl1   = seq(1);
pl2   = seq(2); 
legPC = porkChops(pl1, pl2, T0, tst, Nrev, dvtol);

% --> CP
pl1   = seq(3);
pl2   = seq(4);
t0    = min(legPC(:,18)) + staytol(1);
tf    = max(legPC(:,18)) + staytol(2);
T0    = t0:tst:tf;
legCP = porkChops(pl1, pl2, T0, tst, Nrev, dvtol);

% --> solve PCP problem
STRUC = struct('legOV', []);
for indpc = 1:size(legPC,1)
    
    indpc/size(legPC,1)*100;
    
    tarrc = legPC(indpc,18);
    
    tdepc = legCP(:,8);
    
    stay  = tdepc - tarrc;
    indxs = find(stay > 0 & stay >= staytol(1) & stay <= staytol(2));
    
    STRUC(indpc).legOV = [ legPC(indpc,:).*ones(length(indxs), size(legPC,2)) legCP(indxs,:)  ];
    
end
emptyIndex        = find(arrayfun(@(STRUC) isempty(STRUC.legOV),STRUC));
STRUC(emptyIndex) = [];
LEGov             = cell2mat({STRUC.legOV}');
if isempty(LEGov)
    disp('No solutions with current settings');
else
    % --> apply pruning on TOF
    t1             = LEGov(:,8);
    t2             = LEGov(:,38);
    tofys          = (t2 - t1)./365.25;
    indxs          = find(tofys > tofytol);
    LEGov(indxs,:) = [];
end

if isempty(LEGov)
    
    disp('No solutions with current settings');
    
else
    
    % --> apply DP principles
    dvs   = LEGov(:,19) + LEGov(:,29);
    DVS   = [ dvs [1:size(dvs,1)]' ];
    DVS   = sortrows(DVS,1);
    LEGov = LEGov(DVS(:,2),:);

    t1    = LEGov(:,8);
    t2    = LEGov(:,38);
    
    NODES   = [ t1 t2 ];
    [~, ic] = unique(NODES, 'rows', 'stable');

    LEGu     = LEGov(ic,:);
    nodeuB   = [LEGu(:,7:8) LEGu(:,17:18)];
    nodeuF   = [LEGu(:,27:28) LEGu(:,37:38)];
    [~, icb] = unique(nodeuB, 'rows', 'stable');
    [~, icf] = unique(nodeuF, 'rows', 'stable');
    
    legub = LEGu(icb,:);
    leguf = LEGu(icf,:);
    
    struc.comet = seq(2);
    struc.PCP   = seq;
    struc.LEGu  = LEGu;
    struc.legub = legub;
    struc.leguf = leguf;
    
end


end