function [LEGSnext] = computeLegs_v2(plT, LEGSprev, tofs, tolDSM, Nrev, nleg)

% --> constants of motion
mu = 132724487690;

LEGSnext = zeros(size(LEGSprev,1)*length(tofs), (nleg + 1)*10);
indleg   = 1;

for indi = 1:size(LEGSprev,1) % loop over the number of first legs
    
    legPrev = LEGSprev(indi,:);

    plIN_2 = legPrev(:,end-3);
    tIN_2  = legPrev(:,end-2);
    vvIN_2 = legPrev(:,end-6:end-4);

    % dep. planet (Venus in this case) - is the arrival one of the previous leg
    [r1,v1]        = EphSS_cartesian(plIN_2, tIN_2);
    [muPL, radius] = planetConstants(plIN_2);
    rpmin          = maxmin_flybyAltitude(plIN_2) + radius;
    
%     % --> compute the control
%     CC = computeCC(legPrev, v1);

    for indtof = 1:length(tofs)

        % --> tof for the next leg
        tof2 = tofs(indtof);

        % --> arrival planet of the next leg
        [r2,v2] = EphSS_cartesian(plT, tIN_2 + tof2);

        % --> MR-LP
        [v1Short, v2Short] = lambertMR(r1, r2, tof2*86400, mu, Nrev(1), Nrev(2));
        
        vvrel_A = vvIN_2 - v1;
        vvrel_D = v1Short - v1;
        dvapp   = abs( norm(vvrel_D) - norm(vvrel_A) );
        if dvapp <= tolDSM
            dv = findDV(vvrel_A, vvrel_D, muPL, rpmin); % --> defect
        else
            dv = 1e3;
        end

        rrIN_3  = r2;
        vvIN_3  = v2Short;
        
%         % --> correct the DV with DSM
%         dv = fromC2DSM(CC, dv);
        
        if dv < tolDSM % --> save the route
            leg          = [rrIN_3 vvIN_3 plT tIN_2+tof2 norm(v2 - vvIN_3) dv];
            legNext      = [legPrev leg];
            LEGSnext(indleg,:) = legNext;
        end
        indleg = indleg + 1;
    end

end

% --> eliminate rows all equal to zero
LEGSnext = LEGSnext(~all(LEGSnext == 0, 2),:);

end