function [LEGS, DV0, meshTDEP, meshTOF] = ...
    firstLegN0CircCopl(legs, DEP_OPTIONS, ARR_OPTIONS, vinfMax, vinfMin)

% this function evaluates all the possible transfers between two planets
% with less than 1 spacecraft revolutions

% constants of motion
mu = 132724487690;

% extract info from initial options
t0       = DEP_OPTIONS(1); % mission start date
Dt0      = DEP_OPTIONS(2); % mission start date range
tsteptt0 = DEP_OPTIONS(3); % start interval

minTOF   = ARR_OPTIONS(1); % minimum transfer duration range 
maxTOF   = ARR_OPTIONS(2); % maximum transfer duration range 
tstepTT  = ARR_OPTIONS(3); % duration interval

% generate departure and arrival grids
tt0      = t0:tsteptt0:(t0+Dt0);
TT       = minTOF:tstepTT:maxTOF;

DV0             = zeros(length(tt0), length(TT));
meshTDEP        = zeros(length(tt0), length(TT));
meshTOF         = zeros(length(tt0), length(TT));
meshDateMJD2000 = zeros(length(tt0), length(TT));

nleg = 1;
s    = legs(nleg,:);

LEGS   = zeros(length(tt0)*length(TT), 20);
indleg = 1;

disp('Computing first leg (N0) ...');

for indi = 1:length(tt0)
    
    TDEP    = tt0(indi);
    
%     [r1,v1] = EphSS_car(s(1), TDEP);
    [r1,v1] = ephj2000(s(1), TDEP);
            
    for indj = 1:length(TT)
        
        TOF     = TT(indj);
        
        % Build meshes for contour plot axis
        meshTDEP(indi,indj)        = TDEP;
        meshTOF(indi,indj)         = TOF;
        meshDateMJD2000(indi,indj) = TDEP + TOF; % this is the arrival date at the planet
        
%         [r2,v2] = EphSS_car(s(2), TDEP + TOF);
        [r2,v2] = ephj2000(s(2), TDEP + TOF);
                
        % one revolution
        [~,~,~,~,v1Short, v2Short,~,~] = lambertMR(r1, r2, TOF*86400, mu, 0, 0);
        dvShort = norm(v1Short - v1);
        
        [~,~,~,~,v1Long, v2Long,~,~] = lambertMR(r1, r2, TOF*86400, mu, 1, 0);
        dvLong = norm(v1Long - v1);
        
        [DV0(indi,indj), b] = min([dvShort dvLong]);
        
        % save pairs of states
        if b == 1
            % short transfer is saved
            vInfD  = norm(v1Short - v1);
            
            if vInfD <= vinfMax && vInfD >= vinfMin
                LEGS(indleg,:) = [r1 v1Short s(1) TDEP vInfD 0 r2 v2Short s(2) (TDEP + TOF) norm(v2 - v2Short) 0];
            end
        elseif b == 2
            % long transfer is saved
            vInfD  = norm(v1Long - v1);
            
            if vInfD <= vinfMax && vInfD >= vinfMin
                LEGS(indleg,:) = [r1 v1Long s(1) TDEP vInfD 0 r2 v2Long s(2) (TDEP + TOF) norm(v2 - v2Long) 0];
            end
        end
        indleg = indleg + 1;   
    end
        
end

% eliminate rows all equal to zero
LEGS = LEGS(~all(LEGS == 0, 2),:);

end