function [STRUC] = wrap_AMB(LEGS, REVS, rcMIN, rcMAX, TOFr, dtAMBp, indl)

% --> gravitational parameter of the Sun
mu = 132724487690;

% --> extract info
plIN    = LEGS(indl,end-3);
rrIN    = LEGS(indl,end-9:end-7);
vvIN    = LEGS(indl,end-6:end-4);
tIN     = LEGS(indl,end-2);
TOFr    = TOFr(indl);
vInfDep = sum([LEGS(indl,9) sum(LEGS(indl, 10:10:end ),2)], 2);
tDEP    = LEGS(indl,8);
dtAMBp  = dtAMBp(indl,1); % --> TOFamb on the previous leg
revs    = REVS(indl,:);
epochs  = LEGS(indl,8:10:end-2);

% --> flyby parameters
[muPLIN, radPLIN] = planetConstants(plIN);
rpIN              = [250:100:1000] + radPLIN;
kIN               = deg2rad([0:10:360]);

% --> search for the optimal flyby
MAT = zeros(length(rpIN)*length(kIN), 10);
indmat = 1;
for indrp = 1:length(rpIN)
    rpin = rpIN(indrp);   % --> (km) periapsis of the hyperbola
    for indkp = 1:length(kIN)
        kin = kIN(indkp); % --> (rad) inclination of the hypberbola
        
        % --> perform the flyby of the last planet
        [rrOU, vvOU] = swingby_vA(rrIN, vvIN, plIN, tIN, kin, rpin, muPLIN);
        
        % --> compute the orbit after the flyby
        kepOU    = car2kep([rrOU, vvOU], mu);
        incOUdeg = rad2deg(kepOU(3));
        TOU      = 2*pi*sqrt((kepOU(1))^3/mu);

        % --> compute the time in the AMB
        step    = 10;
        tt      = unique( [[0:step*86400:TOU]'; TOU] );
        [~, yy] = propagateKepler( rrOU, vvOU, tt, mu );
        rrs     = vecnorm( yy(:,1:3)' )';
        indx1   = find( rrs >= rcMIN & rrs <= rcMAX );
        if ~isempty( indx1 ) % --> no time spent in the AMB
            
            TAMB      = tt(indx1);
            D         = [diff(TAMB)./86400];
            D(D>step) = [];
            dtAMB     = sum(D);
            
            tofAMB = (TOFr/(TOU/86400) * dtAMB) + dtAMBp;
                                    
            MAT(indmat,1) = indl;
            MAT(indmat,2) = tDEP;
            MAT(indmat,3) = tIN;
            MAT(indmat,4) = vInfDep;
            MAT(indmat,5) = rpin;
            MAT(indmat,6) = kin;
            MAT(indmat,7) = tofAMB;
            MAT(indmat,8) = incOUdeg;
            
            MAT(indmat,9)  = 3;
            MAT(indmat,10) = plIN;
            
            indmat        = indmat + 1;
        end
    end
end
MAT(MAT(:,1) == 0,:) = [];

% --> save the results
if ~isempty(MAT)
    
    MAT(:,4) = -MAT(:,4);
    MAT(:,7) = -MAT(:,7);
    MAT      = sortrows(MAT,[ 2 7 4 ]); % --> sort by LD, dtAMB, vInfDep
    MAT(:,4) = -MAT(:,4);
    MAT(:,7) = -MAT(:,7);

    MAT      = MAT(1,:);
    
    STRUC.indl     = MAT(1);
    STRUC.tDEP     = MAT(2);
    STRUC.tIN      = MAT(3);
    STRUC.vInfDep  = MAT(4);
    STRUC.rpin     = MAT(5);
    STRUC.kin      = MAT(6);
    STRUC.tofAMB   = MAT(7);
    STRUC.incOUdeg = MAT(8);
    STRUC.pl1      = MAT(9);
    STRUC.pl2      = MAT(10);
    STRUC.revs     = revs;
    STRUC.epochs   = epochs;
    
else
    STRUC = struct('indl', [], 'tDEP', [], 'tIN', [], 'vInfDep', [], 'rpin', [], ...
        'kin', [], 'tofAMB', [], 'incOUdeg', [], 'pl1', [], 'pl2', [], 'revs', [], 'epochs', []);
end

end
