%--------------------------------------------------------------------------
% This function identifies the pareto frontier of a set of points (this
% function consider smaller values are more desirable)
%--------------------------------------------------------------------------
% Input: input, a matrix, each row correspondes to a point, each column
% correspond to a dimension
%--------------------------------------------------------------------------
% Outputs:
% (1) membership: a logical array, have same number of rows as input
% matrix, 1 indicate the corresponding point in input matrix is a member of
% pareto frontier, 0 otherwise
% (2) member_value: matrix, contain point(s) on the pareto frontier.
%--------------------------------------------------------------------------
% Example:
%   x=rand(100,2);
%   [membership,member_value]=find_pareto_frontier(x);
%   scatter(x(:,1),x(:,2));
%   hold on;
%   scatter(member_value(:,1),member_value(:,2),'r');
%   legend({'Data','Pareto Frontier'})
%
%--------------------------------------------------------------------------
function [paretoFront] = find_pareto_frontier(input)

out=[];

data = unique(input,'rows');

% initialise the waitbar
f = waitbar(0, '', 'CreateCancelBtn','setappdata(gcbf,''canceling'',1)');

out = zeros(size(input,1),size(input,2));
for i = 1:size(data,1)
    c_data = repmat(data(i,:),size(data,1),1);
    t_data = data;
    t_data(i,:) = Inf(1,size(data,2));
    smaller_idx = c_data>=t_data;
    
    idx=sum(smaller_idx,2)==size(data,2);
    if ~nnz(idx)
        out(i,:)=data(i,:);
    end
    
    % update the waitbar
    w = waitbar(i/size(data,1), f, sprintf('Computing Pareto front %.3f %%...',i/size(data,1)*100 ));
end
delete(w); % close the waitbar

% eliminate rows all equal to zero
out = out(~all(out == 0, 2),:);

% membership  = ismember(input,out,'rows');
paretoFront = out;

indMAT = zeros(size(paretoFront,1),1);
for indi = 1:size(paretoFront,1)
    lia    = ismember(input, paretoFront(indi,:));
    sumlia = lia(:,1) + lia(:,2);
    indx   = find(sumlia == 2);
    indMAT(indi) = indx;
end

paretoFront = [paretoFront indMAT];

end