function [fig, YY, TT, PLANETS, R, V] = plotPath(path, holdon, color, firstL)

if nargin == 1
    holdon = 0;   % --> open new figure
    color  = 'b'; % --> blue trajectory
    firstL = 1;   % --> highlight departing condition
elseif nargin == 2
    color = 'b';
    firstL = 1;
elseif nargin == 3
    firstL = 1;
end

mu = 132724487690;
AU = 149597870.7;

PLTS = path(:,7);
TFBS = path(:,8);
DTS  = [0; diff(TFBS)];

%%%%% plot planets orbits %%%%%
t0   = path(1,8);
tend = path(end,8);
fig  = plotPLTS_tt(PLTS, t0, tend, holdon);
%%%%% plot planets orbits %%%%%

%%%%% plot trajectory %%%%%
YY = []; TT = [];
for NLEG = 2:size(path,1)
    
    RR  = path(NLEG, 1:3);
    VV  = path(NLEG, 4:6);
    
    [rr1, vv1] = FGKepler_dt(car2kep([RR VV], mu), -DTS(NLEG)*86400, mu); % backward propagation
    tt         = [0:1*86400:DTS(NLEG)*86400]';
    [~,yy]     = propagateKepler(rr1, vv1, tt, mu); % forward propagation

    if firstL == 1
        if NLEG == 2
            hold on;
            plot3(yy(1,1)./AU, yy(1,2)./AU, yy(1,3)./AU, 's', 'MarkerSize', 10, 'MarkerEdgeColor', 'Black', 'MarkerFaceColor', 'Cyan', 'DisplayName', 'Departure');
        end
    end
    
    if NLEG  == 2
        hold on;
        plot3(yy(:,1)./AU, yy(:,2)./AU, yy(:,3)./AU, 'Color', color, 'linewidth', 2, 'HandleVisibility', 'Off');
        if holdon == 0
            plot3(yy(end,1)./AU, yy(end,2)./AU, yy(end,3)./AU, 'o', 'MarkerSize', 8, 'MarkerEdgeColor', 'Black', 'MarkerFaceColor', 'Red', 'DisplayName', 'Fly-by');
        else
            plot3(yy(end,1)./AU, yy(end,2)./AU, yy(end,3)./AU, 'o', 'MarkerSize', 8, 'MarkerEdgeColor', 'Black', 'MarkerFaceColor', 'Red', 'HandleVisibility', 'Off');
        end
    else
        hold on;
        plot3(yy(:,1)./AU, yy(:,2)./AU, yy(:,3)./AU, 'Color', color, 'linewidth', 2, 'HandleVisibility', 'Off');
        plot3(yy(end,1)./AU, yy(end,2)./AU, yy(end,3)./AU, 'o', 'MarkerSize', 8, 'MarkerEdgeColor', 'Black', 'MarkerFaceColor', 'Red', 'HandleVisibility', 'Off');
    end
    
    YY = [YY; yy];
    if NLEG == 2
        TT = [TT; ((tt))];
    else
        TT = [TT; TT(end)+((tt))];
    end
    
end
%%%%% plot trajectory %%%%%

%%%%% distance and velocity w.r.t. time %%%%%
R = zeros(size(YY,1),1);
V = zeros(size(YY,1),1);
for indi = 1:size(YY,1)
    R(indi,1) = norm(YY(indi,1:3));
    V(indi,1) = norm(YY(indi,4:6)); 
end
%%%%% distance and velocity w.r.t. time %%%%%

%%%%% planets positions in the time considered %%%%%
tdep  = path(1,8);
TPLTS = TT./86400 + tdep;
PLTS  = unique(PLTS);
for indj = 1:length(PLTS)
    pl = PLTS(indj);
    PLANETS(indj).pl = pl;
    for indi = 1:length(TPLTS)
        PLANETS(indj).planet(indi,:) = EphSS_car(pl, TPLTS(indi));
        PLANETS(indj).Tpl(indi,:) = TPLTS(indi);
    end
end
%%%%% planets positions in the time considered %%%%%

% if holdon == 0
%     legend('Departing location', 'Flyby');
% end
% legend('Location', 'Best');

end
