function [fig, fig2, fig3] = plotPath_back(path)

mu = 132724487690;
AU = 149597870.7;

PLTS = path(:,7);
TFBS = path(:,8);
DTS  = diff(TFBS);

%%%%% plot planets orbits %%%%%
t0   = path(1,8);
tend = path(end,8);
fig  = plotPLTS_tt(PLTS, t0, tend);
%%%%% plot planets orbits %%%%%

YY = []; TT = 0;
for NLEG = 1:size(path,1)-1
   
    RR  = path(NLEG, 1:3);
    VV  = path(NLEG, 4:6);

    tt         = [0:1*86400:DTS(NLEG)*86400]';
    [~,yy]     = propagateKepler(RR, VV, tt, mu); % forward propagation
    
    hold on;
    plot3(yy(:,1)./AU, yy(:,2)./AU, yy(:,3)./AU, 'b', 'linewidth', 2, 'handlevisibility', 'off');
    if NLEG == 1
        plot3(yy(1,1)./AU, yy(1,2)./AU, yy(1,3)./AU, 'ks', 'markersize', 10, 'DisplayName', 'Departing location');
    elseif NLEG == size(path,1)-1
        plot3(yy(end,1)./AU, yy(end,2)./AU, yy(end,3)./AU, 'ro', 'markersize', 8, 'DisplayName', 'Flyby');
    else
        plot3(yy(1,1)./AU, yy(1,2)./AU, yy(1,3)./AU, 'ro', 'markersize', 8, 'handlevisibility', 'off');
    end
    
    YY = [YY; yy];
    TT = [TT; TT(end)+tt];
    
end
TT(1) = [];

legend('Location', 'Best');

if nargout > 1
    
    %%%%% distance and velocity w.r.t. time %%%%%
    R = zeros(size(YY,1),1);
    V = zeros(size(YY,1),1);
    for indi = 1:size(YY,1)
        R(indi,1) = norm(YY(indi,1:3));
        V(indi,1) = norm(YY(indi,4:6)); 
    end
    %%%%% distance and velocity w.r.t. time %%%%%

    ttt     = TT./86400 + path(1,8);
    lia     = ismember(ttt,  TFBS);
    ttt     = [TT./86400 [1:1:length(ttt)]'];
    ttt     = ttt(lia,:);
    [~,idu] = unique(ttt(:,1));
    ttt     = ttt(idu,:);

    RFBS = R(ttt(:,2),:);
    VFBS = V(ttt(:,2),:);

    fig2 = figure;
    hold on; grid on; xlabel('TOF - years'); ylabel('SC helicentric distance - km');
    plot(TT./(86400*365.35), R./AU, 'b', 'linewidth', 2, 'handlevisibility', 'off');
    plot(TT(ttt(:,2))./(86400*365.35), RFBS./AU, 'ro', 'markersize', 8, 'DisplayName', 'Flyby');
    legend('Location', 'Best');    
    
    if nargout > 2
        fig3 = figure;
        hold on; grid on; xlabel('TOF - years'); ylabel('SC helicentric velocity - km/s');
        plot(TT./(86400*365.35), V, 'b.', 'markersize', 5, 'handlevisibility', 'off');
        plot(TT(ttt(:,2))./(86400*365.35), VFBS, 'ro', 'markersize', 8, 'DisplayName', 'Flyby');
        legend('Location', 'Best');

    end
    
end

end