function [fig] = plotSolVec_v2(solVEC, t0)

AU = 149597870.7;

% case with zero revolutions

% first column of solVec is the sequence
% second column of solVec are the epochs MJD2000

mu = 132724487690;

T = zeros(1,size(solVEC,1)+1);
T(1) = t0;
for indi = 1:size(solVEC,1)
    T(indi+1) = T(indi) + solVEC(indi,3);
end

PLTS = [solVEC(:,1); solVEC(end,2)]';

[fig] = plotPLTS(PLTS, T);
hold on;
plot3(0, 0, 0, 'r*', 'markersize', 10);

options = odeset('abstol', 1e-12, 'reltol', 1e-12);

for indi = 1:size(solVEC,1)
   
    pl1  = solVEC(indi,1);
    pl2  = solVEC(indi,2);
    Nrev = solVEC(indi,4);
    
    t1 = T(indi);
    t2 = T(indi+1);
    
    [r1, v1] = EphSS_car(pl1, t1);
    [r2, ~] = EphSS_car(pl2, t2);
        
    if Nrev < 1
        [~,~,~,~,~, v2Short,~,~] = lambertMR(r1, r2, (t2 - t1)*86400, mu, 0, 0);
        if indi == 1            
            rrIN = r2;
            vvIN = v2Short;
            [~,yy] = ode113(@(t,x) dyn_2BP(t, x, mu), [0 -(t2 - t1)*86400], [rrIN, vvIN], options);

            hold on;
            plot3(yy(:,1)./AU, yy(:,2)./AU, yy(:,3)./AU, 'b', 'linewidth', 2);
            plot3(yy(1,1)./AU, yy(1,2)./AU, yy(1,3)./AU, 'ro', 'markersize', 8);
            plot3(yy(end,1)./AU, yy(end,2)./AU, yy(end,3)./AU, 'ks', 'markersize', 10);
            
        else
            rrIN = r2;
            vvIN = v2Short;

            [~,yy] = ode113(@(t,x) dyn_2BP(t, x, mu), [0 -(t2 - t1)*86400], [rrIN, vvIN], options);

            hold on;
            plot3(yy(:,1)./AU, yy(:,2)./AU, yy(:,3)./AU, 'b', 'linewidth', 2);
            plot3(yy(1,1)./AU, yy(1,2)./AU, yy(1,3)./AU, 'ro', 'markersize', 8);

        end
    else
        [~,~,~,~,v1Short, v2Short,~,~] = lambertMR(r1, r2, (t2 - t1)*86400, mu, 0, Nrev, 0, 0);
        [~,~,~,~,v1Long, v2Long,~,~] = lambertMR(r1, r2, (t2 - t1)*86400, mu, 0, Nrev, 1, 0);
        
        if indi == 1
            dvShort = norm(v1Short - v1);
            dvLong  = norm(v1Long - v1);
            [~,b] = min([dvShort dvLong]);
            if b== 1
            rrIN = r2;
            vvIN = v2Short;
            [~,yy] = ode113(@(t,x) dyn_2BP(t, x, mu), [0 -(t2 - t1)*86400], [rrIN, vvIN], options);

            hold on;
            plot3(yy(:,1)./AU, yy(:,2)./AU, yy(:,3)./AU, 'b', 'linewidth', 2);
            plot3(yy(1,1)./AU, yy(1,2)./AU, yy(1,3)./AU, 'ro', 'markersize', 8);
            plot3(yy(end,1)./AU, yy(end,2)./AU, yy(end,3)./AU, 'ks', 'markersize', 10);
            else
            rrIN = r2;
            vvIN = v2Long;
            [~,yy] = ode113(@(t,x) dyn_2BP(t, x, mu), [0 -(t2 - t1)*86400], [rrIN, vvIN], options);

            hold on;
            plot3(yy(:,1)./AU, yy(:,2)./AU, yy(:,3)./AU, 'b', 'linewidth', 2);
            plot3(yy(1,1)./AU, yy(1,2)./AU, yy(1,3)./AU, 'ro', 'markersize', 8);
            plot3(yy(end,1)./AU, yy(end,2)./AU, yy(end,3)./AU, 'ks', 'markersize', 10);
            end

        else
            [muPL, radius] = planetConstants(pl1);
            [hmin]         = maxmin_flybyAltitude(pl1);
            rpmin          = hmin + radius;

            dvShort = findDV(vvIN - v1, v1Short - v1, muPL, rpmin);
            dvLong  = findDV(vvIN - v1, v1Long - v1, muPL, rpmin);
            
            [~,b] = min([dvShort dvLong]);

            if b== 1
            rrIN = r2;
            vvIN = v2Short;

            [~,yy] = ode113(@(t,x) dyn_2BP(t, x, mu), [0 -(t2 - t1)*86400], [rrIN, vvIN], options);

            hold on;
            plot3(yy(:,1)./AU, yy(:,2)./AU, yy(:,3)./AU, 'b', 'linewidth', 2);
            plot3(yy(1,1)./AU, yy(1,2)./AU, yy(1,3)./AU, 'ro', 'markersize', 8);
            else
            rrIN = r2;
            vvIN = v2Long;

            [~,yy] = ode113(@(t,x) dyn_2BP(t, x, mu), [0 -(t2 - t1)*86400], [rrIN, vvIN], options);

            hold on;
            plot3(yy(:,1)./AU, yy(:,2)./AU, yy(:,3)./AU, 'b', 'linewidth', 2);
            plot3(yy(1,1)./AU, yy(1,2)./AU, yy(1,3)./AU, 'ro', 'markersize', 8);
            end
        
        end
    
    end
end

end