function [OUTPUT] = generate_OUTPUT(OUTPUT, INPUT)

if ~isempty(OUTPUT.LEGS)
    
    % --> compute pareto fronts
    OUTPUT.PARETO_FRONT         = generateParetoFront(OUTPUT.LEGS, 0);
    OUTPUT.LEGS_ON_PARETO_FRONT = OUTPUT.LEGS(OUTPUT.PARETO_FRONT(:,end),:);
    OUTPUT.PATH_BEST_DV         = constructPath(OUTPUT.LEGS(OUTPUT.PARETO_FRONT(end,end),:));
    
    % --> PLOT OPTIONS
    if isfield(INPUT, 'plot') && ~isempty(INPUT.plot)
        if length(INPUT.plot) == 1 % --> plot only the Pareto front
            plotPareto(OUTPUT.PARETO_FRONT);
        else
            if INPUT.plot(2) == 1 % --> plot the best DV trajectory
                matrow = OUTPUT.LEGS(OUTPUT.PARETO_FRONT(end,3),:);
                path   = constructPath(matrow);
                plotPath(path); % --> plot the trajectory
            end
            
            if INPUT.plot(1) == 1
                figure;
                hold on; grid on;
                xlabel('Time of flight - years'); ylabel('\Deltav - km/s');
                plot(OUTPUT.PARETO_FRONT(:,1), OUTPUT.PARETO_FRONT(:,2), 'ks', 'markersize', 3);
            end
        end
    end
    
    % --> DISPLAY OPTIONS
    if isfield(INPUT, 'write') && ~isempty(INPUT.write) && INPUT.write == true
        matrow = OUTPUT.LEGS(OUTPUT.PARETO_FRONT(end,3),:);
        path   = constructPath(matrow);
        folder = generateFolder(INPUT);
        generateOutputTXT(path, folder);
    end

end

end