function [LEGS_N] = wrapConstructionResonance(LEGSnext, res, plT, tolINCL, minMax, parallel)

% --> check the INPUT
if nargin == 3
    tolINCL  = deg2rad(1);
    minMax   = 1; % --> save the min(DINCL)
    parallel = 0;
elseif nargin == 4
    minMax   = 1;
    parallel = 0;
elseif nargin == 5
    parallel = 0;
end

% --> check if you can achieve the resonance
[LEGSnext] = checkResonance(LEGSnext, plT, res);
if isempty(LEGSnext) % --> if the resonance is not achievable by any path, then end
    LEGS_N = [];
    return
end

if parallel == 0 % --> run SEQUENTIAL
    
    % --> construct resonant orbits
    LEGS_N  = [];
    rownext = 1;
    for indres = 1:size(LEGSnext,1)
        legprev = LEGSnext(indres,:);
        LEGS    = constructResonantOrbits(plT, res, legprev, tolINCL, minMax);
        LEGS_N(rownext:rownext-1+size(LEGS,1),:) = LEGS;
        rownext = rownext + size(LEGS,1); 
    end
    
else % --> run PARALLEL
    
    % --> construct resonant orbits
    parfor indres = 1:size(LEGSnext,1)
        legprev = LEGSnext(indres,:);
        LEGS    = constructResonantOrbits(plT, res, legprev, tolINCL, minMax);
        STRUC(indres).LEGS = LEGS;
    end
    
    LEGS_N = cell2mat({STRUC.LEGS}');
    
end

end
