/*
 * Academic License - for use in teaching, academic research, and meeting
 * course requirements at degree granting institutions only.  Not for
 * government, commercial, or other organizational use.
 * File: STM_analytic.c
 *
 * MATLAB Coder version            : 5.1
 * C/C++ source code generated on  : 22-Nov-2021 13:50:12
 */

/* Include Files */
#include "STM_analytic.h"
#include "rt_nonfinite.h"
#include "rt_nonfinite.h"
#include <math.h>

/* Function Declarations */
static double rt_powd_snf(double u0, double u1);

/* Function Definitions */
/*
 * Arguments    : double u0
 *                double u1
 * Return Type  : double
 */
static double rt_powd_snf(double u0, double u1)
{
  double d;
  double d1;
  double y;
  if (rtIsNaN(u0) || rtIsNaN(u1)) {
    y = rtNaN;
  } else {
    d = fabs(u0);
    d1 = fabs(u1);
    if (rtIsInf(u1)) {
      if (d == 1.0) {
        y = 1.0;
      } else if (d > 1.0) {
        if (u1 > 0.0) {
          y = rtInf;
        } else {
          y = 0.0;
        }
      } else if (u1 > 0.0) {
        y = 0.0;
      } else {
        y = rtInf;
      }
    } else if (d1 == 0.0) {
      y = 1.0;
    } else if (d1 == 1.0) {
      if (u1 > 0.0) {
        y = u0;
      } else {
        y = 1.0 / u0;
      }
    } else if (u1 == 2.0) {
      y = u0 * u0;
    } else if ((u1 == 0.5) && (u0 >= 0.0)) {
      y = sqrt(u0);
    } else if ((u0 < 0.0) && (u1 > floor(u1))) {
      y = rtNaN;
    } else {
      y = pow(u0, u1);
    }
  }

  return y;
}

/*
 * compute analytic STM for elliptical keplerian orbits
 * Arguments    : const double rr0[3]
 *                const double vv0[3]
 *                double dt
 *                double mu
 *                double STM[36]
 *                double rr1[3]
 *                double vv1[3]
 *                double R[9]
 *                double V[9]
 *                double Rdash[9]
 *                double Vdash[9]
 * Return Type  : void
 */
void STM_analytic(const double rr0[3], const double vv0[3], double dt, double mu,
                  double STM[36], double rr1[3], double vv1[3], double R[9],
                  double V[9], double Rdash[9], double Vdash[9])
{
  static const signed char b[9] = { 1, 0, 0, 0, 1, 0, 0, 0, 1 };

  double V_tmp[9];
  double b_dvv[9];
  double b_rr1[9];
  double c_rr1[9];
  double d_rr1[9];
  double y[9];
  double dvv[3];
  double DE;
  double DM;
  double DM_tmp;
  double F;
  double Fdot;
  double G;
  double Gdot;
  double a;
  double absxk;
  double b_a;
  double b_d;
  double b_fx_tmp;
  double b_scale;
  double c;
  double d;
  double e;
  double fb;
  double fx_tmp;
  double m;
  double r0;
  double rf;
  double s;
  double scale;
  double t;
  double toler;
  int R_tmp_tmp;
  int b_R_tmp_tmp;
  int exitg2;
  int i;
  boolean_T exitg1;
  scale = 3.3121686421112381E-170;
  b_scale = 3.3121686421112381E-170;

  /*  mean anomaly difference */
  absxk = fabs(rr0[0]);
  if (absxk > 3.3121686421112381E-170) {
    r0 = 1.0;
    scale = absxk;
  } else {
    t = absxk / 3.3121686421112381E-170;
    r0 = t * t;
  }

  absxk = fabs(vv0[0]);
  if (absxk > 3.3121686421112381E-170) {
    a = 1.0;
    b_scale = absxk;
  } else {
    t = absxk / 3.3121686421112381E-170;
    a = t * t;
  }

  absxk = fabs(rr0[1]);
  if (absxk > scale) {
    t = scale / absxk;
    r0 = r0 * t * t + 1.0;
    scale = absxk;
  } else {
    t = absxk / scale;
    r0 += t * t;
  }

  absxk = fabs(vv0[1]);
  if (absxk > b_scale) {
    t = b_scale / absxk;
    a = a * t * t + 1.0;
    b_scale = absxk;
  } else {
    t = absxk / b_scale;
    a += t * t;
  }

  absxk = fabs(rr0[2]);
  if (absxk > scale) {
    t = scale / absxk;
    r0 = r0 * t * t + 1.0;
    scale = absxk;
  } else {
    t = absxk / scale;
    r0 += t * t;
  }

  absxk = fabs(vv0[2]);
  if (absxk > b_scale) {
    t = b_scale / absxk;
    a = a * t * t + 1.0;
    b_scale = absxk;
  } else {
    t = absxk / b_scale;
    a += t * t;
  }

  r0 = scale * sqrt(r0);
  a = b_scale * sqrt(a);
  a = mu / (2.0 * mu / r0 - a * a);
  DM_tmp = rt_powd_snf(a, 3.0);
  DM = sqrt(mu / DM_tmp) * dt;

  /*  evalaute the DE */
  fx_tmp = 1.0 - r0 / a;
  b_fx_tmp = ((rr0[0] * vv0[0] + rr0[1] * vv0[1]) + rr0[2] * vv0[2]) / sqrt(mu) /
    sqrt(a);
  scale = DM - ((DM - fx_tmp * sin(DM)) - b_fx_tmp * (cos(DM) - 1.0));
  if (scale == 0.0) {
    DE = DM;
  } else {
    if (DM != 0.0) {
      b_scale = DM / 50.0;
    } else {
      b_scale = 0.02;
    }

    b_a = DM;
    DE = DM;
    fb = scale;
    do {
      exitg2 = 0;
      if ((scale > 0.0) == (fb > 0.0)) {
        b_scale *= 1.4142135623730951;
        b_a = DM - b_scale;
        scale = DM - ((b_a - fx_tmp * sin(b_a)) - b_fx_tmp * (cos(b_a) - 1.0));
        if (rtIsInf(scale) || rtIsNaN(scale)) {
          DE = rtNaN;
          exitg2 = 1;
        } else if (rtIsInf(b_a) || rtIsNaN(b_a)) {
          DE = rtNaN;
          exitg2 = 1;
        } else if ((scale > 0.0) != (fb > 0.0)) {
          exitg2 = 2;
        } else {
          DE = DM + b_scale;
          fb = DM - ((DE - fx_tmp * sin(DE)) - b_fx_tmp * (cos(DE) - 1.0));
          if (rtIsInf(fb) || rtIsNaN(fb)) {
            DE = rtNaN;
            exitg2 = 1;
          } else {
            if (rtIsInf(DE) || rtIsNaN(DE)) {
              DE = rtNaN;
              exitg2 = 1;
            }
          }
        }
      } else {
        exitg2 = 2;
      }
    } while (exitg2 == 0);

    if (exitg2 != 1) {
      t = fb;
      c = DE;
      e = 0.0;
      b_d = 0.0;
      exitg1 = false;
      while ((!exitg1) && ((fb != 0.0) && (b_a != DE))) {
        if ((fb > 0.0) == (t > 0.0)) {
          c = b_a;
          t = scale;
          b_d = DE - b_a;
          e = b_d;
        }

        if (fabs(t) < fabs(fb)) {
          b_a = DE;
          DE = c;
          c = b_a;
          scale = fb;
          fb = t;
          t = scale;
        }

        m = 0.5 * (c - DE);
        toler = 4.4408920985006262E-16 * fmax(fabs(DE), 1.0);
        if ((fabs(m) <= toler) || (fb == 0.0)) {
          exitg1 = true;
        } else {
          if ((fabs(e) < toler) || (fabs(scale) <= fabs(fb))) {
            b_d = m;
            e = m;
          } else {
            s = fb / scale;
            if (b_a == c) {
              b_scale = 2.0 * m * s;
              scale = 1.0 - s;
            } else {
              scale /= t;
              absxk = fb / t;
              b_scale = s * (2.0 * m * scale * (scale - absxk) - (DE - b_a) *
                             (absxk - 1.0));
              scale = (scale - 1.0) * (absxk - 1.0) * (s - 1.0);
            }

            if (b_scale > 0.0) {
              scale = -scale;
            } else {
              b_scale = -b_scale;
            }

            if ((2.0 * b_scale < 3.0 * m * scale - fabs(toler * scale)) &&
                (b_scale < fabs(0.5 * e * scale))) {
              e = b_d;
              b_d = b_scale / scale;
            } else {
              b_d = m;
              e = m;
            }
          }

          b_a = DE;
          scale = fb;
          if (fabs(b_d) > toler) {
            DE += b_d;
          } else if (DE > c) {
            DE -= toler;
          } else {
            DE += toler;
          }

          fb = DM - ((DE - fx_tmp * sin(DE)) - b_fx_tmp * (cos(DE) - 1.0));
        }
      }
    }
  }

  /*  evaluate the Lagrange coefficients */
  c = cos(DE);
  F = 1.0 - a / r0 * (1.0 - c);
  e = sin(DE);
  b_scale = sqrt(DM_tmp / mu);
  G = dt + b_scale * (e - DE);
  scale = 3.3121686421112381E-170;
  d = F * rr0[0] + G * vv0[0];
  rr1[0] = d;
  absxk = fabs(d);
  if (absxk > 3.3121686421112381E-170) {
    rf = 1.0;
    scale = absxk;
  } else {
    t = absxk / 3.3121686421112381E-170;
    rf = t * t;
  }

  d = F * rr0[1] + G * vv0[1];
  rr1[1] = d;
  absxk = fabs(d);
  if (absxk > scale) {
    t = scale / absxk;
    rf = rf * t * t + 1.0;
    scale = absxk;
  } else {
    t = absxk / scale;
    rf += t * t;
  }

  d = F * rr0[2] + G * vv0[2];
  rr1[2] = d;
  absxk = fabs(d);
  if (absxk > scale) {
    t = scale / absxk;
    rf = rf * t * t + 1.0;
    scale = absxk;
  } else {
    t = absxk / scale;
    rf += t * t;
  }

  rf = scale * sqrt(rf);
  Fdot = -sqrt(mu * a) / (rf * r0) * e;
  Gdot = 1.0 - a / rf * (1.0 - cos(DE));
  DM = a * b_scale * (3.0 * e - (c + 2.0) * DE) - a * dt * (1.0 - cos(DE));
  fx_tmp = r0 / mu;
  a = fx_tmp * (1.0 - F);
  b_fx_tmp = DM / mu;
  fb = Fdot * rr0[0] + Gdot * vv0[0];
  vv1[0] = fb;
  dvv[0] = fb - vv0[0];
  b_scale = rr1[0] - rr0[0];
  fb = Fdot * rr0[1] + Gdot * vv0[1];
  vv1[1] = fb;
  dvv[1] = fb - vv0[1];
  scale = rr1[1] - rr0[1];
  fb = Fdot * rr0[2] + Gdot * vv0[2];
  vv1[2] = fb;
  dvv[2] = fb - vv0[2];
  absxk = d - rr0[2];
  t = r0 * (1.0 - F);
  DM_tmp = rt_powd_snf(rf, 3.0);
  b_a = 1.0 / DM_tmp;
  DE = vv1[0];
  s = vv1[1];
  c = rr1[0];
  e = rr1[1];
  for (i = 0; i < 3; i++) {
    b_d = vv0[i];
    m = rr0[i];
    R[3 * i] = (a * (b_scale * b_d - dvv[0] * m) + b_fx_tmp * DE * b_d) + G *
      (double)b[3 * i];
    R_tmp_tmp = 3 * i + 1;
    R[R_tmp_tmp] = (a * (scale * b_d - dvv[1] * m) + b_fx_tmp * s * b_d) + G *
      (double)b[R_tmp_tmp];
    b_R_tmp_tmp = 3 * i + 2;
    R[b_R_tmp_tmp] = (a * (absxk * b_d - dvv[2] * m) + b_fx_tmp * fb * b_d) + G *
      (double)b[b_R_tmp_tmp];
    V_tmp[3 * i] = dvv[0] * dvv[i];
    toler = t * c * m;
    b_dvv[3 * i] = toler;
    V[3 * i] = toler - DM * c * b_d;
    V_tmp[R_tmp_tmp] = dvv[1] * dvv[i];
    toler = t * e * m;
    b_dvv[R_tmp_tmp] = toler;
    V[R_tmp_tmp] = toler - DM * e * b_d;
    V_tmp[b_R_tmp_tmp] = dvv[2] * dvv[i];
    toler = t * d * m;
    b_dvv[b_R_tmp_tmp] = toler;
    V[b_R_tmp_tmp] = toler - DM * d * b_d;
  }

  for (i = 0; i < 9; i++) {
    V[i] = (fx_tmp * V_tmp[i] + b_a * V[i]) + Gdot * (double)b[i];
  }

  a = rf / mu;
  fx_tmp = rt_powd_snf(r0, 3.0);
  b_a = 1.0 / fx_tmp;
  DE = vv1[0];
  s = vv1[1];
  for (i = 0; i < 3; i++) {
    c = rr0[i];
    Rdash[3 * i] = b_dvv[3 * i] - DM * DE * c;
    R_tmp_tmp = 3 * i + 1;
    Rdash[R_tmp_tmp] = b_dvv[R_tmp_tmp] - DM * s * c;
    R_tmp_tmp = 3 * i + 2;
    Rdash[R_tmp_tmp] = b_dvv[R_tmp_tmp] - DM * fb * c;
  }

  b_fx_tmp = -1.0 / (r0 * r0);
  scale = 1.0 / (rf * rf);
  b_scale = 1.0 / (mu * rf);
  for (i = 0; i < 9; i++) {
    Rdash[i] = (a * V_tmp[i] + b_a * Rdash[i]) + F * (double)b[i];
    V_tmp[i] = 0.0;
  }

  a = mu * DM / (DM_tmp * fx_tmp);
  for (R_tmp_tmp = 0; R_tmp_tmp < 3; R_tmp_tmp++) {
    V_tmp[R_tmp_tmp + 3 * R_tmp_tmp] = 1.0;
    DE = rr0[R_tmp_tmp];
    Vdash[3 * R_tmp_tmp] = b_fx_tmp * dvv[0] * DE;
    y[3 * R_tmp_tmp] = scale * rr1[0] * dvv[R_tmp_tmp];
    c_rr1[3 * R_tmp_tmp] = rr1[0] * rr1[R_tmp_tmp];
    b_rr1[3 * R_tmp_tmp] = rr1[0] * vv1[R_tmp_tmp];
    b_dvv[3 * R_tmp_tmp] = vv1[0] * rr1[R_tmp_tmp];
    b_R_tmp_tmp = 3 * R_tmp_tmp + 1;
    Vdash[b_R_tmp_tmp] = b_fx_tmp * dvv[1] * DE;
    y[b_R_tmp_tmp] = scale * rr1[1] * dvv[R_tmp_tmp];
    c_rr1[b_R_tmp_tmp] = rr1[1] * rr1[R_tmp_tmp];
    b_rr1[b_R_tmp_tmp] = rr1[1] * vv1[R_tmp_tmp];
    b_dvv[b_R_tmp_tmp] = vv1[1] * rr1[R_tmp_tmp];
    b_R_tmp_tmp = 3 * R_tmp_tmp + 2;
    Vdash[b_R_tmp_tmp] = b_fx_tmp * dvv[2] * DE;
    y[b_R_tmp_tmp] = scale * d * dvv[R_tmp_tmp];
    c_rr1[b_R_tmp_tmp] = d * rr1[R_tmp_tmp];
    b_rr1[b_R_tmp_tmp] = d * vv1[R_tmp_tmp];
    b_dvv[b_R_tmp_tmp] = fb * rr1[R_tmp_tmp];
  }

  for (i = 0; i < 9; i++) {
    b_rr1[i] = b_scale * (b_rr1[i] - b_dvv[i]);
  }

  fb = rr1[0];
  DE = rr1[1];
  for (i = 0; i < 3; i++) {
    s = dvv[i];
    d_rr1[3 * i] = fb * s;
    d_rr1[3 * i + 1] = DE * s;
    d_rr1[3 * i + 2] = d * s;
  }

  for (i = 0; i < 3; i++) {
    fb = b_rr1[i];
    DE = b_rr1[i + 3];
    s = b_rr1[i + 6];
    for (R_tmp_tmp = 0; R_tmp_tmp < 3; R_tmp_tmp++) {
      b_R_tmp_tmp = i + 3 * R_tmp_tmp;
      b_dvv[b_R_tmp_tmp] = (V_tmp[b_R_tmp_tmp] - scale * c_rr1[b_R_tmp_tmp]) +
        ((fb * d_rr1[3 * R_tmp_tmp] + DE * d_rr1[3 * R_tmp_tmp + 1]) + s *
         d_rr1[3 * R_tmp_tmp + 2]);
    }
  }

  fb = rr1[0];
  DE = rr1[1];
  for (i = 0; i < 3; i++) {
    s = rr0[i];
    c_rr1[3 * i] = fb * s;
    c_rr1[3 * i + 1] = DE * s;
    c_rr1[3 * i + 2] = d * s;
  }

  for (i = 0; i < 9; i++) {
    Vdash[i] = ((Vdash[i] - y[i]) + Fdot * b_dvv[i]) - a * c_rr1[i];
  }

  for (i = 0; i < 3; i++) {
    STM[6 * i] = Rdash[3 * i];
    R_tmp_tmp = 6 * (i + 3);
    STM[R_tmp_tmp] = R[3 * i];
    STM[6 * i + 3] = Vdash[3 * i];
    STM[R_tmp_tmp + 3] = V[3 * i];
    b_R_tmp_tmp = 3 * i + 1;
    STM[6 * i + 1] = Rdash[b_R_tmp_tmp];
    STM[R_tmp_tmp + 1] = R[b_R_tmp_tmp];
    STM[6 * i + 4] = Vdash[b_R_tmp_tmp];
    STM[R_tmp_tmp + 4] = V[b_R_tmp_tmp];
    b_R_tmp_tmp = 3 * i + 2;
    STM[6 * i + 2] = Rdash[b_R_tmp_tmp];
    STM[R_tmp_tmp + 2] = R[b_R_tmp_tmp];
    STM[6 * i + 5] = Vdash[b_R_tmp_tmp];
    STM[R_tmp_tmp + 5] = V[b_R_tmp_tmp];
  }
}

/*
 * File trailer for STM_analytic.c
 *
 * [EOF]
 */
