function [ PHIdot ] = keplerianSTMdot(t, PHI, mu)

% compute time-derivative of the position/velocity vectors and state
% transition matrix

phi    = reshape(PHI(7:42),6,6);
s(1:6) = PHI(1:6);

J2  = 0;
Req = 0;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

dx = s(4);

dy = s(5);

dz = s(6);

x = s(1);

y = s(2);

z = s(3);



d2x = -mu*x/(((x^2+y^2+z^2))^(3/2))*(1+3/2*J2*(Req^2/(x^2+y^2+z^2))*...
     (1-5*z^2/(x^2+y^2+z^2)));

d2y = -mu*y/(((x^2+y^2+z^2))^(3/2))*(1+3/2*J2*(Req^2/(x^2+y^2+z^2))*...
     (1-5*z^2/(x^2+y^2+z^2)));

d2z = -mu*z/(((x^2+y^2+z^2))^(3/2))*(1+3/2*J2*(Req^2/(x^2+y^2+z^2))*...
     (3-5*z^2/(x^2+y^2+z^2)));
 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
     
d2xx = -(2*mu*(x^2 + y^2 + z^2)^3 - 6*mu*x^2*(x^2 + y^2 + z^2)^2 +...
        3*J2*Req^2*mu*(x^2 + y^2 + z^2)^2 + 105*J2*Req^2*mu*x^2*z^2 -...
        15*J2*Req^2*mu*x^2*(x^2 + y^2 + z^2) - 15*J2*Req^2*mu*z^2*...
        (x^2 + y^2 + z^2))/(2*(x^2 + y^2 + z^2)^(9/2));

d2xy = (6*mu*x*y*(x^2 + y^2 + z^2)^2 - 105*J2*Req^2*mu*x*y*z^2 +...
        15*J2*Req^2*mu*x*y*(x^2 + y^2 + z^2))/(2*(x^2 + y^2 + z^2)^(9/2));
    
d2xz = (6*mu*x*z*(x^2 + y^2 + z^2)^2 - 105*J2*Req^2*mu*x*z^3 + ...
        45*J2*Req^2*mu*x*z*(x^2 + y^2 + z^2))/(2*(x^2 + y^2 + z^2)^(9/2));

% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
      
d2yx = (6*mu*x*y*(x^2 + y^2 + z^2)^2 - 105*J2*Req^2*mu*x*y*z^2 + ...
        15*J2*Req^2*mu*x*y*(x^2 + y^2 + z^2))/(2*(x^2 + y^2 + z^2)^(9/2));

d2yy = -(2*mu*(x^2 + y^2 + z^2)^3 - 6*mu*y^2*(x^2 + y^2 + z^2)^2 + ...
         3*J2*Req^2*mu*(x^2 + y^2 + z^2)^2 + 105*J2*Req^2*mu*y^2*z^2 - ...
         15*J2*Req^2*mu*y^2*(x^2 + y^2 + z^2) - 15*J2*Req^2*mu*z^2*...
         (x^2 + y^2 + z^2))/(2*(x^2 + y^2 + z^2)^(9/2));

d2yz = (6*mu*y*z*(x^2 + y^2 + z^2)^2 - 105*J2*Req^2*mu*y*z^3 + ...
        45*J2*Req^2*mu*y*z*(x^2 + y^2 + z^2))/(2*(x^2 + y^2 + z^2)^(9/2));
    
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        
d2zx = (6*mu*x*z*(x^2 + y^2 + z^2)^2 - 105*J2*Req^2*mu*x*z^3 + ...
        45*J2*Req^2*mu*x*z*(x^2 + y^2 + z^2))/(2*(x^2 + y^2 + z^2)^(9/2));

d2zy = (6*mu*y*z*(x^2 + y^2 + z^2)^2 - 105*J2*Req^2*mu*y*z^3 + ...
        45*J2*Req^2*mu*y*z*(x^2 + y^2 + z^2))/(2*(x^2 + y^2 + z^2)^(9/2));
        
d2zz = -(2*mu*(x^2 + y^2 + z^2)^3 - 6*mu*z^2*(x^2 + y^2 + z^2)^2 + ...
         9*J2*Req^2*mu*(x^2 + y^2 + z^2)^2 + 105*J2*Req^2*mu*z^4 - ...
         90*J2*Req^2*mu*z^2*(x^2 + y^2 + z^2))/(2*(x^2 + y^2 + z^2)^(9/2));

% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

A   =[   0     0    0     1    0    0 ;

           0     0    0     0    1    0 ;

           0     0    0     0    0    1 ;

         d2xx  d2xy  d2xz   0    0    0 ;

         d2yx  d2yy  d2yz   0    0    0 ;

         d2zx  d2zy  d2zz   0    0    0 ];

% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

phidot = A*phi;

% velocities and accelerations
PHIdot(1:6)     = [dx dy dz d2x d2y d2z];

% time-derivative of the STM
PHIdot(7:42)    = reshape(phidot,36,1);

PHIdot = PHIdot';

end

