function [dv, alpha, alpha_A] = findDV(vvrel_A, vvrel_D, muPL, rpmin)

% vvrel_A : approach infinity velocity
% vvrel_D : departing infinity velocity
% muPL    : planet gravitational constant
% rpmin   : minimum flyby radius

alpha   = acos(dot(vvrel_A, vvrel_D)/(norm(vvrel_A)*norm(vvrel_D))); % turning angle
e_A     = 1 + (rpmin*norm(vvrel_A)^2)/muPL;                          % max. deflection hyperbola eccentricity
alpha_A = 2*asin(1/e_A);                                             % max. deflection turning angle

alpha   = wrapToPi(alpha);
alpha_A = wrapToPi(alpha_A);

% --> compute the DV
if alpha <= alpha_A
    dv = abs( norm(vvrel_D) - norm(vvrel_A));
else
    dv = sqrt((norm(vvrel_A))^2 + (norm(vvrel_D))^2 - 2*(norm(vvrel_A))*(norm(vvrel_D))*cos(alpha_A - alpha));
end

end
