function [COST, dvINS, dvDEP, DVS, DTS] = biasedCOST(LEGSnext, hGTO, rpARR, raARR)

% this function computes the biased cost function:
% - departure from GTO
% - arrival at high eccentric orbit (rpARR x raARR)

% departing planet GTO manoeuvre
plDEP                 = LEGSnext(1,7);
[muPLDEP,radiusPLDEP] = planetConstants(plDEP);
rpGTO                 = hGTO + radiusPLDEP;
TGTO                  = 86164;
raGTO                 = (muPLDEP*(TGTO/(2*pi))^2)^(1/3);
vpGTO                 = sqrt((2*muPLDEP)/(rpGTO + raGTO)*(raGTO/rpGTO));

vinfDEP = LEGSnext(:,9);
EipDEP  = 0.5.*vinfDEP.^2;
vpipDEP = sqrt(2.*(EipDEP + muPLDEP./rpGTO));

dvDEP = vpipDEP - vpGTO;
% end departing planet GTO manoeuvre

% arrival planet insertion manoeuvre
plIN   = LEGSnext(1,end-3);
vinfIN = LEGSnext(:,end-1);

muPLARR = planetConstants(plIN);

Eip   = 0.5.*vinfIN.^2;
vpip  = sqrt(2.*(Eip + muPLARR./rpARR));
vp    = sqrt((2*muPLARR)/(rpARR + raARR)*(raARR/rpARR));

dvINS = vpip - vp;
% end arrival planet insertion manoeuvre

[COST, DVS, DTS, vInfDeps] = seq2Cost(LEGSnext);

COST(:,1) = DTS;
COST(:,2) = vInfDeps + sum(DVS,2) + dvINS;

end