function [TT, YY, Tfb, dv] = plotSTRUC(STRUC, NREV)

mu = 132724487690;

seq  = STRUC.Sequence;
t0   = date2mjd2000(STRUC.DepartureDate);
tofs = STRUC.TOF_LEGS_DAYS;
legs = fromSeq2Legs(seq);

sys.mu_planets = astroConstants(11:19);  % Default: Solar System

gammas = deg2rad([0 STRUC.gammas]);
rps    = [0 STRUC.FlyBy_Radii];
alphas = [0 STRUC.alphas];

epochs    = zeros(1, length(seq));
epochs(1) = t0;
for indt = 1:length(tofs)
    epochs(indt+1) = epochs(indt) + tofs(indt);
end
Tfb = epochs;
epochs = [epochs(1:end-1)' epochs(2:end)'];

YY   = [];
TT   = [];
tend = 0;
for indl = 1:size(legs,1)
   
    pl1 = legs(indl,1);
    pl2 = legs(indl,2);
    
    t1 = epochs(indl,1);
    t2 = epochs(indl,2);
    dt = (t2 - t1)*86400;
    
    [rr1, vv1] = EphSS_car(pl1, t1);
    [rr2] = EphSS_car(pl2, t2);
    
    if indl == 1
        
        [vvd, vva] = lambertMR(rr1, rr2, dt, mu, NREV(1,indl), NREV(2,indl));
        
        dv(indl) = norm(vvd - vv1);
        
        % --> propagate
        tt      = linspace(0, dt);
        [tt,yy] = propagateKepler(rr1, vvd, tt, mu);
        TT      = [TT; tend+tt];
        YY      = [YY; yy];
        tend    = TT(end);
        
    else
        
        % --> perform the flyby
        psi = gammas(indl);
        rp  = rps(indl);
        mup = sys.mu_planets(pl1);
        [xp1, vout] = swingby_vA(rr1, vva, pl1, t1, psi, rp, mup);
        
        % --> propagate until the manoeuvre
        alpha   = alphas(indl);
        tt      = linspace(0,dt*alpha);
        [tt,yy] = propagateKepler(xp1, vout, tt, mu);
        TT      = [TT; tend+tt];
        YY      = [YY; yy];
        tend    = TT(end);
        
        [xds, vds1] = FGKepler_dt(car2kep([xp1, vout], mu), dt*alpha, mu);
                
        % --> lambert problem from the manoeuvre to the next flyby
        [vvd, vva] = lambertMR(xds, rr2, dt*(1 - alpha), mu, 0, 0);
        dv(indl) = norm(vvd - vds1);
        
        % --> propagate
        tt      = linspace(0,dt*(1 - alpha));
        [tt,yy] = propagateKepler(xds, vvd, tt, mu);
        TT      = [TT; tend+tt];
        YY      = [YY; yy];
        tend    = TT(end);

    end
end

TT = epochs(1,1) + TT./86400;

end