function [SOL] = BEAM_SEARCH(INPUT, folder, iSP)

% This function DOES NOT consider Mars as an asteroid (i.e. astMax=12)!!!

if ~isempty(INPUT.indASTs)
    
    if nargin == 1
        folder = [];
        iSP = 1;
    elseif nargin == 2
        iSP = 1;
    end
    
    % --> extract the input
    astLISTe        = INPUT.astLISTe;
    EPH             = INPUT.EPH;
    tols            = INPUT.tols;
    astMax          = INPUT.astMax;
    bw              = INPUT.bw;
    OptionsMultiRev = INPUT.OptionsMultiRev;
    % indASTs  = INPUT.indASTs;

    % --> asteroids list
    astlist = astLISTe(astLISTe(:,1) ~= 3 & astLISTe(:,1) ~= 4 ,: );

    tic0 = tic;
    % --> first legs of the transfer
    [LEGS, VAS] = firstLegs_BS_v2(astLISTe, EPH, tols, OptionsMultiRev);

    % --> number of unique asteroids
    N_ASTS(1,1) = length(unique(LEGS(:,end), 'stable'));

    % --> run the beam search
    for ind = 2:astMax
        
        fprintf('Leg # %d \n', ind);

        % --> next asteroids
        [LEGSnext, VASnext] = search_ACO(LEGS, VAS, astlist, EPH, tols, OptionsMultiRev);

%         % --> eliminate too 'late' asts.
%         [LEGSnext, VASnext] = eliminateTooLateAsts_ACO(LEGSnext, VASnext, astlist, astMax);
        
        % --> apply beam width
        [LEGSnext, VASnext] = applyBW_DSMt(LEGSnext, VASnext, bw);
        if ~isempty(LEGSnext)
            LEGS = LEGSnext;
            VAS  = VASnext;
        else
            break
        end

        % --> number of unique asteroids
        N_ASTS(ind,1) = length(unique(LEGSnext(:,end), 'stable'));
        
    end
    costTOT = sum(LEGS(:,2:2:end-1),2); % --> cost of the tour

    % --> find the best-DV path
    [minCost, row] = min(costTOT);
    LEGrow         = LEGS(row,:);
    path           = constructPathFromLEGS_v2(LEGrow, astLISTe, EPH, OptionsMultiRev);

    ids           = path(:,1)';
    ids(ids == 3) = [];
    ids(ids == 4) = [];
    Nasts         = length(ids);

    toc0 = toc(tic0);

    % --> save the solution
    SOL.BeamWidth        = bw;
    SOL.N_ASTS_LEV       = N_ASTS;
    SOL.LEGS             = LEGS;
    SOL.costTOT_legs     = costTOT;
    SOL.path_best_DV     = path;
    SOL.cost_best_path   = minCost;
    SOL.tofy_best_path   = (path(end,2) - path(1,2))/365.25;
    SOL.Nasts            = Nasts;
    SOL.tocVec           = toc0;
    
    saveSOL(folder, iSP, bw, SOL);

    
else
    SOL = [];
end

end