function [SOL] = BEAM_SEARCH_v2(INPUT, folder, iSP, bestSeq)

% This function DOES NOT consider Mars as an asteroid (i.e. astMax=12)!!!

if nargin == 1
    folder  = [];
    iSP     = 1;
    bestSeq = [];
elseif nargin == 2
    iSP     = 1;
    bestSeq = [];
elseif nargin == 3
    bestSeq = [];
end

% --> extract the input
MAT             = INPUT.MAT;
seq             = INPUT.seq;
epochs          = INPUT.epochs;
tols            = INPUT.tols;
astMax          = INPUT.astMax;
bw              = INPUT.bw;
OptionsMultiRev = INPUT.OptionsMultiRev;
parallel        = INPUT.parallel;

% --> first legs of the transfer
[EPH]       = generateEPH_BS(seq, epochs, MAT);
[LEGS, VAS] = firstLEGS_BS(EPH, tols, OptionsMultiRev);

tic0 = tic;

% --> number of unique asteroids
N_ASTS(1,1) = length(unique(reshape(LEGS(:,3:2:end), 1, size(LEGS(:,3:2:end),1)*size(LEGS(:,3:2:end),2))));

nsols(1,1)  = size(LEGS,1);

% --> run the beam search
for ind = 2:astMax

    fprintf('Leg # %d \n', ind);

    % --> next asteroids
    [LEGSnext, VASnext] = search_ACO_v2(LEGS, VAS, EPH, tols, OptionsMultiRev, parallel);

    % --> sort and find BW to capture GO
    if ~isempty(bestSeq)
        [LEGSnext, VASnext] = sortBS_DSMt_v2(LEGSnext, VASnext);
        indrow              = checkSameSeq(bestSeq, LEGSnext);
        if bw < indrow % --> increase the BW to capture the GO
            bw = indrow;
        end
    end

    % --> eliminate too 'late' asts.
    [LEGSnext, VASnext] = eliminateTooLateAsts_ACO(LEGSnext, VASnext, EPH, astMax);
    
    % --> apply beam width (if last leg, do not apply it)
    if ~isempty(LEGSnext)
        if ind < astMax
            [LEGSnext, VASnext] = applyBW_DSMt(LEGSnext, VASnext, bw);
        end
        LEGS = LEGSnext;
        VAS  = VASnext;
    else
        break
    end
    
    % --> number of unique asteroids
%     N_ASTS(ind,1) = length(unique(LEGSnext(:,end), 'stable'));
    N_ASTS(ind,1) = length(unique(reshape(LEGSnext(:,3:2:end), 1, size(LEGSnext(:,3:2:end),1)*size(LEGSnext(:,3:2:end),2))));
    nsols(ind,1)  = size(LEGSnext,1);

end
costTOT = sum(LEGS(:,2:2:end-1),2); % --> cost of the tour

% --> find the best-DV path
[minCost, row] = min(costTOT);
LEGrow         = LEGS(row,:);
path           = constructPath_BS(LEGrow, EPH, OptionsMultiRev);
ids            = path(:,1)';
ids(ids < 11)  = [];
Nasts          = length(ids);

toc0 = toc(tic0);

% --> save the solution
SOL.BeamWidth        = bw;
SOL.N_ASTS_LEV       = N_ASTS;
SOL.LEGS             = LEGS;
SOL.VAS              = VAS;
SOL.EPH              = EPH;
SOL.costTOT_legs     = costTOT;
SOL.path_best_DV     = path;
SOL.cost_best_path   = minCost;
SOL.tofy_best_path   = (path(end,2) - path(1,2))/365.25;
SOL.Nasts            = Nasts;
SOL.tocVec           = toc0;
SOL.nsols            = nsols;

saveSOL(folder, iSP, bw, SOL);

end