function [LEGSnext, VASnext] = search_ACO_v2(LEGS, VAS, EPH, tols, OptionsMultiRev, parallel)

if parallel == 0 % --> USE SEQUENTIAL

    LEGSnext = zeros(15e6, size(LEGS,2)+2);
    VASnext  = zeros(15e6, 3);
    ind      = 1;
    for indl = 1:size(LEGS,1)

        indl/size(LEGS,1)*100;

        % --> extract the info
        legprev = LEGS(indl,:);
        as1     = legprev(end);
        vvin    = VAS(indl,:);

        % --> compute next asteroids
        list = computeDVsNext_ACO_v2(as1, vvin, EPH, tols, OptionsMultiRev);

        % --> construct the legs
        legnext = [legprev.*ones(size(list,1), size(legprev,2)) list(:,3) list(:,1)];
        vasnext = list(:,end-2:end);

        % --> check if the total cost exceeds the tolerance
        costTOT                        = DVseq(legnext);
        legnext( costTOT > tols(4), :) = [];
        vasnext( costTOT > tols(4), :) = [];

        % --> check if the DSMtot exceeds the tolerance
        [~, ~, ~, DSMtot]            = DVseq(legnext);
        legnext( DSMtot > tols(2),:) = [];
        vasnext( DSMtot > tols(2),:) = [];

        LEGSnext(ind:ind-1+size(legnext,1),:) = legnext;
        VASnext(ind:ind-1+size(legnext,1),:)  = vasnext;
        ind = ind + size(legnext,1);

    end
    LEGSnext = LEGSnext(~all(LEGSnext == 0, 2),:); % --> eliminate rows all equal to zero
    VASnext  = VASnext(~all(VASnext == 0, 2),:);   % --> eliminate rows all equal to zero

else % --> USE PARALLEL

    STRUC = struct('LEGSnext', [], 'VASnext', []);
    parfor indl = 1:size(LEGS,1) % --> parallelize here

        indl/size(LEGS,1)*100;

        % --> extract the info
        legprev = LEGS(indl,:);
        as1     = legprev(end);
        vvin    = VAS(indl,:);
        
        % --> compute next asteroids
        list = computeDVsNext_ACO_v2(as1, vvin, EPH, tols, OptionsMultiRev);

        % --> construct the legs
        legnext = [legprev.*ones(size(list,1), size(legprev,2)) list(:,3) list(:,1)];
        vasnext = list(:,end-2:end);

        % --> check if the total cost exceeds the tolerance
        costTOT                        = DVseq(legnext);
        legnext( costTOT > tols(4), :) = [];
        vasnext( costTOT > tols(4), :) = [];

        % --> check if the DSMtot exceeds the tolerance
        [~, ~, ~, DSMtot]            = DVseq(legnext);
        legnext( DSMtot > tols(2),:) = [];
        vasnext( DSMtot > tols(2),:) = [];

        STRUC(indl).LEGSnext = legnext;
        STRUC(indl).VASnext  = vasnext;

    end

    hasNone        = cellfun(@isempty,{STRUC.LEGSnext});
    STRUC(hasNone) = [];

    LEGSnext = cell2mat({STRUC.LEGSnext}');
    VASnext  = cell2mat({STRUC.VASnext}');

end

end
