function INPUT = wrapInit(seq, epochs, MAT, param, OptionsMultiRev)

if nargin == 4
    OptionsMultiRev = [0 0];
end

muSun  = 132712440018; 
astMax = param.astMax;
bw     = param.bw;
tols   = param.tols;

if size(seq,2) > 1
    seq    = seq';
end
if size(epochs,2) > 1
    epochs = epochs';
end

if ~isempty(MAT)
   
    try
        ephNEO('load','ephNEO_CATABC.txt');
    catch
    end
    
    % --> add planets to the MAT
    ASTEROIDS_LIST = MAT(:,1);
    MOIDS_EPOCHS   = MAT(:,4);
    ASTEROIDS      = [ASTEROIDS_LIST, MOIDS_EPOCHS];
    ASTEROIDS      = [ [seq epochs] ; ASTEROIDS];
    ASTEROIDS      = sortrows(ASTEROIDS, 2);
    astLISTe       = ASTEROIDS;
    
    % --> generate the ephemerides
    [EPH] = generateEph(astLISTe);

    % --> run the first legs
    as1   = 3;
    indxs = find(astLISTe(:,1) == as1);
    indxs = indxs(1);
    t1    = EPH(indxs, 2);
    rr1   = EPH(indxs, 3:5);
    vv1   = EPH(indxs, 6:8);

    dv = zeros(size(astLISTe,1),1);
    for inda = 2:size(astLISTe,1)
        
        as2      = astLISTe(inda,1);
        EPH_temp = EPH(1:inda,:);
        indxs    = find(EPH_temp(:,1) == as2);
        indxs    = indxs(end);
        
        t2  = EPH_temp(indxs,2);
        rr2 = EPH_temp(indxs, 3:5);
                
        % --> solve the MRLP and only keep the best DV solution
        [dv(inda,1)] = lambert_MR_opts(vv1, rr1, rr2, (t2 - t1)*86400, muSun, OptionsMultiRev);
        
    end
    
    ind       = 1:1:size(astLISTe,1);
    LIST      = [ind' astLISTe dv];
    LIST(1,:) = [];
    LIST( LIST(:,end) > tols(1) , :) = [];
    indASTs   = LIST(:,1:2);

    INPUT = writeINPUT_BS(astLISTe, EPH, tols, astMax, bw, indASTs);
    INPUT.OptionsMultiRev = OptionsMultiRev;
    
else
    
    INPUT.astLISTe        = [];
    INPUT.EPH             = [];
    INPUT.tols            = [];
    INPUT.astMax          = [];
    INPUT.bw              = [];
    INPUT.indASTs         = [];
    INPUT.OptionsMultiRev = [];
    
end

end

