function [MatrixSummary_4] = MatrixMenu_Search_DirectShot_A62Sp(KepBase, nAst, MOIDThreshold, tW, FlagType, flyby)
%% Compute a list of potential asteroids

% OUTPUT: 
% MatrixSummary_4 = ...
% [AstIndList tA(Ast1(2),E2) tA(KepBase(2),E1) TOpList(indMin) PA  Min_distL]
%
%  AstIndList - Asteroid index as in Ephemeris list (i.e. AstIndList can be
%  smaller than 11).
%
% 
%--------------------------------------------------------------------------

% Constants
AU       = astroConstants(2);
muSun    = astroConstants(4);
muSun_AU = muSun/AU^3;

%--------------------------------------------------------------------------
% Step 2 - Walk through the whole set
%--------------------------------------------------------------------------
MOID_vector = zeros(nAst,1);
E1_vector   = zeros(nAst,1);
E2_vector   = zeros(nAst,1);
for indA = 1:nAst
    
    indexAsteroid = indA+11;
    Ast1          = ephSS_kep(indexAsteroid, 0);
    Ast1(1)       = Ast1(1)/AU;
    
    %--------------------------------------------------------------------------
    % Step 3 - Compute MOID and Relative velocity of asteroids at the MOID
    % point
    %--------------------------------------------------------------------------
    
    [MOIDGuess1, MOIDGuess2] = PhD_MOIDapproxBonnano3(KepBase, Ast1);
    if min([MOIDGuess1,MOIDGuess2]) < 1.5*MOIDThreshold
        
        [MOID,E1,E2]      = MOIDMilisavljevicMex(KepBase, Ast1);
        [MOID,indE]       = min(MOID);
        MOID_vector(indA) = MOID;
        E1_vector(indA)   = E1(indE);
        E2_vector(indA)   = E2(indE);
        
    else
        MOID_vector(indA) = min([MOIDGuess1,MOIDGuess2]);
    end
    indA/nAst*100
end

AstIndList = find(MOID_vector < MOIDThreshold);

%--------------------------------------------------------------------------
%% 3.2. Compute actual distance with potential flybys

if ~isempty(AstIndList)

    % On this list Compute actual potential encounters
    tA = @(ecc,E) 2*atan(sqrt((1+ecc)/(1-ecc))*tan(E/2));
    t0 = tW(1);
    tf = tW(2);

    MatrixSummary = [];
    for iT = 1:length(AstIndList)

        indexAsteroid = AstIndList(iT)+11;
        Ast1          = ephSS_kep(indexAsteroid, t0);
        Ast1(1)       = Ast1(1)/AU;

        MOID = MOID_vector(AstIndList(iT));
        E1   = E1_vector(AstIndList(iT));
        E2   = E2_vector(AstIndList(iT));

        SV1 = kep2car([KepBase(1:5) tA(KepBase(2),E1) ] , muSun_AU);
        SV2 = kep2car([Ast1(1:5)    tA(Ast1(2),E2)    ] , muSun_AU);

        minDist = norm(SV1(1:3) - SV2(1:3));

        error = abs(MOID - minDist)/MOID;
        if error < 10
            % First epoch at which the asteroid is at its MOID point
            Dt_sec  = kepEq_t(tA(Ast1(2),E2), Ast1(1), Ast1(2), muSun_AU, Ast1(6), 0);
            Dt_days = Dt_sec/3600/24;
            PA      = 2*pi*sqrt(Ast1(1)^3/muSun_AU)/3600/24;
            if Dt_days < 0
                Dt_days = Dt_days + PA;
            end
            % Generate Matrix summary
            MatrixSummary = [MatrixSummary; [AstIndList(iT) tA(Ast1(2),E2) tA(KepBase(2),E1) t0+Dt_days PA]];
        end
    end

    % Process checking actual distances for each possible asteroid given initial orbit.

    if ~isempty(MatrixSummary)

        %--------------------------------------------------------------------------
        % cleaning:
        % 2. Clean FlyBies occuring before FB1
        tFB1     = t0;
        indexDEL = find(MatrixSummary(:,4) < tFB1);
        if ~isempty(indexDEL)
            MatrixSummary(indexDEL,:) = [];
        end
        % 3. Clean FlyBies occuring after the 7 years after launch
        indexDEL = find(MatrixSummary(:,4) > tf);
        if ~isempty(indexDEL)
            MatrixSummary(indexDEL,:) = [];
        end
        %--------------------------------------------------------------------------

        nSize                         = size(MatrixSummary);
        MatrixSummary_2               = zeros(nSize(1),nSize(2)+1);
        MatrixSummary_2(:,1:nSize(2)) = MatrixSummary;

        nIter = length(MatrixSummary(:,1));

        for iItr = 1:nIter

            %  SC_phase = MatrixSummary(iItr,3);
            Epoch = t0;
            SCKep = KepBase;
            
            indexAT   = MatrixSummary(iItr,1)+11;
            AsteroidT = ephNEO(t0, indexAT);
            
            % Position Asteroid MOID point
            SV_MOID = kep2car([AsteroidT(1)/AU AsteroidT(2:5) MatrixSummary(iItr,2)] ,muSun_AU);
            
            % Encounter Opportunities
            T1      = MatrixSummary(iItr,4);
            PA      = MatrixSummary(iItr,5);
            TOpList = T1:PA:tf;
            
            % Compute distance for each of these opportunities
            inSV = kep2car(SCKep,muSun_AU);
            dt   = (TOpList-Epoch)*3600*24;
            out  = zeros(length(dt),6);
            for kT = 1:length(dt)
                [out(kT,:)] = kepPro(inSV,dt(kT),muSun_AU);
            end

            distL = sqrt((SV_MOID(1)-out(:,1)).^2 + (SV_MOID(2)-out(:,2)).^2+(SV_MOID(3)-out(:,3)).^2);

            [Min_distL, indMin]              = min(distL);
            MatrixSummary_2(iItr,nSize(2)+1) = Min_distL;
            MatrixSummary_2(iItr,4)          = TOpList(indMin);
        end
        
        %--------------------------------------------------------------------------
        % clean encounters a too much distance
        indexDEL                    = find(MatrixSummary_2(:,6) > MOIDThreshold);
        MatrixSummary_2(indexDEL,:) = [];
        %--------------------------------------------------------------------------
        % Sort Potential Sequence and Add ToF for each FlyB
        
        [~,inSort]      = sort(MatrixSummary_2(:,4));
        MatrixSummary_3 = [MatrixSummary_2(inSort,:) MatrixSummary_2(inSort,4)-Epoch];

        %%
        
        SoyuzC3Performance      = [0 2180; 5 1900; 7 1800; 9 1700; 11.5 1600; 16 1400; 20 1250; 24 1100; 25 1075];
        MassAdapter             = 80; 
        SoyuzC3Performance(:,2) = SoyuzC3Performance(:,2) - MassAdapter;
        Factor                  = 1.5;
        A62C3Performance        = [SoyuzC3Performance(:,1) Factor*SoyuzC3Performance(:,2)];

        % LEG2 CHECK
        % Building Iterative Process to construct sequences
        nlSummary     = length(MatrixSummary_3(:,1));
        DVs_Estimate  = zeros(nlSummary,1);
        Mass_Estimate = zeros(nlSummary,1);
        disp(['MatrixSummary_3 Contains ',num2str(length(MatrixSummary_3(:,1))),' asteroids'])
        for indexSA = 1:length(MatrixSummary_3(:,1))
            if FlagType == 1
                %----------------------------------------------------------------------
                % Sequence calculation for the first leg
                Sequence = [3 MatrixSummary_3(indexSA,1)+11 4];
                t1       = MatrixSummary_3(indexSA,4);
                t2       = tf;
                %     Times = [t0 t1 t2];
                %--------------------------------------------------------------------------
                % Let's go straight with the information we have and add some margin
                [dvTotal, dvSplit]    = Transfer_CASTAway_MultiRev(Sequence, [t0 t1 t2]);
                DVs_Estimate(indexSA) = dvTotal;
                %--------------------------------------------------------------------------
                if dvSplit(1)<=5
                    WetMassDep_1L = interp1(sqrt(A62C3Performance(:,1)),A62C3Performance(:,2),dvSplit(1));
                    ve            = 320*9.81;
                    WetMassDep_2L = WetMassDep_1L*exp(-dvSplit(2)*1000/ve);
                else
                    dvSplit(1)    = dvSplit(1)-5;
                    WetMassDep    = A62C3Performance(end,2);
                    ve            = 320*9.81;
                    WetMassDep_2L = WetMassDep*exp(-sum(dvSplit)*1000/ve);
                end
                Mass_Estimate(indexSA) = WetMassDep_2L;
            elseif FlagType == 2
                %----------------------------------------------------------------------
                % Sequence calculation for the first leg: after Mars FlyBy
                %----------------------------------------------------------------------
                % Sequence calculation for the first leg
                Sequence = [3 4 MatrixSummary_3(indexSA,1)+11];
                t1       = tW(1);
                t0       = tW(3);
                t2       = MatrixSummary_3(indexSA,4);
                %--------------------------------------------------------------------------
                % Let's go straight with the information we have and add some margin              
                [dvTotal, dvSplit] = Transfer_CASTAway_MultiRev_MarsSW(Sequence, [t0 t1 t2], flyby);
                DVs_Estimate(indexSA) = dvTotal;
                %--------------------------------------------------------------------------
                if dvSplit(1) <= 5
                    WetMassDep_1L = interp1(sqrt(A62C3Performance(:,1)),A62C3Performance(:,2),dvSplit(1));
                    ve            = 320*9.81;
                    WetMassDep_2L = WetMassDep_1L*exp(-dvSplit(2)*1000/ve);
                else
                    dvSplit(1)    = dvSplit(1) - 5;
                    WetMassDep    = A62C3Performance(end,2);
                    ve            = 320*9.81;
                    WetMassDep_2L = WetMassDep*exp(-sum(dvSplit)*1000/ve);
                end
                Mass_Estimate(indexSA) = WetMassDep_2L;
            end
        end
        MatrixSummary_4 = [MatrixSummary_3  DVs_Estimate Mass_Estimate];
        
    else
        MatrixSummary_4 = [];
    end

else
    MatrixSummary_4 = [];
end

% --> clear all DV above 2 km/s
if ~isempty(MatrixSummary_4)
    DryMass                     = 850;
    indexDel                    = find( MatrixSummary_4(:,9) < DryMass );
    MatrixSummary_4(indexDel,:) = [];
end

% --> display
if ~isempty(MatrixSummary_4)
    disp(['MatrixSummary_4 Contains ',num2str(length(MatrixSummary_4(:,1))),' asteroids']);
else
    disp(['MatrixSummary_4 Contains ',num2str(0),' asteroids']);
end

end