function [raE, raP2, dryMass, KepBase, svDepSW_mars, Car_Baseline_1, DV] = ...
            Transfer_CASTAway_marsSW_rA_A62( t0, TOF, vinfLim, OptionsMultiRev)
%--------------------------------------------------------------------------
muSun = astroConstants(4);
AU    = astroConstants(2);
RAD   = pi/180;
%--------------------------------------------------------------------------
% Launch Model

t1   = t0 + TOF; % --> arrival date at Mars
vInf = 0;        % km/s

% --> Lambert Arc Generation

% Departure
idEarth = 3;
[sE(1:3), sE(4:6)] = EphSS_car(idEarth, t0); % Departure

% Arrival
idMars             = 4;
[sA(1:3), sA(4:6)] = EphSS_car(idMars, t1); % Arrival

dv              = zeros(1,length(OptionsMultiRev(:,1)));
rA              = zeros(1,length(OptionsMultiRev(:,1)));
Dec             = zeros(1,length(OptionsMultiRev(:,1)));
VelocitiesDep   = zeros(length(OptionsMultiRev(:,1)),3);
VelocitiesArr   = zeros(length(OptionsMultiRev(:,1)),3);
for iO = 1:length(OptionsMultiRev(:,1))
    
    multirev = OptionsMultiRev(iO,1);
    energy   =  OptionsMultiRev(iO,2);
    
    [~, ~, ~, error, vI, vF, ~, ~] = ...
        lambertMR(sE(1:3), sA(1:3), (t1-t0)*86400, muSun, 0, multirev, energy, 0);
    
    if error == 0
        
        VelocitiesDep(iO,:) = vI;
        VelocitiesArr(iO,:) = vF;
        
        dv(iO) = (norm(vI - sE(4:6)) - vInf)*(norm(vI - sE(4:6)) - vInf >= 0);
        
        Car_Baseline_1 = [sE(1:3) vI];
        KepBase        = car2kep(Car_Baseline_1,muSun);
        KepBase(1)     = KepBase(1)/AU;
        rA(iO)         = KepBase(1)*(1+KepBase(2));

        vEscape = vI - sE(4:6);
        epsilon = 23.5*pi/180;
        R       = [1 0 0; 0 cos(epsilon) -sin(epsilon); 0 sin(epsilon) cos(epsilon)];
        v_eci   = R*vEscape';
        Dec(iO) = asin(v_eci(3)/norm(v_eci))/RAD;
    else
        dv(iO)  = 99;
        rA(iO)  = 0;
        Dec(iO) = NaN;
    end
end

%% What dv are feasible? Dv = 5.5 km/s

indexFeasible = find((dv < vinfLim) & (Dec > -10) & (Dec < 5));

if ~isempty(indexFeasible)
    %--------------------------------------------------------------------------
    % Constants
    muMars = getAstroConstants('Mars','Mu');
    RMars  = getAstroConstants('Mars','Radius');
    %--------------------------------------------------------------------------
    
    [raE, indM] = max(rA(indexFeasible)); % --> max rA (apoapsis) after Earth departure
    
    %--------------------------------------------------------------------------
    
    % Mars Swing-by
    
    vinf1 = VelocitiesArr(indexFeasible(indM),:) - sA(4:6);
    
    % --> compute max deflection --> behind --> alignement
    
    % --> As Rosetta, CASTAway should aim at a 250 km altitude fly-by as a maximum close encounter.
    rpFB = RMars + 250;
    
    n_r         = cross(vinf1, sA(4:6)); % --> Reference vector
    n_r         = n_r / norm(n_r);
    gamma       = 0;
    vinf2       = swingby(vinf1, rpFB, muMars, gamma, n_r)'; % --> compute the flyby
    vDepSW_mars = vinf2 + sA(4:6);
    
    %--------------------------------------------------------------------------
    % Departure conditions after Mars Swing By
    svDepSW_mars     = [sA(1:3) vDepSW_mars];
    kepDepSW_mars    = car2kep(svDepSW_mars, muSun);
    kepDepSW_mars(1) = kepDepSW_mars(1)/AU;
    raP2             = kepDepSW_mars(1)*(1 + kepDepSW_mars(2));
    %--------------------------------------------------------------------------
    % Final dryMass
    % Ariane 62 Performance data
    SoyuzC3Performance = [0 2180;...
                          5 1900;...
                          7 1800;...
                          9 1700;...
                       11.5 1600;...
                         16 1400;...
                         20 1250;...
                         24 1100;...
                         25 1075];

    MassAdapter             = 80; 
    SoyuzC3Performance(:,2) = SoyuzC3Performance(:,2) - MassAdapter;
    Factor                  = 1.5;
    A62C3Performance        = [SoyuzC3Performance(:,1) Factor*SoyuzC3Performance(:,2)];

    DV = dv(indexFeasible(indM));
    if DV <= 5
        dryMass = interp1(sqrt(A62C3Performance(:,1)),A62C3Performance(:,2),DV);
        % There is a problem in the above, but now the list has been
        % created so I keep with the same.
    else
        DV         = DV - 5;
        WetMassDep = A62C3Performance(end,2);
        ve         = 320*9.81;
        dryMass    = WetMassDep*exp(-DV*1000/ve);
    end
    %--------------------------------------------------------------------------
    % Computing Baseline Trajectories
    Car_Baseline_1 = [sE(1:3) VelocitiesDep(indexFeasible(indM),:)];
    KepBase1       = car2kep(Car_Baseline_1,muSun);
    KepBase1(1)    = KepBase1(1)/AU;

    KepBase2 = kepDepSW_mars;
    
    KepBase = [KepBase1 t0;...
               KepBase2 t1];
else
    raE     = 0;
    raP2    = 0;
    dryMass = 0;
    KepBase = [];
end

end
