function []=minDistanceSearch(astInd,t0Bounds)
%--------------------------------------------------------------------------
% Constants
AU     = astroConstants(2);  
muSun  = astroConstants(4);                                     %AU^3/sec^2
SEC2DAY=1/3600/24;
% Functions
 tA=@(e,E)2*atan(sqrt((1+e)/(1-e))*tan(E/2));
%--------------------------------------------------------------------------
% Asteroid Data
    ast1Kep = ephNEO(t0Bounds(1), astInd(1));
    ast2Kep = ephNEO(t0Bounds(1), astInd(2));
    
    PA1=(2*pi*sqrt(ast1Kep(1)^3/muSun))*SEC2DAY;
    PA2=(2*pi*sqrt(ast2Kep(1)^3/muSun))*SEC2DAY;
    
%--------------------------------------------------------------------------
% Compute synodic period
  synPer = abs(1/(1/(2*pi*sqrt(ast1Kep(1)^3/muSun))-...
           1/(2*pi*sqrt(ast2Kep(1)^3/muSun))))*SEC2DAY;   
%--------------------------------------------------------------------------
% Setting up first Guesses for min distance search
 [MOID,E1,E2] = MOIDMilisavljevicMexing([ast1Kep(1)/AU ast1Kep(2:6)],...
                                        [ast2Kep(1)/AU ast2Kep(2:6)]);                                 
 indexNaN=find(isnan(MOID));                                  
 MOID(indexNaN)=[];E1(indexNaN)=[];E2(indexNaN)=[];
 
 % Eccentric 2 true anomaly
 tA1=tA(ast1Kep(2),E1); 
 tA2=tA(ast2Kep(2),E2); 
 
 % Time at which either ast1 or ast2 is in one oof its minimums
 tGuess=[];
    % ASTEROID 1
 for iA1=1:length(tA1)
    a = ast1Kep(1);
    e = ast1Kep(2);
    Dt = kepEq_t(tA1(iA1), a, e, muSun, ast1Kep(6), 0);
    tGuess=[tGuess; t0Bounds(1)+Dt*SEC2DAY];   
    while tGuess(end)<t0Bounds(2)
        tGuess=[tGuess; tGuess(end)+PA1]
    end
 end
    % ASTEROID 2
 for iA2=1:length(tA2)
    a = ast2Kep(1);
    e = ast2Kep(2);
    Dt = kepEq_t(tA2(iA2), a, e, muSun, ast2Kep(6), 0);
    tGuess=[tGuess; t0Bounds(1)+Dt*SEC2DAY];   
    while tGuess(end)<t0Bounds(2)
        tGuess=[tGuess; tGuess(end)+PA2]
    end
 end
 indexCUT=find(tGuess<t0Bounds(1)|tGuess>t0Bounds(2));
 tGuess(indexCUT)=[];
 %-------------------------------------------------------------------------
    % Minimization
    
    dist=@(t,ind1,ind2)norm(ephSS_car(ind1,t)-ephSS_car(ind2,t))/AU;
    lb=t0Bounds(1);
    ub=t0Bounds(2);
    
    Results=zeros(length(tGuess),3);
   for iO=1:length(tGuess) 
    [tS,fval,exitflag,output] = fmincon(@(t)dist(t,astInd(1),astInd(2)),tGuess(iO),[],[],[],[],...
                        lb,ub,[]);                    
    Results(iO,:)=[fval tS exitflag];
   end


    optionfmin = optimset('Display','off','MaxFunEvals',1000,'TolFun',1e-11,'TolX',1e-11);
  
    
    
end
