function ev = kep2ev(kep)

% kep2ev.m - Keplerian elements to Equinoctial Variables.
%
% PROTOTYPE:
%   ev = kep2ev(kep)
%
% DESCRIPTION:
%   Transformation from Keplerian elements to Equinoctial Variables.
%   Vector of Keplerian elements:
%       [a e i Om om f], where f is the true anomaly.
%       a in [L], angles in [rad].
%   Vector of Equinoctial Variables:
%       [a P1 P2 Q1 Q2 l], where l is the mean longitude.
%       a in [L], l in [rad].
%
% INPUT:
%	kep[6]      Vector of Keplerian elements [a e i Om om f],
%               where f is the true anomaly. a in [L], angles in [rad].
%
% OUTPUT:
%	ev[6,1]       Vector of Equinoctial Variables [a P1 P2 Q1 Q2 l],
%               where l is the mean longitude. a in [L], l in [rad].
%
%
% CALLED FUNCTIONS:
%   (none)
%
% AUTHOR:
%   Alessandro Peloni, 10/05/2013, MATLAB, kep2ev.m
%
%
% -------------------------------------------------------------------------

omega_t = kep(4)+kep(5);

E = acos((kep(2)+cos(kep(6)))/(1+kep(2)*cos(kep(6))));
if sin(kep(6)) < 0
    E = -E;
end

K = omega_t + E;


ev(1,1) = kep(1);

ev(2,1) = kep(2)*sin(omega_t);

ev(3,1) = kep(2)*cos(omega_t);

ev(4,1) = tan(kep(3)/2)*sin(kep(4));

ev(5,1) = tan(kep(3)/2)*cos(kep(4));

ev(6,1) = K + ev(2)*cos(K)-ev(3)*sin(K);

return