%BulirschStoer Mex File ... BulirschMex.m
%--------------------------------------------------------------------------
%Description:
%--------------------------------------------------------------------------
%Adaptation from Juergen Dietel's BulierschStoer Numerical ODE Solver
%Currently only Kepler state equations have been incorporated .... this
%framework should work for all coupled first order differential equations
%
% Functions must be precompiled to run on MATLAB.  Please Compile using the
% following command sequence:
% >> mex BulirschMex.cpp bulirsch.cpp basis_r.cpp t_dgls.cpp vmblock.cpp
%
%Input List:
%--------------------------------------------------------------------------
% bspnummer             Pointer                 Case Number [0-13]
%                                               These cases may be expanded
%                                               on if J2 pertubations or
%                                               other coupled ODEs are
%                                               necessary
%
% epsabs                REAL                    Absolute Error Tolerance
%
% epsrel                REAL                    Relative Error Tolerance
%
% y0                    Pointer                 Array of initial values
%                                               y1(x0) = A
%                                               y2(x0) = B
%                                               y3(x0) = C
%
% h                     long                    Starting Step Size
%                                               Recomended to be set to 1
%
% fmax                  long                    Max Number of Func Calls
%
% SupressOutput         Bool                    Turn Verbose Output On
%                                               This is used for testing
%                                               and debugging purposes
%                                               WARNING: DO NOT USE THIS
%                                               FOR MULTIPLE FUNCTION
%                                               CALLS
%
% xn                    Pointer                 [x0 .... xend]  Steps in
%                                               which a solution is
%                                               required.
%
% amax                  mwSize                  Maximum array initialization
%                                               element size.  This should
%                                               not be set too large as it
%                                               will cause memory issues.
%                                               This is only needed when
%                                               multiple timesteps are
%                                               required
%
% singletonOutput      Bool                     TRUE = single solution
%                                                      (amax not required)
%
%                                               FALSE = time step solutions
%                                                       (amax required to
%                                                       retain values)
%
%Output List:
%--------------------------------------------------------------------------
% y                       Pointer               [N x M] solutions for f(x)
%                                                corresponding to each x
%--------------------------------------------------------------------------
% Programmed by Darin Koblick 02/03/2011 All Rights Reserved.
%--------------------------------------------------------------------------
function [varargout] = BulirschMex(varargin)
if exist('BulirschMex','file') ~= 3
    disp('Please Wait ... Compiling BulirschMex Code');
    mex BulirschMex.cpp bulirsch.cpp basis_r.cpp t_dgls.cpp vmblock.cpp;
    disp('Done ... Resuming Code Execution');
end
[varargout{1} varargout{2} varargout{3}] = BulirschMex(varargin{:});