/***********************************************************************/
//Note: to link with files: bulirsch.cpp, basis_r.cpp, t_dgls.cpp, vmblock.cpp
// Modified by Darin Koblick 02/03/2011 All Rights Reserved.
//----------------------------------------------------------------------------	
#include <iostream>
#include <math.h>
#include "basis.h"
#include "vmblock.h"
#include "t_dgls.h"
#include "mex.h"
using namespace std;
extern void _main();

int bul_stoe       /* Extrapolation method for 1st order DE systems ..*/
    (
     REAL      *x,             /* initial x-value/ final x-value .....*/
     REAL      xend,           /* desired end point ..................*/
     int       n,              /* number of DEs ......................*/
     dglsysfnk dgl,            /* right hand side of DE system .......*/
     REAL      y[],            /* initial y-value/ final y-value .....*/
     REAL      epsabs,         /* absolute error bound ...............*/
     REAL      epsrel,         /* relative error bound ...............*/
     REAL      *h,             /* initial/final step size ............*/
     REAL      hmax,           /* maximal step size ..................*/
     int       neu,            /* use an outside given x ? ...........*/
     REAL      fmax,           /* maximal # of calls of  dgl() .......*/
     long      *aufrufe,       /* actual # of calls of dgl() .........*/
     REAL      *xstep,         /* all steps of x values ..............*/
     int       *nsteps,        /* Total number of steps needed .......*/
     REAL      *ysteps,        /* all steps of y values ..............*/
     mwSize    *amax,          /* Maximum array size .................*/
     bool      singletonOutput /* Only output the final solution y(x).*/
    );                         /* error code .........................*/

/****************************/

void mexFunction(
		 int          nlhs,
         mxArray *plhs[],
		 int          nrhs,
		 const mxArray *prhs[]
		 )
{
  //----------------------------------------------------------------------------	
  int bspnummer;       /* Example Number (0-12)                       */
  REAL   epsabs,       /* Absolute Error Bound epsabs                 */
         epsrel,       /* Relative Error Bound epsrel                 */
         *xstep,       /* Initialize array for adaptive steps         */         
         *y0,          /* Function Value y0[0] at x0                  */
         h,            /* starting step size h                        */
         *y,           /* Array of y values corresponding to x values */
         *steps,       /* Total number of steps needed                */
         hmax,         /* maximum step size allowed                   */
         fmax;         /* maximal number of calls of right hand side  */
                       /* of DE in awp()                              */
  REAL*   yt = NULL;   /* temporary holding pointer                   */
  
long     aufrufe;      /* actual number of calls of r h side in awp() */
  
  int    n,
         fehler,         /* error code from awp()                     */
         neu,            /* use an outside given x                    */
         count,          /* Counter                                   */
         i,              /* loop counter                              */ 
         *nsteps,        /* Total number of steps needed              */
         k;              /* loop counter                              */
  
  double *xn,
          x0,
        xend;

  bsptyp *beispiel;      /* pointer to the structure describing the   */
                         /* problem at hand                           */
  void   *vmblock;       /* List of dynamic allocations               */
  bool   suppressOutput, /* Suppress Screen Output                    */
         singletonOutput;/* Output final solution y(xend)             */
  
  mwSize ncols;        /* Array Allocation Size                       */
  mwSize amax;         /* Array Allocation Size                       */
  
  /* MATLAB DATA */
  /* Check for proper number of arguments */
  if (nrhs != 11) {
    mexErrMsgIdAndTxt("MATLAB:mexcpp:nargin","BurlischMex requires eleven input arguments.");
  } else if (nlhs != 3) {
    mexErrMsgIdAndTxt("MATLAB:mexcpp:nargout","BurlischMex requires three output arguments.");
  }
  bspnummer = *mxGetPr(prhs[0]);
     epsabs = *mxGetPr(prhs[1]);
     epsrel = *mxGetPr(prhs[2]);
         y0 = mxGetPr(prhs[3]);
          h = *mxGetPr(prhs[4]);
       hmax = *mxGetPr(prhs[5]);
       fmax = *mxGetPr(prhs[6]);
       suppressOutput = mxGetScalar(prhs[7]);
         xn = mxGetPr(prhs[8]);
      ncols = mxGetN(prhs[8]);
       amax = *mxGetPr(prhs[9]);
       singletonOutput = mxGetScalar(prhs[10]);
      
      /* -------------------- read input data --------------------------- */
      if ((beispiel = dgls_waehlen(bspnummer)) == NULL) {
          printf("improper example number\n", 0, __FILE__, __LINE__);
          return;
      }
      count = -1;
      n = beispiel->n;
      vmblock = vminit();                           /* initialize storage */
      if (! vmcomplete(vmblock)) {
          printf("lack of memory", 0, __FILE__, __LINE__);
          return;
      }
      if (!singletonOutput)
      {
        plhs[0] = mxCreateDoubleMatrix(1, amax, mxREAL);
        plhs[1] = mxCreateDoubleMatrix(n, amax, mxREAL);
        plhs[2] = mxCreateDoubleMatrix(1, 1, mxREAL);
      }
      else
      {
        plhs[0] = mxCreateDoubleMatrix(1, 1, mxREAL);
        plhs[1] = mxCreateDoubleMatrix(n, 1, mxREAL);
        plhs[2] = mxCreateDoubleMatrix(1, 1, mxREAL);
      }
      xstep = mxGetPr(plhs[0]);
      y = mxGetPr(plhs[1]);
      steps = mxGetPr(plhs[2]);
      x0 = xn[0];
      xend = xn[1];
  /* ------------ print out input ----------------------------------- */
  if (!suppressOutput)
  {
  printf("\n"
         "Solution of a first order ordinary differential equations "
         "system\n"
         "=========================================================="
         "======\n"
         "using the extrapolation method of Bulirsch-Stoer-Gragg\n"
         "======================================================\n\n\n"
         "System of DEs:\n"
         "--------------\n"
         "%s\n\n"
         "Input data:\n"
         "-----------\n"
         "Example  = %24d\n"
         "n        = %24d\n"
         "x0       = %24.15"LZP"e\n"
         "xend     = %24.15"LZP"e\n"
         "epsabs   = %24.15"LZP"e\n"
         "epsrel   = %24.15"LZP"e\n"
         "fmax     = %24ld\n"
         "h        = %24.15"LZP"e\n"
         "hmax     = %24f\n",
         (*beispiel->dgl_text)(), bspnummer, n,x0,xend, epsabs, epsrel, fmax, h, hmax);
  for (i = 0; i < n; i++)
    printf("y0[%d]    = %24.15"LZP"e\n", i, y0[i]);
  }
  /* ------------ solve DE system ----------------------------------- */
 nsteps = new int;
 /* Assign values to yt in order to pass them to bul_stoe method      */
 yt = new REAL[n];
 for (i=0; i<n; i++)
     yt[i] = y0[i];
 fehler =  
         bul_stoe(&x0,xend,n,beispiel->rechte_seite,yt,epsabs,epsrel,&h,
         hmax,TRUE,fmax,&aufrufe,xstep,nsteps,y,&amax,singletonOutput);
 *steps = (double)*nsteps;
 x0 = xn[0];
 xend = xn[1];
 
 if (singletonOutput)
 {
     for (i = 0; i < n; i++)
        y[i] = yt[i];
     *xstep = (REAL)xend;
 }
  if (fehler != 0)
  {
    printf("Error in bul_stoe #%d\n", 10 + fehler);
    return;
  }
  /* -------------------- print results ----------------------------- */
   if (!suppressOutput)
  {
  printf("\n\n"
         "Output data:\n"
         "------------\n"
         "error code from bul_stoe():         %24d\n"
         "final step size:                    %24.15"LZP"e\n"
         "number of evaluations of r.h. side: %24ld\n"
         "Initial x-value x =                 %24.15"LZP"e\n"
         "final x-value x =                   %24.15"LZP"e\n\n",
         fehler, h, aufrufe, x0,xend);
  for (i = 0; i < n; i++)
    printf("approximate solution y%d(x) = %24.15"LZP"e\n",i + 1, yt[i]);
   }
 delete [] yt;  // When done, free memory pointed to by yt
 yt = NULL;     // Clear yt to prevent using invalid memory reference
 return;
}
