%%%%%%%%%%%%%%%%%%%%%%%%%% MEX GATEAWAY FUNCTION %%%%%%%%%%%%%%%%%%%%%%%%%%
%
% NSGA2 - Nondominated Sorting Genetic Algorithm II
%
% This function is a gateway to the NSGA-II C implementation, ver. 1.1
% For mor information about NSGA-II, visit the Kanpur Genetic Algorithms
% Laboratory website (http://www.iitk.ac.in/kangal/codes.shtml).
% This implementation has been done by N. Croisard, from the University of
% glasgow, UK.
%
% COMPILING
%   As any mex file are platform dependent, please recombile the mex
%   function before use by runing at Matlab prompt:
%       mex mexNsga2.c allocate.c auxiliary.c crossover.c crowddist.c
%               decode.c dominance.c eval.c fillnds.c initialize.c list.c
%               merge.c mutation.c problemdef.c rand.c rank.c report.c
%               sort.c tourselect.c -output nsga2 -DMEXCOMPILE
%
% PROTOTYPES
%	[bestPop,crossMut,finalPop] = nsga2(seed, popsize, ngen, nobj, ncon ...
%       nreal, bds_realvar, param_realvar, nbin, nbits, bds_binvar, ...
%       param_binvar, problem, param_problem, saveInFile);
%
% INPUTS
%	seed            Seed for the random number generation (0<seed<1)
%   popsize         Population size (a multiple of 4)
%	ngen            Number of generations
%	nobj            Number of objectives
%	ncon            Number of constraints
%	nreal           Number of real variables
%	bds_realvar     Boundaries of the real variables
%                   bds_realvar = [min_realvar; max_realvar] if nreal>0
%                               = [] otherwise.
%	param_realvar   Parameters for the real variables
%                   param_realvar = [pcross_real pmut_real eta_c eta_m]
%                                                                if nreal>0
%                                 = [] otherwise
%	nbin            Number of discrete variables
%	nbits           Number of bits for each discrete variable (vector of nbin
%                   elements if nbin>1, [] otherwise)
%	bds_binvar      Boundaries of the discrete variables
%                   bds_binvar = [min_binvar; max_binvar] if nbin>0
%				               = [] otherwise.
%	param_binvar    Parameters for the discrete variables
%                   param_binvar = [pcross_bin pmut_bin] if nbin>0
%					             = [] otherwise
%	problem         String containing the name of the M-file computing the
%                   objectives and constrains.
%	param_problem   List of parameters required to evaluate the objectives
%                   and constrains. If none necessary, pass {}
%	saveInFile      Optional input
%                   1 if output files required
%			        0 otherwise (default)
%
% OUTPUTS
%	bestPop         Matrix of the best population if found. Each row
%                   corresponds to a non dominated feasible solution. The
%                   columns are as follow: objectives, constrains, real
%                   variables, binary variables, constrain violation, rank,
%                   crowd distance.
%	crossMut        Number of crossover mutation for the real and binary
%                   variables.
%                       crossMut = [nrealcross nrealmut nbincross nbinmut]
%                       If nreal = 0, nrealcross and nrealmut are NaN.
%                       If nbin = 0, nbincross and nbinmut are NaN.
%	finalPop        Matrix of the final population found. Each row
%                   corresponds to a non dominated feasible solution. The
%                   columns are as follow: objectives, constrains, real
%                   variables, binary variables, constrain violation, rank,
%                   crowd distance.
%
% FORMAT OF PROBLEM M-FILE
%   This implementation accept a fixed format for the M-file containing the
%   problem to be solved (problem input):
%   1/ It must accept 3 inputs: xreal (vector of the real variables), xbin
%      (vector of the binary variables, not the bites) and param (list of
%      optional parameters the problem function may need)
%   2/ It must return 2 outputs: obj (vector of the objectives) and constr
%   (vector of the constrains, can be empty).
%
% EXAMPLES
%	Along with this code, 24 examples of problems are provided as
%	M-files (bnh, fon, sch1, sch2, zdt5, etc). Look at their help for
%	more information and examples on how to call nsga2.
%
% REFERENCES
%   "A Fast and Elitist multi-objective Genetic Algorithm: NSGA-II", Dr.
%   Kalyanmoy Deb, Sameer Agrawal, Amrit Pratap, T Meyarivan, IEEE
%   Transactions on Evolutionary Computation (IEEE-TEC), 2002, 6-2,
%   pp182-197
%
% AUTHOR OF THE MEX IMPLEMENTATION
%   Nicolas Croisard, 18/02/2009
%   University of Glasgow
%   (n.croisard@aero.gla.ac.uk)
%
% CHANGELOG
%	See file Revision.