function [obj,constr] = zdt5(xreal,xbin,param)
%  Test problem ZDT5
%    # of real variables = 0
%    # of bin variables = 11
%    # of bits for binvar1 = 30
%    # of bits for binvar2-11 = 5
%    # of objectives = 2
%    # of constraints = 0
%
% To solve it using the mex implementation of NSGA2 ver 1.1, run in matlab
% [bestPop,crossMut,finalPop] = nsga2(0.5,100,300,2,0,...
%       0,[],[],11,[30 5*ones(1,10)],[0 zeros(1,10); 30 5*ones(1,10)],...
%       [0.9 0.0125],'zdt5',{[30 5*ones(1,10)],...
%       [0 zeros(1,10); 30 5*ones(1,10)]});
%
% Nicolas Croisard (2009)

% Manage parameters
nbits = param{1};
bounds = param{2};
min_binvar = bounds(1,:);
max_binvar = bounds(2,:);

% Number of variables
nvar = numel(xbin);

% Compute the genes based on the xbin values
gene = cell(1,nvar);
sigma = (xbin-min_binvar).*(2.^nbits-1)./(max_binvar-min_binvar);
for i=1:nvar
    gene{i} = rem(floor(sigma(i)*pow2(1-nbits(i):0)),2);
end


% Compute the 2 objectives
u = zeros(1,nvar);
for i=1:nvar, u(i) = sum(gene{i}); end

v = ones(1,nvar-1);
for i=2:nvar
    if u(i)<5, v(i-1) = 2 + u(i); end
end

obj = [1 + u(1);
       sum(v)/(1+u(1))];
constr = [];
end