function [V] = CometPhotoModel_t(DT, kepComet, kepEarth, HNucleus)
%--------------------------------------------------------------------------
% constants
muSun = astroConstants(4);
AU    = astroConstants(2);
G     = 0.41;  % according to "Michael Weiler, Heike Rauer, Christiaan Sterken.
%   Cometary Nuclear Magnitudes from Sky Survey Observations.
%   Icarus, Elsevier, 2011, 212 (1), pp.351.
%   <10.1016/j.icarus.2010.12.026>."
%--------------------------------------------------------------------------

% Earth Position
smaE = kepEarth(1)*AU;
[fEDep,errorflag] = kepEq_f(DT*86400, smaE, kepEarth(2), muSun, kepEarth(6), 0);
if errorflag ~= 0
    error
end
outE = kep2car([kepEarth(1)*AU  kepEarth(2:5) fEDep],muSun);

% Comet Position
outComet = kep2car([kepComet(1)*AU kepComet(2:6)],muSun);
F = @(t,x) [x(4); %dx/dt=Vx
            x(5); %dy/dt=Vy
            x(6); %dz/dt=Vz
            -muSun*x(1)/(sqrt(x(1)^2+x(2)^2+x(3)^2)^3);
            -muSun*x(2)/(sqrt(x(1)^2+x(2)^2+x(3)^2)^3);
            -muSun*x(3)/(sqrt(x(1)^2+x(2)^2+x(3)^2)^3)];
options = odeset('RelTol',1e-6,'AbsTol',1e-7,'Refine',50);
if DT ~= 0
    [~, XC2FB] = ode45(F,[0 DT*86400],outComet, options);
    XC2FB      = XC2FB(end,:);
else
    XC2FB = outComet;
end

%--------------------------------------------------------------------------

rCom = XC2FB(1:3)/AU;
rE   = outE(1:3)/AU;
rho  = rCom - rE; % Vector

ComToSun       = norm(rCom);
RangeTelescope = norm(rho);

%--------------------------------------------------------------------------
% 3. Bowell model for apparent magnitude of the asteroid
solarPhase = acos((rho*rCom')/RangeTelescope/ComToSun);
Phi        = ((1-G)*exp(-3.33*(tan(solarPhase/2)).^0.63) + G*exp(-1.87*(tan(solarPhase/2)).^1.22));
V          = HNucleus+5*log10(RangeTelescope*ComToSun) - 2.5*log10(Phi);
%--------------------------------------------------------------------------

end

