function [LEGSn, VASn] = wrap_DynProgr_st2(INPUT, n, EPH, LEGS, VAS)

Nasts           = INPUT.astMax;
MAT             = INPUT.MAT;
OptionsMultiRev = INPUT.OptionsMultiRev;
tols            = INPUT.tols;
soltokeep       = INPUT.soltokeep;

fprintf('Leg # %d \n', n);

states = findNextStates(n-1, Nasts, MAT, LEGS );

if INPUT.parallel == 1 % --> use parallel

    parfor idc = 1:size(states,1)
    
        as1 = states(idc,1);
        as2 = states(idc,2);

        indxs   = find(LEGS(:,end) == as1);
        legprev = LEGS(indxs,:);
        vasprev = VAS(indxs,:);

        dv  = zeros(size(legprev,1),1);
        vvf = zeros(size(legprev,1),3);
        for indlp = 1:size(legprev,1)
            vvin = vasprev(indlp,:);
            [dv(indlp,:), vvf(indlp,:)] = nextLegs_Seqs_v2(as1, vvin, as2, EPH, OptionsMultiRev);        
        end
        legn = [ legprev [dv as2.*ones(size(dv,1),1)]];

        % --> apply the pruning
        indxs          = find(legn(:,end-1) > tols(3));
        legn(indxs,:)  = [];
        vvf(indxs,:)   = [];
        
        costTOT        = DVseq(legn);
        indxs          = find(costTOT > tols(end));
        legn(indxs,:)  = [];
        vvf(indxs,:)   = [];

        if ~isempty(legn)

            if n == INPUT.astMax % --> KEEP ALL
                structosav(idc,:).LEGSn = legn;
                structosav(idc,:).VASn  = vvf;
            else % --> APPLY DP
                costTOTn = sortrows([ DVseq(legn) [1:size(legn,1)]' ], 1);
                if size(costTOTn,1) > soltokeep
                    costTOTn = costTOTn(1:soltokeep,:);
                end
                row = costTOTn(:,2);
    
                % --> save the next leg
                structosav(idc,:).LEGSn = legn(row,:);
                structosav(idc,:).VASn  = vvf(row,:);
            end

        end

    end

else % --> do not use parallel
    
    for idc = 1:size(states,1)
    
        idc/size(states,1)*100

        as1 = states(idc,1);
        as2 = states(idc,2);

        indxs   = find(LEGS(:,end) == as1);
        legprev = LEGS(indxs,:);
        vasprev = VAS(indxs,:);

        dv  = zeros(size(legprev,1),1);
        vvf = zeros(size(legprev,1),3);
        for indlp = 1:size(legprev,1)
            vvin = vasprev(indlp,:);
            [dv(indlp,:), vvf(indlp,:)] = nextLegs_Seqs_v2(as1, vvin, as2, EPH, OptionsMultiRev);        
        end
        legn = [ legprev [dv as2.*ones(size(dv,1),1)]];

        % --> apply the pruning
        indxs          = find(legn(:,end-1) > tols(3));
        legn(indxs,:)  = [];
        vvf(indxs,:)   = [];
        
        costTOT        = DVseq(legn);
        indxs          = find(costTOT > tols(end));
        legn(indxs,:)  = [];
        vvf(indxs,:)   = [];

        if ~isempty(legn)

            if n == INPUT.astMax % --> KEEP ALL
                structosav(idc,:).LEGSn = legn;
                structosav(idc,:).VASn  = vvf;
            else % --> APPLY DP
                costTOTn = sortrows([ DVseq(legn) [1:size(legn,1)]' ], 1);
                if size(costTOTn,1) > soltokeep
                    costTOTn = costTOTn(1:soltokeep,:);
                end
                row = costTOTn(:,2);
    
                % --> save the next leg
                structosav(idc,:).LEGSn = legn(row,:);
                structosav(idc,:).VASn  = vvf(row,:);
            end

        end
        

    end

end

try
    LEGSn = cell2mat({structosav.LEGSn}');
    VASn  = cell2mat({structosav.VASn}');
catch
    LEGSn = [];
    VASn  = [];
end

% --> apply pruning on the cost of the sequence (not considering the vinf at the Earth)
if ~isempty(LEGSn)
    indxs           = find(LEGSn(:,end-1) > tols(3));
    LEGSn(indxs,:)  = [];
    VASn(indxs,:)   = [];
end

% --> apply pruning on the total cost of the sequence
if ~isempty(LEGSn)
    costTOT         = DVseq(LEGSn);
    indxs           = find(costTOT > tols(end));
    LEGSn(indxs,:)  = [];
    VASn(indxs,:)   = [];
end

if ~isempty(LEGSn)
    indxs          = find(LEGSn(:,1) == 0);
    LEGSn(indxs,:) = [];
    VASn(indxs,:)  = [];
end

end
