function [LEGSnext, VASnext, rownext, PROBnext] = ...
    computeNextNode_ACO(LEGSnext, VASnext, visited, alpha, beta, beam, p0)

% --> CHANGE IT to a proper BEAM-ACO :
%     --> p0 --> is the probability that the branches are computed
%     deterministically (p0) or stochastically (1-p0) (--> biased sampling
%     without replacement)
%     • if p0=1                     --> then the searh is purely
%     deterministic (both pheromone and heuristic considered)
%     • if alpha=0                  --> then the search is only stochastic
%     BS (only heuristic considered)
%     • if p0=1 U alpha=0           --> then the search is the deterministic BS
%     • if BW=1 U p0=0              --> then the search is the standard ACO
%     • if p0~=1 U p0~=0 U alpha~=0 --> then the search is BEAM-ACO

% --> compute probability of choosing the next node
HEURnext = computeHeuristic_ACO(LEGSnext);             % --> compute heuristic to next nodes (1/DV)
PHERnext = computePheromone_ACO(LEGSnext, visited);    % --> compute the pheromone to next nodes
PROBnext = (PHERnext.^alpha).*(HEURnext.^beta);        % --> probability to choose next node
PROBnext = PROBnext./sum(PROBnext);

% dn   = [DVtot [1:1:size(DVtot,1)]'];
% dn   = [dn PROBnext LEGSnext(:,end)];
% dn    = sortrows(dn,1,'ascend');

data_DS        = [1 2]; % --> 1: deterministic; 2: stochastic
data_DS_weight = [p0 (1-p0)];
data_DS_sam    = datasample(data_DS, 1, 'Weights', data_DS_weight, 'Replace', false);

pn    = [PROBnext [1:1:size(PROBnext,1)]'];
pn    = sortrows(pn,1,'descend');
if beam >= size(LEGSnext,1)
    temp_beam = size(LEGSnext,1);
else
    temp_beam = beam;
end

if data_DS_sam == 1 % --> deterministic branching
    rownext = pn(1:temp_beam,2);
else % --> stochastic branching
    data    = [1:1:size(PROBnext,1)]';
    datas   = datasample(data, temp_beam, 'Weights', pn(:,1), 'Replace', false);
    rownext = pn(datas(:,1), 2);
end

% --> choose the next node
LEGSnext = LEGSnext(rownext,:); 
VASnext  = VASnext(rownext,:);  
% LEGS = LEGSnext;
% VAS = VASnext;

end