function [OUTPUT] = wrap_BEAM_ACO(INPUT, indrun, folder)

% --> load the INPUT
if nargin == 1
    indrun = 1;
    folder = '\results_BS_ACO';
elseif nargin == 2
    folder = '\results_BS_ACO';
elseif nargin == 3
    if isempty(folder)
        folder = '\results_BS_ACO';
    end
end

% --> load the INPUT
astLISTe = INPUT.astLISTe;
EPH      = INPUT.EPH;
tols     = INPUT.tols;
visited  = INPUT.visited;
alpha    = INPUT.alpha;
beta     = INPUT.beta;
Q        = INPUT.Q;
rho      = INPUT.rho;
beam     = INPUT.beam;
p0       = INPUT.p0;
itermax  = INPUT.itermax;
nants    = INPUT.nants;
astMax   = INPUT.astMax;

% --> remove Earth and Mars from the catalogue
astLIST                    = astLISTe(2:end,:);
astlist                    = astLIST;
astlist(astlist(:,1)==4,:) = [];

% --> first legs of the transfer
[LEGSi, VASi] = firstLegs_BS_v2(astLISTe, EPH, tols);
[LEGSi, VASi] = computeNextNode_ACO(LEGSi, VASi, visited, alpha, beta, beam, p0);

% --> START : ACO algorithm <--
totr = itermax*nants;
SOLUTIONS_ACO = struct('iter', cell(totr,1), 'ant', cell(totr,1), 'Tour', cell(totr,1),...
    'cost', cell(totr,1), 'LEGS', cell(totr,1), 'costs', cell(totr,1),...
    'N_ASTS', cell(totr,1), 'PROB', cell(totr,1));
indp = 1;
for iter = 1:itermax
    
    iter

    % --> release the colony
    ant = [];
    parfor k = 1:nants
        
        % --> the ant constructs a tour
        [LEGS, cost, triplets, N_ASTS, PROBABILITY] = antDownTheTree_ACO(LEGSi, VASi, astlist,...
            EPH, tols, astMax, visited, alpha, beta, beam, p0);

        % --> use the best to update the pheromone
        min_cost = min(cost);
        dtauij   = Q/min_cost;

        ant(k).Tour     = LEGS;     % --> tour
        ant(k).cost     = min_cost; % --> cost of the tour
        ant(k).triplets = triplets; % --> triplets
        ant(k).dtauij   = dtauij;   % --> dtauij
        ant(k).LEGS     = LEGS;
        ant(k).costs    = cost;
        ant(k).N_ASTS   = N_ASTS;
        ant(k).PROB     = PROBABILITY;

    end

    % --> save ACO solutions
    [sols_aco_temp] = saveSolutions_ACO(nants, ant, iter);
    SOLUTIONS_ACO(indp:indp-1+nants) = sols_aco_temp;
    indp = indp + nants;
    
    % --> update the pheromone
    [visited] = updatePheromone(ant, rho, visited);

end
% --> END : ACO algorithm <--

% --> post-process the solutions
[SOLUTIONS_ACO, dv_iter] = postProcessSOLUTIONS_ACO(SOLUTIONS_ACO, itermax);

% --> save the OUTPUT
OUTPUT.SOLUTIONS = SOLUTIONS_ACO;
OUTPUT.dv_iter   = dv_iter;

% --> save the results
if exist(folder(2:end), 'dir') == 7 % --> then the folder exists on the current path
    name2 = [folder '\OUTPUT_BS_ACO' '_run_' num2str(indrun) '.mat'];
else % --> then the folder does not exist on the current path
    mkdir(folder(2:end)); % --> create the folder in the current path
    name2 = [folder '\OUTPUT_BS_ACO' '_run_' num2str(indrun) '.mat'];
end
name  = [pwd name2];
save(name, 'OUTPUT');

end