function [dv, dvSplit]=Transfer_CASTAway_MarsSW_SeqMR(Sequence, Times)
% Sequenceuence - defines the asteroids to be visited in [index+11] type
% Times - defines the times for the fly by
%--------------------------------------------------------------------------
% Initialization
%  ephNEO('load','GTOC7ASTEROIDS.txt');
muSun = astroConstants(4);
muMars=astroConstants(14);
% smaMars=227940540.039744; If not used, please remove.
RMars=3389.92;
%--------------------------------------------------------------------------
% Spacecraft Model mi = 1500; % 1500 kg wet mass, similar to Marco Polo
% (and M class candidate) Isp = 350; % Standard Number. ve =
% Isp*astroConstants(6);
%--------------------------------------------------------------------------
nFB = length(Sequence);
dvSplit=zeros(1,nFB-1);

Vsc_Asteroid=NaN(nFB,3);
vInf = 0; %km/s
dv = 0; %km/s
%--------------------------------------------------------------------------
for iFB=1:nFB-1
    
    % Departure
    [r1, v1] = EphSS_car(Sequence(iFB), Times(iFB)); % Departure
    
    % Arrival
    [r2, ~] = EphSS_car(Sequence(iFB+1), Times(iFB+1)); % Arrival
    
    % Understanding maximum number of revolutions
    tof_days=(Times(iFB+1)-Times(iFB));
    sma_min=1/4*(norm(r1)+norm(r2)+norm(r2-r1));
    P_min_days=2*pi*sqrt(sma_min^3/muSun)/3600/24;
    NumRevMax=floor(tof_days/P_min_days);
    
    OptionsMultiRev=[0 0; 1 0; 1 1; 2 0; 2 1; 3 0; 3 1];
%     OptionsMultiRev=[0 0];
    indexDel=find(OptionsMultiRev(:,1)>NumRevMax);
    OptionsMultiRev(indexDel,:)=[];
    % Initializing Store Matrices
    dvTemp=zeros(1,length(OptionsMultiRev(:,1)));
    VelocitiesDep=zeros(length(OptionsMultiRev(:,1)),3);
    VelocitiesArr=zeros(length(OptionsMultiRev(:,1)),3);
    
    for iO=1:length(OptionsMultiRev(:,1))
        
        multirev = OptionsMultiRev(iO,1);
        energy =  OptionsMultiRev(iO,2);
        
        [~, ~, ~, error, vI, vF, ~, ~] = ...
            lambertMR(r1, r2, tof_days*86400, muSun, 0, multirev, energy, 0);
        
        if error==0
            VelocitiesDep(iO,:)=vI;
            VelocitiesArr(iO,:)=vF;
            % Results Transfers
            if Sequence(iFB)==3 % departure conditions from Earth
                dvTemp(iO) = (norm(vI-v1)-vInf)*(norm(vI-v1)-vInf>=0);
            elseif Sequence(iFB)==4 % Mars FB as DV defect
                %--------------------------------------------------------------------------
                % Applying SwingBy Manoeuvre at Mars Mars Swing-by
                VArr2Mars=Vsc_Asteroid(iFB,:);
                vinf1=VArr2Mars-v1; vinf1_mod=norm(vinf1);
                VDep2Mars=VelocitiesDep(iO,:);
                vinf2=VDep2Mars-v1; vinf2_mod=norm(vinf2);
                
                % Deflection Necessary for this fly-by
                delta = acos(dot(vinf1, vinf2) / (vinf1_mod*vinf2_mod));
                            
                rpFB_min=RMars+250; % minimum altitude allowed for a mars FB
                delta_max = 2*asin(1/(1 + (rpFB_min*vinf1_mod^2/muMars)));
                if delta <= delta_max
                    dvTemp(iO) = norm(vinf2_mod - vinf1_mod);
                else
                    dvTemp(iO) = sqrt(vinf2_mod^2 + vinf1_mod^2 - 2*vinf2_mod*vinf1_mod * cos(delta-delta_max));
                end
                %--------------------------------------------------------------------------
            else
                dvTemp(iO) = norm(vI-Vsc_Asteroid(iFB,:));
            end
        else
            dvTemp(iO) = 99;
            VelocitiesDep(iO,:)=[1e99 1e99 1e99];
            VelocitiesArr(iO,:)=[1e99 1e99 1e99];
        end
    end
    [~,bestOption]=min(dvTemp);
    % Results Transfers
    dv = dvTemp(bestOption)+dv;
    dvSplit(iFB)=dvTemp(bestOption);
    Vsc_Asteroid(iFB+1,:)=VelocitiesArr(bestOption,:);
end
end


