function [dv, dvSplit]=Transfer_CASTAway_MultiRev_MarsSW(Sequence, Times)
% Sequence - defines the asteroids to be visited in [index+11] type
% Times - defines the times for the fly by
%--------------------------------------------------------------------------
% Initialization
%  ephNEO('load','GTOC7ASTEROIDS.txt');
muSun = astroConstants(4);
muMars=getAstroConstants('Mars','Mu');
smaMars=getAstroConstants('Mars','Sma');
RMars=getAstroConstants('Mars','Radius');
%--------------------------------------------------------------------------
% Spacecraft Model
mi = 1500; % 1500 kg wet mass, similar to Marco Polo (and M class candidate)
Isp = 350; % Standard Number.
ve = Isp*astroConstants(6);
%--------------------------------------------------------------------------
nFB = length(Sequence);
dvSplit=zeros(1,nFB-1);
%--------------------------------------------------------------------------
% Launch Model

t0 = Times(1); % 1/1/2029
t1 = Times(2); % 31/12/2030

% Earth Launch with Soyuz-Fregat-like

vInf = 0; %km/s

%--------------------------------------------------------------------------
% Initial Tranfer Guess

Seq=Sequence;

% timeLaunch =tW(1)+(tW(2)-tW(1))*rand;
%
%        ToF = 365; %[days]

%--------------------------------------------------------------------------
% Lambert Arc Generation
%     mass = mi;
% Departure
[sE(1:3), sE(4:6)] = EphSS_car(Seq(1), t0); % Departure

% Arrival
[sA(1:3), sA(4:6)] = EphSS_car(Seq(2), t1); % Arrival
% Multi-Rev: 0 rev
%--------------------------------------------------------------------------
% OLD single revolution part
% % Options
% multirev = 0;
% energy = 0;
% [A, P, E, error, vI, vF, TPAR, THETA] = ...
%     lambertMR(sE(1:3), sA(1:3), (t1-t0)*86400, muSun, 0, multirev, energy, 0);
% 
% % Results Transfers
% dv = (norm(vI-sE(4:6))-vInf)*(norm(vI-sE(4:6))-vInf>=0);
% dvSplit(1)=dv;
%--------------------------------------------------------------------------
% New Multi revolution part (27/01/2017)
OptionsMultiRev=[0 0; 1 0; 1 1];
dv=zeros(1,length(OptionsMultiRev(:,1)));
VelocitiesDep=zeros(length(OptionsMultiRev(:,1)),3);
VelocitiesArr=zeros(length(OptionsMultiRev(:,1)),3);
for iO=1:length(OptionsMultiRev(:,1)) 
    multirev = OptionsMultiRev(iO,1);
    energy =  OptionsMultiRev(iO,2);
    
    [A, P, E, error, vI, vF, TPAR, THETA] = ...
        lambertMR(sE(1:3), sA(1:3), (t1-t0)*86400, muSun, 0, multirev, energy, 0);
    
    if error==0
        VelocitiesDep(iO,:)=[vI];
        VelocitiesArr(iO,:)=[vF];
        % Results Transfers
        dv(iO) = (norm(vI-sE(4:6))-vInf)*(norm(vI-sE(4:6))-vInf>=0);    
    else
        dv(iO) = 99;
    end
end
[dvMin,indexMin]=min(dv);
% Results Transfers
dv = dvMin;
dvSplit(1)=dv;
vI=VelocitiesDep(indexMin,:);
vF=VelocitiesArr(indexMin,:);
%--------------------------------------------------------------------------
% Applying SwingBy Manoeuvre at Mars
    % Mars Swing-by
    VArr2Mars=vF;
    vinf1=VArr2Mars-sA(4:6);
    
    % As Rosetta, CASTAway should aim at a 250 km altitude fly-by as a maximum
    % close encounter.
    rpFB=RMars+250;
    
    n_r=cross(vinf1,sA(4:6)); % Reference vector
    n_r=n_r/norm(n_r);
    
    gamma=0;
    
    vinf2 = swingby(vinf1,rpFB,muMars,gamma,n_r)';
    
    vDepSW_mars=vinf2+sA(4:6);
    
    %--------------------------------------------------------------------------
    % Departure conditions after Mars Swing By
    svDepSW_mars=[sA(1:3) vDepSW_mars];   
    kepDepSW_mars=car2kep(svDepSW_mars,muSun);
%     kepDepSW_mars(1)=kepDepSW_mars(1)/AU; 
%--------------------------------------------------------------------------
% Checking Spacecraft period for next leg
P_SC = 2*pi*sqrt(kepDepSW_mars(1)^3/muSun)/3600/24;
%--------------------------------------------------------------------------
% The rest of the legs
vI=zeros(5,3);vF=zeros(5,3);dvP=99*ones(1,5);
if  nFB>2
    for iFB=2:nFB-1
        if (Times(iFB+1)-Times(iFB))>0
            % Departure
            [sA(1:3), sA(4:6)] = EphSS_car(Seq(iFB), Times(iFB)); % Departure
            
            % Arrival
            [sA2(1:3), sA2(4:6)] = EphSS_car(Seq(iFB+1), Times(iFB+1)); % Arrival
            %--------------------------------------------------------------------------
            % Options
            multirev = 0;
            energy = 0;
            [A, P, E, error, vI(1,:), vF(1,:), TPAR, THETA] = ...
                lambertMR(sA(1:3), sA2(1:3), (Times(iFB+1)-Times(iFB))*86400, muSun, 0, multirev, energy, 0);
            dvP(1) = norm(vI(1,:)-vDepSW_mars);
            
            if  (Times(iFB+1)-Times(iFB))>0.9*P_SC
                % Multi-Rev: 1 rev
                % Options
                multirev = 1;
                energy = 0;
                [A, P, E, error, vI(2,:), vF(2,:), TPAR, THETA] = ...
                    lambertMR(sA(1:3), sA2(1:3), (Times(iFB+1)-Times(iFB))*86400, muSun, 0, multirev, energy, 0);
                dvP(2) = norm(vI(2,:)-vDepSW_mars);
                
                % Options
                multirev = 1;
                energy = 1;
                [A, P, E, error, vI(3,:), vF(3,:), TPAR, THETA] = ...
                    lambertMR(sA(1:3), sA2(1:3), (Times(iFB+1)-Times(iFB))*86400, muSun, 0, multirev, energy, 0);
                
                % Results Transfers
                dvP(3) = norm(vI(3,:)-vDepSW_mars);
            end
            if  (Times(iFB+1)-Times(iFB))>0.9*2*P_SC
                % Multi-Rev: 1 rev
                % Options
                multirev = 2;
                energy = 0;
                [A, P, E, error, vI(4,:), vF(4,:), TPAR, THETA] = ...
                    lambertMR(sA(1:3), sA2(1:3), (Times(iFB+1)-Times(iFB))*86400, muSun, 0, multirev, energy, 0);
                dvP(4) = norm(vI(4,:)-vDepSW_mars);
                
                % Options
                multirev = 2;
                energy = 1;
                [A, P, E, error, vI(5,:), vF(5,:), TPAR, THETA] = ...
                    lambertMR(sA(1:3), sA2(1:3), (Times(iFB+1)-Times(iFB))*86400, muSun, 0, multirev, energy, 0);
                
                % Results Transfers
                dvP(5) = norm(vI(5,:)-vDepSW_mars);
            end
            %--------------------------------------------------------------------------
            % Checking best option
            [dvMin,indmin]=min(dvP);
            % Results Transfers
            dv = norm(vI(indmin,:)-vDepSW_mars)+dv;
            dvSplit(iFB)=norm(vI(indmin,:)-vDepSW_mars);
            vDepSW_mars=vF(indmin);
        else
            dv = 99;
            dvSplit(iFB)=99;
            return
        end
        %--------------------------------------------------------------------------
    end
end

end
