%{
FUNCTION: SimilarityMeasure.m
---------------------------------------------------------------------------
IRP
17/05/2021

Maria Carrillo Barrenechea
Student ID: s334328
---------------------------------------------------------------------------
----------------------------Similarity Measure-----------------------------
---------------------------------------------------------------------------
DESCRIPTION:
This function gives a similarity score for given sequences of asteroids. It
takes into account two similarities:
    - asteroid by asteroid similarity
    - subsequences similarity
Each of the scores are pondered by a user input weight.

INPUTS:
    - Ast_Solutions:    Matrix containing the asteroid sequences to compare
    - n_asteroids:      Number of asteroids in the asteroid sequences,
                        normally called CurrentSearch

OUTPUTS:
    - sim_score_ast:        Score corresponding to asteroid by asteroid
                            similarity
    - sim_score_ast_subseq: Score corresponding to subsequences similarity
    - sim_num_ast_subseq:   Number of subsequences that are repeated in the
                            solutions
%}

function [simScoreTot, sim_score_ast, sim_score_ast_subseq, sim_num_ast_subseq] = SimilarityMeasure_def(Ast_Solutions, n_asteroids)

%% User inputs
sim_score_ast_weight = 1;
sim_score_ast_subseq_weight = 1;

%% Initialisation

% Check if Earth is also included in the solutions and remove it
if size(Ast_Solutions,2) > n_asteroids
    if all(Ast_Solutions(:,1) == 0)
        Ast_Solutions = Ast_Solutions(:,2:end);
    else
        warning('The number of asteroids does not match the Asteroid Solutions length.')
    end
end

n_solutions     = length(Ast_Solutions(:,1));
sim_score_ast   = 0;
% sim_score_ToF   = 0;
% sim_score_dist	= 0;
sim_score_ast_subseq = 0;
sim_num_ast_subseq = 0;

% ToF_seq         = zeros(1, n_solutions);
% ToF_seq_prev    = 0;
% ToF_ast_prev    = t0;

% j_ast = 4;  % Initialise the asteroid index


%% Loop

for i_seq = 1:(n_solutions-1)   % TODO: take into account last one for ToF and distance
    
    for j_seq = i_seq+1:n_solutions
        j_ast = 1;  % Initialise the asteroid index
        % Checking
%         if sim_score_ast_subseq_aux ~= 0
%             disp(['Total score of this sequence is ', num2str(sim_score_ast_subseq_aux)])
%         end
        prev_equal = false;
        sim_score_ast_subseq_aux = 0; % Checking 2
        for i_ast = 1:n_asteroids
%             ToF_ast_act  = MatrixSummary_BC(Ast_Solutions(i_seq, i_ast),4);   % 4: Time: epoch at which asteroid is at MOID point
%             ToF_seq_act  = ToF_ast_act - ToF_ast_prev + ToF_seq_prev;
%             ToF_ast_prev = ToF_ast_act;
%             ToF_seq_prev = ToF_seq_act;
            % Check if an index is equal
            while i_ast <= n_asteroids && j_ast <= n_asteroids
                if Ast_Solutions(j_seq, j_ast) <= Ast_Solutions(i_seq, i_ast)
                    if Ast_Solutions(i_seq, i_ast) == Ast_Solutions(j_seq, j_ast)
                        sim_score_ast = sim_score_ast + 1;
                        % Checking 1
%                         disp(['Index ' num2str(i_ast) ' of sequence ' num2str(i_seq) ' equals index ' num2str(j_ast) ' of sequence ' num2str(j_seq)])
%                     else
%                         MatrixSummary_BC(i_ast, 4);  % 4: Time: epoch at which asteroid is at MOID point
%                         MatrixSummary_BC(i_ast, 6);  % 6: distance to asteroid
                        if prev_equal
                            sim_score_ast_subseq = sim_score_ast_subseq + 1;
                            % Checking 2
                            sim_score_ast_subseq_aux = sim_score_ast_subseq_aux + 1;
                            if sim_score_ast_subseq_aux == 1
                                sim_num_ast_subseq = sim_num_ast_subseq + 1;
                            end
%                             disp(['Index ' num2str(i_ast) ' of sequence ' num2str(i_seq) ' equals index ' num2str(j_ast) ' of sequence ' num2str(j_seq)])
                        else
                            prev_equal = true;
                        end
                    else
                        prev_equal = false;
                    end
                    j_ast = j_ast + 1;
                else
                    break
                end
            end
        end         
    end
%     ToF_seq(i_seq) = ToF_seq_act;
end

% Checking 2
% disp(['The asteroid subsequence score is ', num2str(sim_score_ast_subseq)])

% i_seq = n_solutions;
% for i_ast = 4:n_asteroids+3
%     ToF_ast_act  = MatrixSummary_BC(Ast_Solutions(i_seq, i_ast),4);   % 4: Time: epoch at which asteroid is at MOID point
%     ToF_seq_act  = ToF_ast_act - ToF_ast_prev + ToF_seq_prev;
%     ToF_ast_prev = ToF_ast_act;
%     ToF_seq_prev = ToF_seq_act;
% end
% ToF_seq(i_seq) = ToF_seq_act;

% Applying weight parameters to score
sim_score_ast        = sim_score_ast_weight * sim_score_ast;
sim_score_ast_subseq = sim_score_ast_subseq_weight * sim_score_ast_subseq;
simScoreTot          = sim_score_ast + sim_score_ast_subseq;


end

