function [OUTPUT] = wrapSim(SOLS, ind, seq1, nsols, folder)

% This function computes the similarity measure of one sequence w.r.t.
% all the other sequences in a set.
%
% INPUT :
% - SOLS : matrix containing the set of solutions
% - seq1 : sequence to compare
% - folder : specify the folder where you want the results
%
% OUTPUT :
% - structure containing the following information:
%   --> simScoreTot   : vector of similarity scores of the input sequence
%                       w.r.t. all the other solutions in the set
%   --> seqScores     : sum(simScoreTot)
%   --> seqScoresNorm : seqScores./nsols
%   --> ind           : row index of seq1 in SOLS
%
% -------------------------------------------------------------------------

MAT_sols        = SOLS;
MAT_sols(ind,:) = [];

simScoreTot = zeros(size(MAT_sols,1),1);
for inds = 1:size(MAT_sols,1)
    seq2 = MAT_sols(inds,:);
    [simScoreTot(inds,:)] = similarityMeasure_seqs(seq1, seq2);
end
seqScores     = sum(simScoreTot);
seqScoresNorm = seqScores./nsols;

OUTPUT.simScoreTot   = simScoreTot;
OUTPUT.seqScores     = seqScores;
OUTPUT.seqScoresNorm = seqScoresNorm;
OUTPUT.ind           = ind;

% --> save the results --> create the folder for saving the results
if nargin > 4 && ~isempty(folder) % --> then the folder is specified
    if exist(folder(2:end), 'dir') == 7 % --> then the folder exists on the current path
        name2 = [folder '\OUTPUT_' num2str(ind) '.mat'];
    else % --> then the folder does not exist on the current path
        mkdir(folder(2:end)); % --> create the folder in the current path
        name2 = [folder '\OUTPUT_' num2str(ind) '.mat'];
    end
else % --> then the folder is not specified --> save in '\results'
    if exist('results', 'dir') == 7 % --> then the folder '\results' exists on the current path
        name2 = ['\results\OUTPUT_' num2str(ind) '.mat'];
    else % --> then the folder '\results' does not exist on the current path
        mkdir('results');
        name2 = ['\results\OUTPUT_' num2str(ind) '.mat'];
    end
end
name    = [pwd name2];
save(name, 'OUTPUT');

end
