function [SOL] = wrap_Bellman(INPUT, folder, folder2)

% --> extract INPUT
as1      = INPUT.as1;
as2      = INPUT.as2;
idm      = INPUT.idm;
astMax   = INPUT.astMax;
astLISTe = INPUT.astLISTe;
EPH      = INPUT.EPH;
tols     = INPUT.tols;
bw       = INPUT.bw;
indc     = INPUT.indc;

% --> solve the Lambert problem between two asteroids
[~, vva2] = lambertAsteroids(as1, as2, EPH);

% --> check if better to expand first BACKWARD or FORWARD
astlist = astLISTe(2:end,:);
nasts   = length(astlist);
id1     = find(astlist == as1);
nastmid = floor(nasts/2);
if id1 < nastmid % --> first expand BACKWARD
    bf = 1;
else
    bf = 2; % --> first expand FORWARD
end

if bf == 1 % --> first expand BACKWARD

    % --> expand BACKWARD
    t0    = tic;
    LEGSb = bellmanExp_backward(as1, idm, astMax, astLISTe, EPH, tols);
    tb    = toc(t0);
    seqs  = LEGSb(:,1:2:end);
    
    if ~isempty(LEGSb) && size(seqs,2) >= idm
        
        % --> update the propellant available on board
        dvsb    = sum(LEGSb(:,2:2:end-1),2);
        dvspb   = sum(LEGSb(:,4:2:end-1),2);
        tols(4) = tols(5) - dvsb(1);
        tols(2) = tols(2) - dvspb(1);
        
        % --> expand FORWARD
        t1                  = tic;
        [LEGSu, ~, DSMtotu] = bellmanExp_forward(as2, idm+1, astMax, astLISTe, EPH, tols, bw, vva2);
        tu                  = toc(t1);

        if ~isempty(LEGSu)

            % --> construct the best path
            [best_path, cost_best_path, LEGSb] = bellmanExp_link(LEGSb, LEGSu, as1, as2, EPH, DSMtotu);
            
            if size(best_path,1)-1 >= astMax && cost_best_path < tols(5)
            
                SOL.couple    = [as1 as2];
                SOL.indCoup   = indc;
                SOL.LEGSb     = LEGSb;
                SOL.LEGSu     = LEGSu;
                SOL.bestPath  = best_path;
                SOL.bestDV    = cost_best_path;
                SOL.compTime  = [tb tu];
                SOL.compTimeS = tb + tu;

                % --> save the solution
                if nargin > 1 && ~isempty(folder) % --> then the folder is specified
                    if exist(folder(2:end), 'dir') == 7 % --> then the folder exists on the current path
                        name2 = [folder '\SOL_couple_' num2str(indc) '.mat'];
                    else % --> then the folder does not exist on the current path
                        mkdir(folder(2:end)); % --> create the folder in the current path
                        name2 = [folder '\SOL_couple_' num2str(indc) '.mat'];
                    end
                else % --> then the folder is not specified --> save in '\results'
                    if exist('results', 'dir') == 7 % --> then the folder '\results' exists on the current path
                        name2 = ['\results\SOL_couple_' num2str(indc) '.mat'];
                    else % --> then the folder '\results' does not exist on the current path
                        mkdir('results');
                        name2 = ['\results\SOL_couple_' num2str(indc) '.mat'];
                    end
                end
                name = [pwd name2];
                save(name, 'SOL');
            
            else
                SOL = [];
            end
            
        else
            SOL = [];
        end

    else

        SOL = [];

    end

else % --> first expand FORWARD
    
    % --> expand FORWARD
    t1 = tic;
    [LEGSu, ~, DSMtotu] = bellmanExp_forward(as2, idm+1, astMax, astLISTe, EPH, tols, bw, vva2);
    tu = toc(t1);
    seqs = LEGSu(:,1:2:end);
    
    if ~isempty(LEGSu) && size(seqs,2) >= idm
        
        % --> update the propellant available on board
        dvsu    = sum(LEGSu(:,2:2:end-1),2);
        dvspu   = dvsu;
        tols(4) = tols(5) - dvsu(1);
        tols(2) = tols(2) - dvspu(1);
        
        % --> expand BACKWARD
        t0 = tic;
        [LEGSb] = bellmanExp_backward(as1, idm, astMax, astLISTe, EPH, tols);
        tb = toc(t0);
        
        if ~isempty(LEGSb)
            
            % --> construct the best path
            [best_path, cost_best_path, LEGSb] = bellmanExp_link(LEGSb, LEGSu, as1, as2, EPH, DSMtotu);
            
            if size(best_path,1)-1 >= astMax && cost_best_path < tols(5)
            
                SOL.couple    = [as1 as2];
                SOL.indCoup   = indc;
                SOL.LEGSb     = LEGSb;
                SOL.LEGSu     = LEGSu;
                SOL.bestPath  = best_path;
                SOL.bestDV    = cost_best_path;
                SOL.compTime  = [tb tu];
                SOL.compTimeS = tb + tu;

                % --> save the solution
                if nargin > 1 && ~isempty(folder) % --> then the folder is specified
                    if exist(folder(2:end), 'dir') == 7 % --> then the folder exists on the current path
                        name2 = [folder '\SOL_couple_' num2str(indc) '.mat'];
                    else % --> then the folder does not exist on the current path
                        mkdir(folder(2:end)); % --> create the folder in the current path
                        name2 = [folder '\SOL_couple_' num2str(indc) '.mat'];
                    end
                else % --> then the folder is not specified --> save in '\results'
                    if exist('results', 'dir') == 7 % --> then the folder '\results' exists on the current path
                        name2 = ['\results\SOL_couple_' num2str(indc) '.mat'];
                    else % --> then the folder '\results' does not exist on the current path
                        mkdir('results');
                        name2 = ['\results\SOL_couple_' num2str(indc) '.mat'];
                    end
                end
                name = [pwd name2];
                save(name, 'SOL');
            
            else
                SOL = [];
            end
            
        else
            SOL = [];
        end
        
    else
        SOL = [];
    end
    
end

% --> save the couple explored
if nargin > 2 && ~isempty(folder2) % --> then the folder is specified
    if exist(folder2(2:end), 'dir') == 7 % --> then the folder exists on the current path
        name2 = [folder2 '\couple_' num2str(indc) '.mat'];
    else % --> then the folder does not exist on the current path
        mkdir(folder2(2:end)); % --> create the folder in the current path
        name2 = [folder2 '\couple_' num2str(indc) '.mat'];
    end
else % --> then the folder is not specified --> save in '\results'
    if exist('bellman_couples_expl', 'dir') == 7 % --> then the folder '\results' exists on the current path
        name2 = ['\bellman_couples_expl\couple_' num2str(indc) '.mat'];
    else % --> then the folder '\results' does not exist on the current path
        mkdir('bellman_couples_expl');
        name2 = ['\bellman_couples_expl\couple_' num2str(indc) '.mat'];
    end
end
name = [pwd name2];
save(name, 'indc');

end