function [DVtot, DSMtot, dv, DSM, TOFd, VAS] = costFunctionSeq(x, EPH, OptionsMultiRev)

% --> the sequence needs to start at the Earth!!!
% --> the Earth and Mars are included in the sequence
% --> ephemerides are provided in INPUT

muSun = 132712440018; % --> gravitational parameter of the Sun

dv   = zeros(1, length(x)-1);
VAS  = zeros(length(x)-1, 3); % --> arrival velocities at the asteroids
for indi = 1:length(x)-1
   
    as1 = x(indi);    
    as2 = x(indi+1);
    
    t1  = EPH(EPH(:,1) == as1, 2);
    rr1 = EPH(EPH(:,1) == as1, 3:5);
    vv1 = EPH(EPH(:,1) == as1, 6:8);
    
    t2  = EPH(EPH(:,1) == as2, 2);
    rr2 = EPH(EPH(:,1) == as2, 3:5);
    
    % --> solve the MRLP
    if indi == 1
        [dv(indi), ~, va2] = lambert_MR_opts(vv1, rr1, rr2, (t2 - t1)*86400, muSun, OptionsMultiRev);
    else
        if as1 < 11
            [dv(indi), ~, va2] = lambert_MR_opts_flyby(vaprev, vv1, 4, rr1, rr2, (t2 - t1)*86400, muSun, OptionsMultiRev);
        else
            [dv(indi), ~, va2] = lambert_MR_opts(vaprev, rr1, rr2, (t2 - t1)*86400, muSun, OptionsMultiRev);
        end
    end    
    vaprev      = va2;
    VAS(indi,:) = va2;
end
DVtot  = sum(dv);
DSM    = dv(2:end);
DSMtot = sum(DSM);

% --> compute the total time of flight for the mission
T1   = EPH(EPH(:,1) == x(1), 2);
T2   = EPH(EPH(:,1) == x(end), 2);
TOFd = T2 - T1;

end
