function [DVtot, DSMtot, dv, DSM, TOFd, VAS] = costFunctionSeq_Eph(x, t, OptionsMultiRev)

% --> the sequence needs to start at the Earth!!!
% --> the Earth and Mars are included in the sequence
% --> epochs are provided in INPUT, and ephemerides are generated within
%     this function

muSun = 132712440018; % --> gravitational parameter of the Sun

dv   = zeros(1, length(x)-1);
VAS  = zeros(length(x)-1, 3); % --> arrival velocities at the asteroids
for indi = 1:length(x)-1
   
    as1 = x(indi);    
    as2 = x(indi+1);
    t1  = t(indi);
    t2  = t(indi+1);
    
    [rr1, vv1] = EphSS_car_m(as1, t1);
    [rr2, vv2] = EphSS_car_m(as2, t2);
    
    % --> solve the MRLP
    if indi == 1
        [dv(indi), ~, va2] = lambert_MR_opts(vv1, rr1, rr2, (t2 - t1)*86400, muSun, OptionsMultiRev);
    else
        if as1 == 4
            [dv(indi), ~, va2] = lambert_MR_opts_flyby(vaprev, vv1, 4, rr1, rr2, (t2 - t1)*86400, muSun, OptionsMultiRev);
        else
            [dv(indi), ~, va2] = lambert_MR_opts(vaprev, rr1, rr2, (t2 - t1)*86400, muSun, OptionsMultiRev);
        end
    end    

    vaprev      = va2;
    VAS(indi,:) = va2;
end
DVtot  = sum(dv);
DSM    = dv(2:end);
DSMtot = sum(DSM);

% --> compute the total time of flight for the mission
TOFd = t(end) - t(1);

end
