function [fig1, fig2, fig3] = plotPath_Eph(path)

seq = path(:,1);
t   = path(:,2);

mu  = 132712440018;
AU  = 149597870.691;

fig1 = figure;
hold on; axis equal; grid on;
xlabel('x - AU'); ylabel('y - AU');

% plot Sun texture
plot_sun(0.2, [0 0 0]);

idx = find(path(:,1) == 4);
if ~isempty(idx)
    % plot Mars orbit
    idMARS = path(idx,1);
    tMARS  = path(idx,2);
    [rrMARS, vvMARS] = EphSS_car(idMARS, tMARS);
    options = odeset('abstol', 1e-12, 'reltol', 1e-12);
    [~,yy] = ode113(@(t,x) dyn_2BP(t, x, mu), [0 4*365.25*86400], [rrMARS, vvMARS], options);
    hold on;
    plot3(yy(:,1)./AU, yy(:,2)./AU, yy(:,3)./AU, 'k', 'linewidth', 0.3);

    % plot Mars texture
    plot_mars(0.12, [rrMARS(1) rrMARS(2) rrMARS(3)]./AU);
end
% plot Earth orbit
[rrEARTH, vvEARTH] = EphSS_car(3, path(1,2));
options = odeset('abstol', 1e-12, 'reltol', 1e-12);
[~,yy] = ode113(@(t,x) dyn_2BP(t, x, mu), [0 365.25*86400], [rrEARTH, vvEARTH], options);
hold on;
plot3(yy(:,1)./AU, yy(:,2)./AU, yy(:,3)./AU, 'k', 'linewidth', 0.3);

% plot Earth texture
plot_earth(0.12, [rrEARTH(1) rrEARTH(2) rrEARTH(3)]./AU);

YY = [];
TT = []; tend = 0;
for indi = 1:size(path,1)-1
    
    as1 = seq(indi);
    as2 = seq(indi+1);
    t2  = t(indi+1);
    t1  = t(indi);
    
    [rr1, vv1] = EphSS_car_m(as1, t1);
    [rr2, vv2] = EphSS_car_m(as2, t2);

    [vvd, vvf] = lambertMR_vA(rr1, rr2, (t2 - t1)*86400, mu, 0, 0);
    
    options = odeset('abstol', 1e-12, 'reltol', 1e-12);
    [tt,yy]  = ode113(@(t,x) dyn_2BP(t, x, mu), [0 (t2 - t1)*86400], [rr1, vvd], options);
    
    hold on;
    plot3(yy(:,1)./AU, yy(:,2)./AU, yy(:,3)./AU, 'b', 'linewidth', 1.5);
    plot3(yy(end,1)./AU, yy(end,2)./AU, yy(end,3)./AU, 'ko', 'markersize', 8);
    
    YY = [YY; yy];
    TT = [TT; [tend + tt]];
    tend = TT(end);

end

t = t - t(1);
if nargout == 2
    RR = sqrt(sum(YY(:,1:3).^2,2));
    fig2 = figure; hold on; grid on;
    xlabel('Time from departure - days'); ylabel('Spacecraft distance from the Sun - AU');
    plot(TT./86400, RR./AU, 'linewidth', 2);
    
    for ind = 1:length(t)
        vline(t(ind));
    end
    
elseif nargout == 3
    RR = sqrt(sum(YY(:,1:3).^2,2));
    fig2 = figure; hold on; grid on;
    xlabel('Time from departure - days'); ylabel('Spacecraft distance from the Sun - AU');
    plot(TT./86400, RR./AU, 'linewidth', 2);
    
    for ind = 1:length(t)
        vline(t(ind));
    end
    
    VV = sqrt(sum(YY(:,4:6).^2,2));
    fig3 = figure; hold on; grid on;
    xlabel('Time from departure - days'); ylabel('Spacecraft velocity - km/s');
    plot(TT./86400, VV, 'linewidth', 2);
    
    for ind = 1:length(t)
        vline(t(ind));
    end
end

end