function [fig] = plotPath_castpath(path)

try

    mu  = 132712440018;
    AU  = 149597870.691;

    fig = figure;
    hold on; axis equal; grid on;
    xlabel('x - AU'); ylabel('y - AU');

    % plot Sun texture
    plot_sun(0.2, [0 0 0]);

    idx = find(path(:,1) == 4);
    if ~isempty(idx)
        % plot Mars orbit
        idMARS = path(idx,1);
        tMARS  = path(idx,2);
        [rrMARS, vvMARS] = EphSS_car(idMARS, tMARS);
        options = odeset('abstol', 1e-12, 'reltol', 1e-12);
        [~,yy] = ode113(@(t,x) dyn_2BP(t, x, mu), [0 4*365.25*86400], [rrMARS, vvMARS], options);
        hold on;
        plot3(yy(:,1)./AU, yy(:,2)./AU, yy(:,3)./AU, 'k', 'linewidth', 0.3);

        % plot Mars texture
        plot_mars(0.12, [rrMARS(1) rrMARS(2) rrMARS(3)]./AU);

    else
    end
    % plot Earth orbit
    [rrEARTH, vvEARTH] = EphSS_car(3, path(1,2));
    options = odeset('abstol', 1e-12, 'reltol', 1e-12);
    [~,yy] = ode113(@(t,x) dyn_2BP(t, x, mu), [0 365.25*86400], [rrEARTH, vvEARTH], options);
    hold on;
    plot3(yy(:,1)./AU, yy(:,2)./AU, yy(:,3)./AU, 'k', 'linewidth', 0.3);

    % plot Earth texture
    plot_earth(0.12, [rrEARTH(1) rrEARTH(2) rrEARTH(3)]./AU);

    for indi = 2:size(path,1)

        idAST = path(indi,1);

        if idAST == 4

            idASTPREC   = path(indi-1,1);
            tPREC       = path(indi-1,2);
            [rrPREC, ~] = EphSS_car(idASTPREC, tPREC);

            tAST          = path(indi,2);
            [rrTARGET, ~] = EphSS_car(idAST, tAST);

            [~, ~, ~, ~, vI, ~, ~, ~] = ...
                lambertMR(rrPREC, rrTARGET, (tAST - tPREC)*86400, mu, 0, 0, 0, 0);

            rr = rrPREC;
            vv = vI;
            options = odeset('abstol', 1e-12, 'reltol', 1e-12);
            [~,yy] = ode113(@(t,x) dyn_2BP(t, x, mu), [0 (tAST - tPREC)*86400], [rr, vv], options);

            hold on;
            plot3(yy(:,1)./AU, yy(:,2)./AU, yy(:,3)./AU, 'b', 'linewidth', 1);
            plot3(yy(end,1)./AU, yy(end,2)./AU, yy(end,3)./AU, 'k.', 'markersize', 15);

        else

            tAST       = path(indi,2);
            [rrAST, ~] = EphSS_car(idAST, tAST);

            rr = rrAST;
            vv = path(indi,3:5);

            dt = (tAST - path(indi-1,2))*86400;

            options = odeset('abstol', 1e-12, 'reltol', 1e-12);
            [~,yy] = ode113(@(t,x) dyn_2BP(t, x, mu), [0 -dt], [rr, vv], options);

            hold on;
            plot3(yy(:,1)./AU, yy(:,2)./AU, yy(:,3)./AU, 'b', 'linewidth', 1);
            plot3(yy(1,1)./AU, yy(1,2)./AU, yy(1,3)./AU, 'ko', 'markersize', 8);

        end

        if indi == 2
            plot3(yy(end,1)./AU, yy(end,2)./AU, yy(end,3)./AU, 'ks', 'markersize', 10);
        end

    end

catch % --> load the database
    
    ephNEO('load','ephNEO_CATABC.txt');
    
    mu  = 132712440018;
    AU  = 149597870.691;

    fig = figure;
    hold on; axis equal; grid on;
    xlabel('x - AU'); ylabel('y - AU');

    % plot Sun texture
    plot_sun(0.2, [0 0 0]);

    idx = find(path(:,1) == 4);
    if ~isempty(idx)
        % plot Mars orbit
        idMARS = path(idx,1);
        tMARS  = path(idx,2);
        [rrMARS, vvMARS] = EphSS_car(idMARS, tMARS);
        options = odeset('abstol', 1e-12, 'reltol', 1e-12);
        [~,yy] = ode113(@(t,x) dyn_2BP(t, x, mu), [0 4*365.25*86400], [rrMARS, vvMARS], options);
        hold on;
        plot3(yy(:,1)./AU, yy(:,2)./AU, yy(:,3)./AU, 'k', 'linewidth', 0.3);

        % plot Mars texture
        plot_mars(0.12, [rrMARS(1) rrMARS(2) rrMARS(3)]./AU);

    else
    end
    % plot Earth orbit
    [rrEARTH, vvEARTH] = EphSS_car(3, path(1,2));
    options = odeset('abstol', 1e-12, 'reltol', 1e-12);
    [~,yy] = ode113(@(t,x) dyn_2BP(t, x, mu), [0 365.25*86400], [rrEARTH, vvEARTH], options);
    hold on;
    plot3(yy(:,1)./AU, yy(:,2)./AU, yy(:,3)./AU, 'k', 'linewidth', 0.3);

    % plot Earth texture
    plot_earth(0.12, [rrEARTH(1) rrEARTH(2) rrEARTH(3)]./AU);

    for indi = 2:size(path,1)

        idAST = path(indi,1);

        if idAST == 4

            idASTPREC   = path(indi-1,1);
            tPREC       = path(indi-1,2);
            [rrPREC, ~] = EphSS_car(idASTPREC, tPREC);

            tAST          = path(indi,2);
            [rrTARGET, ~] = EphSS_car(idAST, tAST);

            [~, ~, ~, ~, vI, ~, ~, ~] = ...
                lambertMR(rrPREC, rrTARGET, (tAST - tPREC)*86400, mu, 0, 0, 0, 0);

            rr = rrPREC;
            vv = vI;
            options = odeset('abstol', 1e-12, 'reltol', 1e-12);
            [~,yy] = ode113(@(t,x) dyn_2BP(t, x, mu), [0 (tAST - tPREC)*86400], [rr, vv], options);

            hold on;
            plot3(yy(:,1)./AU, yy(:,2)./AU, yy(:,3)./AU, 'b', 'linewidth', 1);
            plot3(yy(end,1)./AU, yy(end,2)./AU, yy(end,3)./AU, 'k.', 'markersize', 15);

        else

            tAST       = path(indi,2);
            [rrAST, ~] = EphSS_car(idAST, tAST);

            rr = rrAST;
            vv = path(indi,3:5);

            dt = (tAST - path(indi-1,2))*86400;

            options = odeset('abstol', 1e-12, 'reltol', 1e-12);
            [~,yy] = ode113(@(t,x) dyn_2BP(t, x, mu), [0 -dt], [rr, vv], options);

            hold on;
            plot3(yy(:,1)./AU, yy(:,2)./AU, yy(:,3)./AU, 'b', 'linewidth', 1);
            plot3(yy(1,1)./AU, yy(1,2)./AU, yy(1,3)./AU, 'ko', 'markersize', 8);

        end

        if indi == 2
            plot3(yy(end,1)./AU, yy(end,2)./AU, yy(end,3)./AU, 'ks', 'markersize', 10);
        end

    end

end