function [dv, dvSplit]=Transfer_CASTAway_Sequence(Sequence, Times)
% Sequence - defines the asteroids to be visited in [index+11] type
% Times - defines the times for the fly by
%--------------------------------------------------------------------------
% Initialization
%  ephNEO('load','GTOC7ASTEROIDS.txt');
muSun = astroConstants(4);
muMars=42828.0184128135;
smaMars=227940540.039744;
RMars=3389.92;
%--------------------------------------------------------------------------
% Spacecraft Model
mi = 1500; % 1500 kg wet mass, similar to Marco Polo (and M class candidate)
Isp = 350; % Standard Number.
ve = Isp*astroConstants(6);
%--------------------------------------------------------------------------
nFB = length(Sequence);
dvSplit=zeros(1,nFB-1);
%--------------------------------------------------------------------------
% Launch Model

t0 = Times(1); % 1/1/2029
t1 = Times(2); % 31/12/2030

% Earth Launch with Soyuz-Fregat-like

vInf = 0; %km/s

%--------------------------------------------------------------------------
% Initial Tranfer Guess

Seq=Sequence;

% timeLaunch =tW(1)+(tW(2)-tW(1))*rand;
%
%        ToF = 365; %[days]

%--------------------------------------------------------------------------
% Lambert Arc Generation
%     mass = mi;
% Departure
[sE(1:3), sE(4:6)] = EphSS_car(Seq(1), t0); % Departure

% Arrival
[sA(1:3), sA(4:6)] = EphSS_car(Seq(2), t1); % Arrival

% Options
multirev = 0;
energy   = 0;
[A, P, E, error, vI, vF, TPAR, THETA] = ...
    lambertMR(sE(1:3), sA(1:3), (t1-t0)*86400, muSun, 0, multirev, energy, 0);

% Results Transfers
dv = (norm(vI-sE(4:6))-vInf)*(norm(vI-sE(4:6))-vInf>=0);
Vsc_Asteroid=vF;
% Apply SwingBy is second object is mars
if Seq(2)==4
    %--------------------------------------------------------------------------
    % Applying SwingBy Manoeuvre at Mars
    % Mars Swing-by
    VArr2Mars=vF;
    vinf1=VArr2Mars-sA(4:6);
    
    % As Rosetta, CASTAway should aim at a 250 km altitude fly-by as a maximum
    % close encounter.
    rpFB=RMars+250;
    
    n_r=cross(vinf1,sA(4:6)); % Reference vector
    n_r=n_r/norm(n_r);
    
    gamma=0;
    
    vinf2 = swingby(vinf1,rpFB,muMars,gamma,n_r)';
    
    vDepSW_mars=vinf2+sA(4:6);
    
    %--------------------------------------------------------------------------
    % Departure conditions after Mars Swing By
    Vsc_Asteroid=vDepSW_mars;
    %     svDepSW_mars=[sA(1:3) vDepSW_mars];
    %     kepDepSW_mars=car2kep(svDepSW_mars,muSun);
end
dvSplit(1)=dv;
%--------------------------------------------------------------------------
% The rest of the legs
if  nFB>2

    for iFB=2:nFB-1
        
        % Departure
        [sA(1:3), sA(4:6)] = EphSS_car(Seq(iFB), Times(iFB)); % Departure
        
        % Arrival
        [sA2(1:3), sA2(4:6)] = EphSS_car(Seq(iFB+1), Times(iFB+1)); % Arrival
        
        % Options
        multirev = 0;
        energy = 0;
        [A, P, E, error, vI, vF, TPAR, THETA] = ...
            lambertMR(sA(1:3), sA2(1:3), (Times(iFB+1)-Times(iFB))*86400, muSun, 0, multirev, energy, 0);
        
        % Results Transfers
        dv = norm(vI-Vsc_Asteroid)+dv;
        dvSplit(iFB)=norm(vI-Vsc_Asteroid);
        Vsc_Asteroid=vF;
        % Apply SwingBy is second object is mars
        if Seq(iFB+1)==4
            %--------------------------------------------------------------------------
            % Applying SwingBy Manoeuvre at Mars
            % Mars Swing-by
            VArr2Mars=vF;
            vinf1=VArr2Mars-sA2(4:6);
            
            % As Rosetta, CASTAway should aim at a 250 km altitude fly-by as a maximum
            % close encounter.
            rpFB=RMars+250;
            
            n_r=cross(vinf1,sA2(4:6)); % Reference vector
            n_r=n_r/norm(n_r);
            
            gamma=0;
            
            vinf2 = swingby(vinf1,rpFB,muMars,gamma,n_r)';
            
            vDepSW_mars=vinf2+sA2(4:6);
            
            %--------------------------------------------------------------------------
            % Departure conditions after Mars Swing By
            Vsc_Asteroid=vDepSW_mars;
            %     svDepSW_mars=[sA(1:3) vDepSW_mars];
            %     kepDepSW_mars=car2kep(svDepSW_mars,muSun);
        end
        %--------------------------------------------------------------------------
    end

end

end
