function [DVTotal, dv, output] = Transfer_CASTAway_dsmEM_MarsFB(Seq, tDepEarth, TOFs, MarsSW, muSun, options)

if nargin == 5
    options(1) = 0; % if 0, the journey starts at s(1) with a deep space flight,
%                       with departure velocity v0. No swing-by is
%                       performed at body s(1).
    options(2) = 0; % if 0, the journey ends at the encounter of the last planet,
%                       s(end) without doing the swing-by of it.
    options(3) = 1; % if 1, v0 input is relative to the first planet, in
%                       cartesian coordinates.
%                       This case can be used with v0 = [0 0 0], and in
%                       conjunction with alpha1=0, to create a trajectory
%                       in which there is no real DSM in the first leg. In
%                       fact, the DSM is moved to emulate launch. Note that
%                       in this case, the first element of the output dv 
%                       will still be considered as a DSM.
    options(4) = 0; % if 0, No plot
    options(5) = 0; % if 0, output structure not generated
end

%--------------------------------------------------------------------------
%   v0[1,3]     Initial velocity vector [km/s]. It can be relative to the
%              first planet or absolute, depending on options(3).
        v0 = [0 0 0];
%--------------------------------------------------------------------------
%   T           Vector of parameters.
%               If options(1)=0:
%                   T = [alpha1, TOF1,
%                       gamma2, rp2, alpha2, TOF2,
%                       gamma3, rp3, alpha3, TOF3,
%                       ...];
             
                T(1) = 0;       % alpha1
                T(2) = TOFs(1); % TOF1
                
                indMars=find(Seq==4);
                n=length(TOFs)-1;
                if n>0
                    for in=1:n
                        if in==(indMars-1)
                            T = [T MarsSW TOFs(in+1)];
                        else
                            T = [T 0 1000 0 TOFs(in+1)];
                        end
                    end
                end
%--------------------------------------------------------------------------
%   multirev    Matrix containing, in each column (relative to each Lambert
%               arc), the type of transfer (direct or retrograde), the
%               number of revolutions for the Lambert arc, the case of
%               transfer (low or high energy):
%                   multirev = [type1, type2,  ...;
%                               nrev1, nrev2, ...;
%                               case1, case2, ...];
%               Leave it empty [] for using 0 rev, low energy, direct
%               transfer for each arc. Or it's possible to fill only the
%               first 1 or 2 rows, to take 0 rev and low energy.
                multirev = [];
%--------------------------------------------------------------------------                
%   sys         Optional. A structure which defines the planetary system and
%               ephemerides to use:
%                   .mu: Gravitational constant of the main attrector;
%                   .mu_planets: Gravitational constants of the satellites;
%                   .R_planets: Radii of the satellites;
%                   .eph_handle: Handle to the ephemeris function for the
%                       bodies, with prototype: [x, v] = eph_handle(id, t).
%                   .eph_kep_handle: Handle to the ephemeris function for the
%                       keplerian parameters of the bodies, with prototype:
%                       kep = eph_kep_handle(id, t).
%               If not specified or empty, uses the Solar System
%               (astroConstants and EphSS_car).

    sys.mu             = muSun;
    sys.mu_planets     = zeros(1,max(Seq));  % Default: Solar System
    sys.R_planets      = 10*ones(1,max(Seq)); % Default: Solar System
    sys.eph_handle     = @EphSS_car_m; % Default: Solar System
    sys.eph_kep_handle = @EphSS_kep_m; % Default: Solar System
    
%--------------------------------------------------------------------------

% Loading Mars
muMars            = 42828.0184128135;
RMars             = 3389.92;
sys.mu_planets(4) = muMars;
sys.R_planets (4) = RMars;

%--------------------------------------------------------------------------

    [dv, vin, error, xp2, vp2, output] = ...
        mimga(tDepEarth, T, Seq, multirev, v0, options ,sys);

    vInf  = 0;                            % --> km/s
    dv(1) = (dv(1)-vInf)*(dv(1)-vInf>=0); % --> km/s

    DVTotal = sum(dv); % --> km/s
    
end
