function [Tour, Struc] = beamSearch(bw, as, tas, tE, tols, astLIST, maxLev)

tolDSM   = tols(2);
tolVINFD = tols(1);

% compute the first leg
[Vsc_Asteroid, dv, ~] = firstLeg([3 as], [tE tas]);

% check all the reachable asteroids
[astREACH] = generateAllReachablePoints(as, tas, astLIST);

tour = [as tas Vsc_Asteroid dv];

if dv < tolVINFD % departing vInfinity pruning criterion

    Struc(:,1).Level = tour;
    Struc(:,1).Cost  = tour(:,6);

    for indi = 2:maxLev
        indi

        if indi == 2

            % compute the heuristic and the visited segments
            [~, visited, ~] = computeHeuristic(as, tas, Vsc_Asteroid, astREACH);

            % compute the next point
            [asNext, tasNext, Vsc_Asteroid_Next, dv_Next, ~] = computeNextPoint(visited, bw);

            tourNext = [asNext, tasNext, Vsc_Asteroid_Next, dv_Next];

            Struc(:,indi).Level = tourNext;
            Struc(:,indi).Cost  = tourNext(:,6);

        else

            nLevPrev = indi - 1;
            prevTour = Struc(nLevPrev).Level;

            tempNextPoint = [];
            tempNextCost  = [];

            for indk = 1:size(prevTour,1)

                indk
                
                % compute precedent points
                as           = prevTour(indk, 1);
                tas          = prevTour(indk, 2);
                Vsc_Asteroid = prevTour(indk, 3:5);
                
                % generate all reachable points
                [astREACH] = generateAllReachablePoints(as, tas, astLIST);

                % compute the heuristic and the visited segments
                [~, visited, ~] = computeHeuristic_BS(as, tas, Vsc_Asteroid, astREACH);

                % evaluate the next points
                [asNext, tasNext, Vsc_Asteroid_Next, dv_Next, ~] = computeNextPoint_BS(visited, bw);
                tourNext = [asNext, tasNext, Vsc_Asteroid_Next, dv_Next];

                % compute the new cost
                prevCost = Struc(nLevPrev).Cost(indk);
                newCost  = prevCost + dv_Next;

                tempNextPoint = [tempNextPoint; tourNext];
                tempNextCost  = [tempNextCost; newCost];

            end

            Struc(indi).Level = tempNextPoint;
            Struc(indi).Cost  = tempNextCost;

        end
        
        % interrompi la ricerca se l'ultimo livello ha tutti i costi
        % superiori alla soglia --> in questo modo, avr il tour pi lungo
        % sotto la soglia dato l'asteroide di partenza
        
        Cost = [Struc(:,indi).Cost];
        idx  = find(Cost < tolDSM);
        
        if isempty(idx)
            % se vuoto, allora nell'ultimo livello tutti hanno superato la
            % soglia, pertanto,rimuovi un livello a Struc e interrompi la
            % ricerca per il dato asteroide di partenza
            
            Struc(:,indi) = [];
            break
            
        end
        
    end
    % construct the tours
    [Tour] = extractRoutes(Struc, bw, tolDSM, tE);
else
    disp('Departing DV is greater than the tolerance!!');
    Tour = [];
end

end