function [SOL] = beamSearchAst_v2(INPUT, folder)

% --> load the INPUT
as       = INPUT.as;
bw       = INPUT.bw;
tols     = INPUT.tols;
EPH      = INPUT.EPH;
astLISTe = INPUT.astLISTe;
indast   = find(astLISTe(:,1) == as);
astMax   = INPUT.astMax;

% --> first leg
as1 = 3;
as2 = as;
[LEGS, VAS] = firstLeg_v2(as1, as2, EPH);

% --> create the folder for saving the results
if nargin > 1 && ~isempty(folder) % --> then the folder is specified
    if exist(folder(2:end), 'dir') == 7 % --> then the folder exists on the current path
        name2 = [folder '\SOL_astMOID_' num2str(indast) '_bw_' num2str(bw) '.mat'];
    else % --> then the folder does not exist on the current path
        mkdir(folder(2:end)); % --> create the folder in the current path
        name2 = [folder '\SOL_astMOID_' num2str(indast) '_bw_' num2str(bw) '.mat'];
    end
else % --> then the folder is not specified --> save in '\results'
    if exist('results', 'dir') == 7 % --> then the folder '\results' exists on the current path
        name2 = ['\results\SOL_astMOID_' num2str(indast) '_bw_' num2str(bw) '.mat'];
    else % --> then the folder '\results' does not exist on the current path
        mkdir('results');
        name2 = ['\results\SOL_astMOID_' num2str(indast) '_bw_' num2str(bw) '.mat'];
    end
end
name    = [pwd name2];

% --> run the search
LEGSnext = 1;
t2  = [];
ind = 1;
while ~isempty(LEGSnext) && ind < astMax 
   
    % --> perform the search
    t1 = tic;
    [LEGSnext, VASnext] = search_v2(LEGS, VAS, astLISTe, EPH, tols);
    t2 = [t2 toc(t1)]; toc(t1)
    
    % --> apply beam width
%     [LEGSnext, VASnext] = applyBW(LEGSnext, VASnext, bw);
    [LEGSnext, VASnext] = applyBW_DSMt(LEGSnext, VASnext, bw);
    
    if ~isempty(LEGSnext)
        LEGS = LEGSnext;
        VAS  = VASnext;
    end
    
    ind = ind + 1;
    
end
Ttot = sum(t2);

% --> compute the total cost for the missions identified
costTOT = DVseq(LEGS);

% --> find the best-DV path
[minCost, row] = min(costTOT);
LEGrow         = LEGS(row,:);
path           = constructPathFromLEGS_v2(LEGrow, astLISTe, EPH);

ids = path(:,1)';
ids(ids == 3) = [];
ids(ids == 4) = [];
Nasts = length(ids);

if isempty(Nasts) || (Nasts+1 < astMax)
    SOL = [];
    disp('No solutions found with current settings!');
else
    
    % --> save the solution
    SOL.LEGS             = LEGS;
    SOL.costTOT_legs     = costTOT;
    SOL.path_best_DV     = path;
    SOL.cost_best_path   = minCost;
    SOL.tofy_best_path   = (path(end,2) - path(1,2))/365.25;
    SOL.Elapsed_time_sec = Ttot;
    SOL.Nasts            = Nasts;
    SOL.EPH              = EPH;
    
    save(name, 'SOL');
    
end

end