function [SOL] = beamSearch_v2(astLISTe, EPH, tols, astMax, bw)

% --> first legs of the transfer
[LEGS, VAS] = firstLegs_BS_v2(astLISTe, EPH, tols);

% --> next legs
LEGSnext = 1;
ind      = 1;
t2       = [];
while ~isempty(LEGSnext) && ind < astMax 
   
    % --> perform the search
    t1                  = tic;
    [LEGSnext, VASnext] = search_v2(LEGS, VAS, astLISTe, EPH, tols);
    t2                  = [t2 toc(t1)]; toc(t1)
    
    % --> apply beam width
    [LEGSnext, VASnext] = applyBW_DSMt(LEGSnext, VASnext, bw);
    
    if ~isempty(LEGSnext)
        LEGS = LEGSnext;
        VAS  = VASnext;
    end
    
    ind = ind + 1;
    
end
Ttot = sum(t2);

if ~isempty(LEGS)
    
    % --> compute the total cost for the missions identified
    costTOT = DVseq(LEGS);

    % --> find the best-DV path
    [minCost, row] = min(costTOT);
    LEGrow         = LEGS(row,:);
    path           = constructPathFromLEGS_v2(LEGrow, astLISTe, EPH);
    
        ids = path(:,1)';
        ids(ids == 3) = [];
        ids(ids == 4) = [];
        Nasts = length(ids);
        
    if Nasts >= astMax-1

        % --> save the solution
        SOL.LEGS             = LEGS;
        SOL.costTOT_legs     = costTOT;
        SOL.path_best_DV     = path;
        SOL.cost_best_path   = minCost;
        SOL.tofy_best_path   = (path(end,2) - path(1,2))/365.25;
        SOL.Elapsed_time_sec = Ttot;
            ids = path(:,1)';
            ids(ids == 3) = [];
            ids(ids == 4) = [];
        SOL.Nasts            = length(ids);
        SOL.EPH              = EPH;
        SOL.BW               = bw;

    else
        SOL = [];
    end
else
    SOL = [];
end

end
