/*
 * Academic License - for use in teaching, academic research, and meeting
 * course requirements at degree granting institutions only.  Not for
 * government, commercial, or other organizational use.
 * File: lambertMR_vA.c
 *
 * MATLAB Coder version            : 5.2
 * C/C++ source code generated on  : 18-Feb-2022 12:10:16
 */

/* Include Files */
#include "lambertMR_vA.h"
#include "acosh.h"
#include "asinh.h"
#include "lambertMR_vA_data.h"
#include "lambertMR_vA_initialize.h"
#include "rt_nonfinite.h"
#include "rt_defines.h"
#include "rt_nonfinite.h"
#include <math.h>
#include <string.h>

/* Variable Definitions */
static double an[25];

static const short iv[25] = {0,   2,   6,   12,  20,  30,  42,  56,  72,
                             90,  110, 132, 156, 182, 210, 240, 272, 306,
                             342, 380, 420, 462, 506, 552, 600};

/* Function Declarations */
static double LancasterBlanchard(double x, double q, double m);

static void b_LancasterBlanchard(double x, double q, double m, double *T,
                                 double *Tp, double *Tpp);

static void lambert(double r1vec[3], double r2vec[3], double tf, double m,
                    double muC, double V1[3], double V2[3]);

static void lambert_LancasterBlanchard(const double r1vec[3],
                                       const double r2vec[3], double tf,
                                       double m, double muC, double V1[3],
                                       double V2[3], double *exitflag);

static double rt_atan2d_snf(double u0, double u1);

static double rt_powd_snf(double u0, double u1);

/* Function Definitions */
/*
 * protection against idiotic input
 *
 * Arguments    : double x
 *                double q
 *                double m
 * Return Type  : double
 */
static double LancasterBlanchard(double x, double q, double m)
{
  double E;
  double T;
  double f;
  double g;
  double y;
  double z;
  int k;
  /*  Lancaster & Blanchard's function, and three derivatives thereof */
  if (x == -1.0) {
    /*  impossible; offset x slightly */
    x = -0.99999999999999978;
  }
  /*  compute parameter E */
  E = x * x - 1.0;
  /*  T(x), T'(x), T''(x) */
  if (x == 1.0) {
    /*  exactly parabolic; solutions known exactly */
    /*  T(x) */
    T = 1.3333333333333333 * (1.0 - rt_powd_snf(q, 3.0));
    /*  T'(x) */
    /*  T''(x) */
    /*  T'''(x) */
  } else if (fabs(x - 1.0) < 0.01) {
    /*  near-parabolic; compute with series */
    /*  evaluate sigma */
    /*  preload the factors [an] */
    /*  (25 factors is more than enough for 16-digit accuracy) */
    /*  series approximation to T(x) and its derivatives */
    /*  (used for near-parabolic cases) */
    /*  powers of y */
    /*  sigma itself */
    /*  dsigma / dx (derivative) */
    /*  d2sigma / dx2 (second derivative) */
    /*  d3sigma / dx3 (third derivative) */
    /*  preload the factors [an] */
    /*  (25 factors is more than enough for 16-digit accuracy) */
    /*  series approximation to T(x) and its derivatives */
    /*  (used for near-parabolic cases) */
    /*  powers of y */
    /*  sigma itself */
    /*  dsigma / dx (derivative) */
    /*  d2sigma / dx2 (second derivative) */
    /*  d3sigma / dx3 (third derivative) */
    /*  T(x) */
    z = -E * q * q;
    y = 0.0;
    f = 0.0;
    for (k = 0; k < 25; k++) {
      y += rt_powd_snf(-E, (((double)k + 1.0) - 1.0) + 1.0) * an[k];
      f += rt_powd_snf(z, (((double)k + 1.0) - 1.0) + 1.0) * an[k];
    }
    T = (y + 1.3333333333333333) -
        rt_powd_snf(q, 3.0) * (f + 1.3333333333333333);
    /*  T'(x) */
    /*  T''(x) */
    /*  T'''(x) */
  } else {
    /*  all other cases */
    /*  compute all substitution functions */
    y = sqrt(fabs(E));
    z = sqrt(q * q * E + 1.0);
    f = y * (z - q * x);
    g = x * z - q * E;
    /*  BUGFIX: (Simon Tardivel) this line is incorrect for E==0 and f+g==0 */
    /*  d  = (E < 0)*(atan2(f, g) + pi*m) + (E > 0)*log( max(0, f + g) ); */
    /*  it should be written out like so: */
    /*  T(x) */
    if (E < 0.0) {
      f = rt_atan2d_snf(f, g) + 3.1415926535897931 * m;
    } else if (E == 0.0) {
      f = 0.0;
    } else {
      f = log(fmax(0.0, f + g));
    }
    T = 2.0 * ((x - q * z) - f / y) / E;
    /*   T'(x) */
    /*  T''(x) */
    /*  T'''(x) */
  }
  return T;
}

/*
 * protection against idiotic input
 *
 * Arguments    : double x
 *                double q
 *                double m
 *                double *T
 *                double *Tp
 *                double *Tpp
 * Return Type  : void
 */
static void b_LancasterBlanchard(double x, double q, double m, double *T,
                                 double *Tp, double *Tpp)
{
  double b_powers[25];
  double dv[25];
  double powers[25];
  double E_tmp;
  double d;
  double f;
  double g;
  double y;
  double z;
  double z_tmp;
  int k;
  /*  Lancaster & Blanchard's function, and three derivatives thereof */
  if (x < -1.0) {
    /*  impossible; negative eccentricity */
    x = fabs(x) - 2.0;
  } else if (x == -1.0) {
    /*  impossible; offset x slightly */
    x = -0.99999999999999978;
  }
  /*  compute parameter E */
  E_tmp = x * x;
  /*  T(x), T'(x), T''(x) */
  if (x == 1.0) {
    /*  exactly parabolic; solutions known exactly */
    /*  T(x) */
    *T = 1.3333333333333333 * (1.0 - rt_powd_snf(q, 3.0));
    /*  T'(x) */
    *Tp = 0.8 * (rt_powd_snf(q, 5.0) - 1.0);
    /*  T''(x) */
    *Tpp = *Tp + 1.7142857142857142 * (1.0 - rt_powd_snf(q, 7.0));
    /*  T'''(x) */
  } else if (fabs(x - 1.0) < 0.01) {
    /*  near-parabolic; compute with series */
    /*  evaluate sigma */
    /*  preload the factors [an] */
    /*  (25 factors is more than enough for 16-digit accuracy) */
    /*  series approximation to T(x) and its derivatives */
    /*  (used for near-parabolic cases) */
    /*  powers of y */
    /*  sigma itself */
    /*  dsigma / dx (derivative) */
    /*  d2sigma / dx2 (second derivative) */
    /*  d3sigma / dx3 (third derivative) */
    y = -(E_tmp - 1.0) * q * q;
    /*  preload the factors [an] */
    /*  (25 factors is more than enough for 16-digit accuracy) */
    /*  series approximation to T(x) and its derivatives */
    /*  (used for near-parabolic cases) */
    /*  powers of y */
    /*  sigma itself */
    /*  dsigma / dx (derivative) */
    /*  d2sigma / dx2 (second derivative) */
    /*  d3sigma / dx3 (third derivative) */
    /*  T(x) */
    f = 0.0;
    g = 0.0;
    for (k = 0; k < 25; k++) {
      z = rt_powd_snf(-(E_tmp - 1.0), (((double)k + 1.0) - 1.0) + 1.0);
      powers[k] = z;
      d = rt_powd_snf(y, (((double)k + 1.0) - 1.0) + 1.0);
      b_powers[k] = d;
      z_tmp = an[k];
      f += z * z_tmp;
      g += d * z_tmp;
    }
    *T = (f + 1.3333333333333333) -
         rt_powd_snf(q, 3.0) * (g + 1.3333333333333333);
    /*  T'(x) */
    dv[0] = 1.0;
    for (k = 0; k < 24; k++) {
      dv[k + 1] = (((double)k + 1.0) + 1.0) * b_powers[k];
    }
    z = 0.0;
    for (k = 0; k < 25; k++) {
      z += dv[k] * an[k];
    }
    dv[0] = 1.0;
    for (k = 0; k < 24; k++) {
      dv[k + 1] = (((double)k + 1.0) + 1.0) * powers[k];
    }
    d = 0.0;
    for (k = 0; k < 25; k++) {
      d += dv[k] * an[k];
    }
    *Tp = 2.0 * x * (rt_powd_snf(q, 5.0) * z - d);
    /*  T''(x) */
    dv[0] = (double)iv[0] * (1.0 / -(E_tmp - 1.0));
    dv[1] = iv[1];
    for (k = 0; k < 23; k++) {
      dv[k + 2] = (double)iv[k + 2] * powers[k];
    }
    z = 0.0;
    for (k = 0; k < 25; k++) {
      z += dv[k] * an[k];
    }
    dv[0] = (double)iv[0] * (1.0 / y);
    dv[1] = iv[1];
    for (k = 0; k < 23; k++) {
      dv[k + 2] = (double)iv[k + 2] * b_powers[k];
    }
    d = 0.0;
    for (k = 0; k < 25; k++) {
      d += dv[k] * an[k];
    }
    *Tpp = *Tp / x + 4.0 * E_tmp * (z - rt_powd_snf(q, 7.0) * d);
    /*  T'''(x) */
  } else {
    /*  all other cases */
    /*  compute all substitution functions */
    y = sqrt(fabs(E_tmp - 1.0));
    z_tmp = q * q;
    z = sqrt(z_tmp * (E_tmp - 1.0) + 1.0);
    f = y * (z - q * x);
    g = x * z - q * (E_tmp - 1.0);
    /*  BUGFIX: (Simon Tardivel) this line is incorrect for E==0 and f+g==0 */
    /*  d  = (E < 0)*(atan2(f, g) + pi*m) + (E > 0)*log( max(0, f + g) ); */
    /*  it should be written out like so: */
    /*  T(x) */
    if (E_tmp - 1.0 < 0.0) {
      g = rt_atan2d_snf(f, g) + 3.1415926535897931 * m;
    } else if (E_tmp - 1.0 == 0.0) {
      g = 0.0;
    } else {
      g = log(fmax(0.0, f + g));
    }
    *T = 2.0 * ((x - q * z) - g / y) / (E_tmp - 1.0);
    /*   T'(x) */
    f = rt_powd_snf(q, 3.0);
    *Tp = ((4.0 - 4.0 * f * x / z) - 3.0 * x * *T) / (E_tmp - 1.0);
    /*  T''(x) */
    *Tpp = ((-4.0 * f / z * (1.0 - z_tmp * E_tmp / (z * z)) - 3.0 * *T) -
            3.0 * x * *Tp) /
           (E_tmp - 1.0);
    /*  T'''(x) */
  }
}

/*
 * original documentation:
 * {
 *  This routine implements a new algorithm that solves Lambert's problem. The
 *  algorithm has two major characteristics that makes it favorable to other
 *  existing ones.
 *  1) It describes the generic orbit solution of the boundary condition
 *  problem through the variable X=log(1+cos(alpha/2)). By doing so the
 *  graph of the time of flight become defined in the entire real axis and
 *  resembles a straight line. Convergence is granted within few iterations
 *  for all the possible geometries (except, of course, when the transfer
 *  angle is zero). When multiple revolutions are considered the variable is
 *  X=tan(cos(alpha/2)*pi/2).
 *  2) Once the orbit has been determined in the plane, this routine
 *  evaluates the velocity vectors at the two points in a way that is not
 *  singular for the transfer angle approaching to pi (Lagrange coefficient
 *  based methods are numerically not well suited for this purpose).
 *  As a result Lambert's problem is solved (with multiple revolutions
 *  being accounted for) with the same computational effort for all
 *  possible geometries. The case of near 180 transfers is also solved
 *  efficiently.
 *   We note here that even when the transfer angle is exactly equal to pi
 *  the algorithm does solve the problem in the plane (it finds X), but it
 *  is not able to evaluate the plane in which the orbit lies. A solution
 *  to this would be to provide the direction of the plane containing the
 *  transfer orbit from outside. This has not been implemented in this
 *  routine since such a direction would depend on which application the
 *  transfer is going to be used in.
 *  please report bugs to dario.izzo@esa.int
 * }
 *
 * Arguments    : double r1vec[3]
 *                double r2vec[3]
 *                double tf
 *                double m
 *                double muC
 *                double V1[3]
 *                double V2[3]
 * Return Type  : void
 */
static void lambert(double r1vec[3], double r2vec[3], double tf, double m,
                    double muC, double V1[3], double V2[3])
{
  double Vt2[3];
  double crossprd[3];
  double Lambda;
  double T;
  double V;
  double a;
  double a_min;
  double absxk;
  double c;
  double d;
  double d1;
  double d2;
  double dth;
  double leftbranch;
  double logt;
  double longway;
  double longway_tmp;
  double mcr;
  double mr2vec;
  double r1;
  double s;
  double scale;
  double t;
  double x1;
  double x2;
  double x_tmp;
  double x_tmp_tmp;
  double xnew;
  double y2;
  int iterations;
  boolean_T bad;
  boolean_T exitg1;
  /*  LAMBERT            Lambert-targeter for ballistic flights */
  /*                     (Izzo, and Lancaster, Blanchard & Gooding) */
  /*  */
  /*  Usage: */
  /*     [V1, V2, extremal_distances, exitflag] = lambert(r1, r2, tf, m,
   * GM_central) */
  /*  */
  /*  Dimensions: */
  /*              r1, r2 ->  [1x3] */
  /*              V1, V2 ->  [1x3] */
  /*  extremal_distances ->  [1x2] */
  /*               tf, m ->  [1x1] */
  /*          GM_central ->  [1x1] */
  /*  */
  /*  This function solves any Lambert problem *robustly*. It uses two separate
   */
  /*  solvers; the first one tried is a new and unpublished algorithm developed
   */
  /*  by Dr. D. Izzo from the European Space Agency [1]. This version is
   * extremely */
  /*  fast, but especially for larger [m] it still fails quite frequently. In
   * such */
  /*  cases, a MUCH more robust algorithm is started (the one by Lancaster & */
  /*  Blancard [2], with modifcations, initial values and other improvements by
   */
  /*  R.Gooding [3]), which is a lot slower partly because of its robustness. */
  /*  */
  /*  INPUT ARGUMENTS: */
  /*  ====================================================================== */
  /*     name        units    description */
  /*  ====================================================================== */
  /*    r1, r1       [km]     position vectors of the two terminal points. */
  /*      tf        [days]    time of flight to solve for */
  /*       m          [-]     specifies the number of complete orbits to
   * complete */
  /*                          (should be an integer) */
  /*  GM_central   [km3/s2]   std. grav. parameter (G�M = mu) of the central
   * body */
  /*  */
  /*  OUTPUT ARGUMENTS: */
  /*  ====================================================================== */
  /*    name             units   description */
  /*  ====================================================================== */
  /*   V1, V2             [km/s]  terminal velocities at the end-points */
  /*   extremal_distances  [km]   minimum(1) and maximum(2) distance of the */
  /*                              spacecraft to the central body. */
  /*   exitflag             [-]   Integer containing information on why the */
  /*                              routine terminated. A value of +1 indicates */
  /*                              success; a normal exit. A value of -1 */
  /*                              indicates that the given problem has no */
  /*                              solution and cannot be solved. A value of -2
   */
  /*                              indicates that both algorithms failed to find
   */
  /*                              a solution. This should never occur since */
  /*                              these problems are well-defined, and at the */
  /*                              very least it can be determined that the */
  /*                              problem has no solution. Nevertheless, it */
  /*                              still occurs sometimes for accidental */
  /*                              erroneous input, so it provides a basic */
  /*                              mechanism to check any application using this
   */
  /*                              algorithm. */
  /*  */
  /*  This routine can be compiled to increase its speed by a factor of about */
  /*  10-15, which is certainly advisable when the complete application requires
   */
  /*  a great number of Lambert problems to be solved. The entire routine is */
  /*  written in embedded MATLAB, so it can be compiled with the emlmex() */
  /*  function (older MATLAB) or codegen() function (MATLAB 2011a and later). */
  /*  */
  /*  To do this using emlmex(), make sure MATLAB's current directory is equal
   */
  /*  to where this file is located. Then, copy-paste and execute the following
   */
  /*  commands to the command window: */
  /*  */
  /*     example_input = {... */
  /*          [0.0, 0.0, 0.0], ...% r1vec */
  /*          [0.0, 0.0, 0.0], ...% r2vec */
  /*           0.0, ...           % tf */
  /*           0.0, ...           % m */
  /*           0.0};              % muC */
  /*     emlmex -eg example_input lambert.m */
  /*  */
  /*  This is of course assuming your compiler is configured correctly. See the
   */
  /*  documentation of emlmex() on how to do that. */
  /*  */
  /*  Using codegen(), the syntax is as follows: */
  /*  */
  /*     example_input = {... */
  /*          [0.0, 0.0, 0.0], ...% r1vec */
  /*          [0.0, 0.0, 0.0], ...% r2vec */
  /*           0.0, ...           % tf */
  /*           0.0, ...           % m */
  /*           0.0};              % muC */
  /*     codegen lambert.m -args example_input */
  /*  */
  /*  Note that in newer MATLAB versions, the code analyzer will complain about
   */
  /*  the pragma "%#eml" after the main function's name, and possibly, issue */
  /*  subsequent warnings related to this issue. To get rid of this problem,
   * simply */
  /*  replace the "%#eml" directive with "%#codegen". */
  /*  */
  /*  */
  /*  */
  /*  References: */
  /*  */
  /*  [1] Izzo, D. ESA Advanced Concepts team. Code used available in MGA.M, on
   */
  /*      http://www.esa.int/gsp/ACT/inf/op/globopt.htm. Last retreived Nov,
   * 2009. */
  /*  [2] Lancaster, E.R. and Blanchard, R.C. "A unified form of Lambert's
   * theorem." */
  /*      NASA technical note TN D-5368,1969. */
  /*  [3] Gooding, R.H. "A procedure for the solution of Lambert's orbital
   * boundary-value */
  /*      problem. Celestial Mechanics and Dynamical Astronomy, 48:145�165,1990.
   */
  /*  */
  /*  See also lambert_low_ExpoSins. */
  /*  Please report bugs and inquiries to: */
  /*  */
  /*  Name       : Rody P.S. Oldenhuis */
  /*  E-mail     : oldenhuis@gmail.com */
  /*  Licence    : 2-clause BSD (see License.txt) */
  /*  If you find this work useful, please consider a donation: */
  /*  https://www.paypal.me/RodyO/3.5 */
  /*  If you want to cite this work in an academic paper, please use */
  /*  the following template: */
  /*  */
  /*  Rody Oldenhuis, orcid.org/0000-0002-3162-3660. "Lambert" <version>, */
  /*  <date you last used it>. MATLAB Robust solver for Lambert's */
  /*  orbital-boundary value problem. */
  /*  https://nl.mathworks.com/matlabcentral/fileexchange/26348 */
  /*  ----------------------------------------------------------------- */
  /*  Izzo's version: */
  /*  Very fast, but not very robust for more complicated cases */
  /*  ----------------------------------------------------------------- */
  /*  adjusted documentation: */
  /* { */
  /*  For problems with |m| > 0, there are generally two solutions. By */
  /*  default, the right branch solution will be returned. The left branch */
  /*  may be requested by giving a negative value to the corresponding */
  /*  number of complete revolutions [m]. */
  /* } */
  /*  Authors */
  /*  .-`-.-`-.-`-.-`-.-`-.-`-.-`-.-`-.-`-.-`-.-`-.-`-.-`-.-`-.-`-. */
  /*  Name       : Dr. Dario Izzo */
  /*  E-mail     : dario.izzo@esa.int */
  /*  Affiliation: ESA / Advanced Concepts Team (ACT) */
  /*  Made more readible and optimized for speed by Rody P.S. Oldenhuis */
  /*  Code available in MGA.M on   http://www.esa.int/gsp/ACT/inf/op/globopt.htm
   */
  /*  last edited 12/Dec/2009 */
  /*  ADJUSTED FOR EML-COMPILATION 24/Dec/2009 */
  /*  initial values */
  bad = false;
  /*  work with non-dimensional units */
  scale = 3.3121686421112381E-170;
  absxk = fabs(r1vec[0]);
  if (absxk > 3.3121686421112381E-170) {
    r1 = 1.0;
    scale = absxk;
  } else {
    t = absxk / 3.3121686421112381E-170;
    r1 = t * t;
  }
  absxk = fabs(r1vec[1]);
  if (absxk > scale) {
    t = scale / absxk;
    r1 = r1 * t * t + 1.0;
    scale = absxk;
  } else {
    t = absxk / scale;
    r1 += t * t;
  }
  absxk = fabs(r1vec[2]);
  if (absxk > scale) {
    t = scale / absxk;
    r1 = r1 * t * t + 1.0;
    scale = absxk;
  } else {
    t = absxk / scale;
    r1 += t * t;
  }
  r1 = scale * sqrt(r1);
  V = sqrt(muC / r1);
  T = r1 / V;
  /*  also transform to seconds */
  /*  relevant geometry parameters (non dimensional) */
  /*  make 100% sure it's in (-1 <= dth <= +1) */
  d = r1vec[0] / r1;
  r1vec[0] = d;
  d1 = r2vec[0] / r1;
  r2vec[0] = d1;
  scale = d1 * d1;
  absxk = d * d1;
  d = r1vec[1] / r1;
  r1vec[1] = d;
  d1 = r2vec[1] / r1;
  r2vec[1] = d1;
  scale += d1 * d1;
  absxk += d * d1;
  d = r1vec[2] / r1;
  d1 = r2vec[2] / r1;
  scale += d1 * d1;
  absxk += d * d1;
  mr2vec = sqrt(scale);
  dth = acos(fmax(-1.0, fmin(1.0, absxk / mr2vec)));
  /*  decide whether to use the left or right branch (for multi-revolution */
  /*  problems), and the long- or short way */
  leftbranch = m;
  if (m < 0.0) {
    leftbranch = -1.0;
  } else if (m > 0.0) {
    leftbranch = 1.0;
  } else if (m == 0.0) {
    leftbranch = 0.0;
  }
  longway_tmp = r1vec[0] * r2vec[1] - r2vec[0] * r1vec[1];
  longway = longway_tmp;
  if (longway_tmp < 0.0) {
    longway = -1.0;
  } else if (longway_tmp > 0.0) {
    longway = 1.0;
  } else if (longway_tmp == 0.0) {
    longway = 0.0;
  }
  m = fabs(m);
  tf = fabs(tf / T);
  if (longway < 0.0) {
    dth = 6.2831853071795862 - dth;
  }
  /*  derived quantities */
  c = sqrt((mr2vec * mr2vec + 1.0) - 2.0 * mr2vec * cos(dth));
  /*  non-dimensional chord */
  s = ((mr2vec + 1.0) + c) / 2.0;
  /*  non-dimensional semi-perimeter */
  a_min = s / 2.0;
  /*  minimum energy ellipse semi major axis */
  Lambda = sqrt(mr2vec) * cos(dth / 2.0) / s;
  /*  lambda parameter (from BATTIN's book) */
  crossprd[0] = r1vec[1] * d1 - r2vec[1] * d;
  crossprd[1] = r2vec[0] * d - r1vec[0] * d1;
  mcr = sqrt((crossprd[0] * crossprd[0] + crossprd[1] * crossprd[1]) +
             longway_tmp * longway_tmp);
  /*  magnitues thereof */
  /*  unit vector thereof */
  /*  Initial values */
  /*  --------------------------------------------------------- */
  /*  ELMEX requires this variable to be declared OUTSIDE the IF-statement */
  logt = log(tf);
  /*  avoid re-computing the same value */
  /*  single revolution (1 solution) */
  if (m == 0.0) {
    /*  initial values */
    scale = -0.5233;
    /*  first initial guess */
    t = 0.5233;
    /*  second initial guess */
    x1 = -0.740867916771357;
    /*  transformed first initial guess */
    x2 = 0.42087903416051825;
    /*  transformed first second guess */
    /*  multiple revolutions (0, 1 or 2 solutions) */
    /*  the returned soltuion depends on the sign of [m] */
  } else {
    /*  select initial values */
    if (leftbranch < 0.0) {
      scale = -0.5234;
      /*  first initial guess, left branch */
      t = -0.2234;
      /*  second initial guess, left branch */
    } else {
      scale = 0.7234;
      /*  first initial guess, right branch */
      t = 0.5234;
      /*  second initial guess, right branch */
    }
    x1 = tan(scale * 6.2831853071795862 / 4.0);
    /*  transformed first initial guess */
    x2 = tan(t * 6.2831853071795862 / 4.0);
    /*  transformed first second guess */
  }
  /*  since (inn1, inn2) < 0, initial estimate is always ellipse */
  x_tmp_tmp = s - c;
  x_tmp = x_tmp_tmp / 2.0;
  a = longway * 2.0;
  /*  make 100.4% sure it's in (-1 <= xx <= +1) */
  /*  evaluate the time of flight via Lagrange expression */
  d2 = 6.2831853071795862 * m;
  xnew = a_min / (1.0 - scale * scale);
  y2 = a * asin(sqrt(x_tmp / xnew));
  scale = 2.0 * acos(scale);
  xnew = xnew * sqrt(xnew) * (((scale - sin(scale)) - (y2 - sin(y2))) + d2);
  absxk = xnew;
  xnew = a_min / (1.0 - t * t);
  y2 = a * asin(sqrt(x_tmp / xnew));
  scale = 2.0 * acos(t);
  xnew = xnew * sqrt(xnew) * (((scale - sin(scale)) - (y2 - sin(y2))) + d2);
  /*  initial estimates for y */
  if (m == 0.0) {
    absxk = log(absxk) - logt;
    y2 = log(xnew) - logt;
  } else {
    absxk -= tf;
    y2 = xnew - tf;
  }
  /*  Solve for x */
  /*  --------------------------------------------------------- */
  /*  Newton-Raphson iterations */
  /*  NOTE - the number of iterations will go to infinity in case */
  /*  m > 0  and there is no solution. Start the other routine in */
  /*  that case */
  scale = rtInf;
  iterations = 0;
  xnew = 0.0;
  exitg1 = false;
  while ((!exitg1) && (scale > 1.0E-14)) {
    /*  increment number of iterations */
    iterations++;
    /*  new x */
    xnew = (x1 * y2 - absxk * x2) / (y2 - absxk);
    /*  copy-pasted code (for performance) */
    if (m == 0.0) {
      t = exp(xnew) - 1.0;
    } else {
      t = atan(xnew) * 2.0 / 3.1415926535897931;
    }
    a = a_min / (1.0 - t * t);
    if (t < 1.0) {
      /*  ellipse */
      absxk = longway * 2.0 * asin(sqrt(x_tmp / a));
      /*  make 100.4% sure it's in (-1 <= xx <= +1) */
      scale = 2.0 * acos(fmax(-1.0, t));
    } else {
      /*  hyperbola */
      b_acosh(&t);
      scale = 2.0 * t;
      d2 = sqrt(x_tmp_tmp / (-2.0 * a));
      b_asinh(&d2);
      absxk = longway * 2.0 * d2;
    }
    /*  evaluate the time of flight via Lagrange expression */
    if (a > 0.0) {
      scale = a * sqrt(a) *
              (((scale - sin(scale)) - (absxk - sin(absxk))) +
               6.2831853071795862 * m);
    } else {
      scale = -a * sqrt(-a) * ((sinh(scale) - scale) - (sinh(absxk) - absxk));
    }
    /*  new value of y */
    /*  save previous and current values for the next iterarion */
    /*  (prevents getting stuck between two values) */
    x1 = x2;
    x2 = xnew;
    absxk = y2;
    if (m == 0.0) {
      y2 = log(scale) - logt;
    } else {
      y2 = scale - tf;
    }
    /*  update error */
    scale = fabs(x1 - xnew);
    /*  escape clause */
    if (iterations > 15) {
      bad = true;
      exitg1 = true;
    }
  }
  /*  If the Newton-Raphson scheme failed, try to solve the problem */
  /*  with the other Lambert targeter. */
  if (bad) {
    /*  NOTE: use the original, UN-normalized quantities */
    crossprd[0] = r1vec[0] * r1;
    Vt2[0] = r2vec[0] * r1;
    crossprd[1] = r1vec[1] * r1;
    Vt2[1] = r2vec[1] * r1;
    crossprd[2] = d * r1;
    Vt2[2] = d1 * r1;
    lambert_LancasterBlanchard(crossprd, Vt2, longway * tf * T, leftbranch * m,
                               muC, V1, V2, &scale);
  } else {
    /*  convert converged value of x */
    if (m == 0.0) {
      t = exp(xnew) - 1.0;
    } else {
      t = atan(xnew) * 2.0 / 3.1415926535897931;
    }
    /*     %{ */
    /*       The solution has been evaluated in terms of log(x+1) or
     * tan(x*pi/2), we */
    /*       now need the conic. As for transfer angles near to pi the Lagrange-
     */
    /*       coefficients technique goes singular (dg approaches a zero/zero
     * that is */
    /*       numerically bad) we here use a different technique for those cases.
     * When */
    /*       the transfer angle is exactly equal to pi, then the ih unit vector
     * is not */
    /*       determined. The remaining equations, though, are still valid. */
    /*     %} */
    /*  Solution for the semi-major axis */
    a = a_min / (1.0 - t * t);
    /*  Calculate psi */
    if (t < 1.0) {
      /*  ellipse */
      /*  make 100.4% sure it's in (-1 <= xx <= +1) */
      scale = sin(
          (2.0 * acos(fmax(-1.0, t)) - longway * 2.0 * asin(sqrt(x_tmp / a))) /
          2.0);
      absxk = 2.0 * a * (scale * scale) / s;
      scale = sqrt(absxk);
    } else {
      /*  hyperbola */
      d2 = t;
      b_acosh(&d2);
      xnew = sqrt((c - s) / 2.0 / a);
      b_asinh(&xnew);
      scale = sinh((2.0 * d2 - longway * 2.0 * xnew) / 2.0);
      absxk = -2.0 * a * (scale * scale) / s;
      scale = sqrt(absxk);
    }
    /*  unit of the normalized normal vector */
    /*  unit vector for normalized [r2vec] */
    crossprd[0] = longway * (crossprd[0] / mcr);
    V2[0] = r2vec[0] / mr2vec;
    crossprd[1] = longway * (crossprd[1] / mcr);
    V2[1] = r2vec[1] / mr2vec;
    crossprd[2] = longway * (longway_tmp / mcr);
    V2[2] = d1 / mr2vec;
    /*  cross-products */
    /*  don't use cross() (emlmex() would try to compile it, and this way it */
    /*  also does not create any additional overhead) */
    /*  radial and tangential directions for departure velocity */
    t = 1.0 / scale / sqrt(a_min) *
        ((2.0 * Lambda * a_min - Lambda) - t * scale);
    a = sin(dth / 2.0);
    absxk = sqrt(mr2vec / a_min / absxk * (a * a));
    /*  radial and tangential directions for arrival velocity */
    scale = absxk / mr2vec;
    a = (absxk - scale) / tan(dth / 2.0) - t;
    /*  terminal velocities */
    V1[0] = absxk * (crossprd[1] * d - r1vec[1] * crossprd[2]);
    V1[1] = absxk * (r1vec[0] * crossprd[2] - crossprd[0] * d);
    V1[2] = absxk * (crossprd[0] * r1vec[1] - r1vec[0] * crossprd[1]);
    Vt2[1] = scale * (V2[0] * crossprd[2] - crossprd[0] * V2[2]);
    Vt2[2] = scale * (crossprd[0] * V2[1] - V2[0] * crossprd[1]);
    V1[0] = (t * r1vec[0] + V1[0]) * V;
    V2[0] =
        (a * V2[0] + scale * (crossprd[1] * V2[2] - V2[1] * crossprd[2])) * V;
    V1[1] = (t * r1vec[1] + V1[1]) * V;
    V2[1] = (a * V2[1] + Vt2[1]) * V;
    V1[2] = (t * d + V1[2]) * V;
    V2[2] = (a * V2[2] + Vt2[2]) * V;
    /*  exitflag */
    /*  (success) */
    /*  also compute minimum distance to central body */
    /*  NOTE: use un-transformed vectors again! */
    /*      extremal_distances = ... */
    /*          minmax_distances(r1vec*r1, r1, r2vec*r1, mr2vec*r1, dth, a*r1,
     * V1, V2, m, muC); */
  }
}

/*
 * {
 * LAMBERT_LANCASTERBLANCHARD       High-Thrust Lambert-targeter
 * lambert_LancasterBlanchard() uses the method developed by
 * Lancaster & Blancard, as described in their 1969 paper. Initial values,
 * and several details of the procedure, are provided by R.H. Gooding,
 * as described in his 1990 paper.
 * }
 *
 * Arguments    : const double r1vec[3]
 *                const double r2vec[3]
 *                double tf
 *                double m
 *                double muC
 *                double V1[3]
 *                double V2[3]
 *                double *exitflag
 * Return Type  : void
 */
static void lambert_LancasterBlanchard(const double r1vec[3],
                                       const double r2vec[3], double tf,
                                       double m, double muC, double V1[3],
                                       double V2[3], double *exitflag)
{
  static const short b_iv[25] = {0,    0,     6,     24,   60,   120,  210,
                                 336,  504,   720,   990,  1320, 1716, 2184,
                                 2730, 3360,  4080,  4896, 5814, 6840, 7980,
                                 9240, 10626, 12144, 13800};
  double b_powers[25];
  double dv[25];
  double powers[25];
  double T;
  double T0;
  double Td;
  double Tp;
  double Tpp;
  double Tpp_tmp;
  double b_gamma;
  double c;
  double crsprod_idx_0;
  double crsprod_idx_1;
  double crsprod_idx_2;
  double dth;
  double leftbranch;
  double mcrsprd;
  double phr;
  double q;
  double q_tmp;
  double r1;
  double r1unit_idx_0;
  double r1unit_idx_1;
  double r1unit_idx_2;
  double r2;
  double r2unit_idx_0;
  double r2unit_idx_1;
  double r2unit_idx_2;
  double s;
  double sigma;
  double th1unit_idx_0;
  double th1unit_idx_1;
  double th1unit_idx_2;
  double th2unit_idx_0;
  double th2unit_idx_1;
  double th2unit_idx_2;
  double xM;
  double x_tmp;
  double z;
  int exitg1;
  int exitg2;
  int iterations;
  int k;
  boolean_T guard1 = false;
  boolean_T rEQ0;
  /*  ----------------------------------------------------------------- */
  /*  Lancaster & Blanchard version, with improvements by Gooding */
  /*  Very reliable, moderately fast for both simple and complicated cases */
  /*  ----------------------------------------------------------------- */
  /*  Please report bugs and inquiries to: */
  /*  */
  /*  Name       : Rody P.S. Oldenhuis */
  /*  E-mail     : oldenhuis@gmail.com */
  /*  Licence    : 2-clause BSD (see License.txt) */
  /*  If you find this work useful, please consider a donation: */
  /*  https://www.paypal.me/RodyO/3.5 */
  /*  ADJUSTED FOR EML-COMPILATION 29/Sep/2009 */
  /*  manipulate input */
  /*  optimum for numerical noise v.s. actual precision */
  /*  magnitude of r1vec */
  r1 = sqrt((r1vec[0] * r1vec[0] + r1vec[1] * r1vec[1]) + r1vec[2] * r1vec[2]);
  r2 = sqrt((r2vec[0] * r2vec[0] + r2vec[1] * r2vec[1]) + r2vec[2] * r2vec[2]);
  /*  magnitude of r2vec */
  /*  unit vector of r1vec */
  /*  unit vector of r2vec */
  crsprod_idx_0 = r1vec[1] * r2vec[2] - r2vec[1] * r1vec[2];
  crsprod_idx_1 = r2vec[0] * r1vec[2] - r1vec[0] * r2vec[2];
  crsprod_idx_2 = r1vec[0] * r2vec[1] - r2vec[0] * r1vec[1];
  /*  cross product of r1vec and r2vec */
  r1unit_idx_0 = r1vec[0] / r1;
  r2unit_idx_0 = r2vec[0] / r2;
  r1unit_idx_1 = r1vec[1] / r1;
  r2unit_idx_1 = r2vec[1] / r2;
  r1unit_idx_2 = r1vec[2] / r1;
  r2unit_idx_2 = r2vec[2] / r2;
  mcrsprd =
      sqrt((crsprod_idx_0 * crsprod_idx_0 + crsprod_idx_1 * crsprod_idx_1) +
           crsprod_idx_2 * crsprod_idx_2);
  /*  magnitude of that cross product */
  crsprod_idx_0 /= mcrsprd;
  crsprod_idx_1 /= mcrsprd;
  crsprod_idx_2 /= mcrsprd;
  th1unit_idx_0 = crsprod_idx_1 * r1unit_idx_2 - r1unit_idx_1 * crsprod_idx_2;
  th1unit_idx_1 = r1unit_idx_0 * crsprod_idx_2 - crsprod_idx_0 * r1unit_idx_2;
  th1unit_idx_2 = crsprod_idx_0 * r1unit_idx_1 - r1unit_idx_0 * crsprod_idx_1;
  /*  unit vectors in the tangential-directions */
  th2unit_idx_0 = crsprod_idx_1 * r2unit_idx_2 - r2unit_idx_1 * crsprod_idx_2;
  th2unit_idx_1 = r2unit_idx_0 * crsprod_idx_2 - crsprod_idx_0 * r2unit_idx_2;
  th2unit_idx_2 = crsprod_idx_0 * r2unit_idx_1 - r2unit_idx_0 * crsprod_idx_1;
  /*  make 100.4% sure it's in (-1 <= x <= +1) */
  dth = acos(fmax(-1.0, fmin(1.0, ((r1vec[0] * r2vec[0] + r1vec[1] * r2vec[1]) +
                                   r1vec[2] * r2vec[2]) /
                                      r1 / r2)));
  /*  turn angle */
  /*  if the long way was selected, the turn-angle must be negative */
  /*  to take care of the direction of final velocity */
  mcrsprd = tf;
  if (tf < 0.0) {
    mcrsprd = -1.0;
  } else if (tf > 0.0) {
    mcrsprd = 1.0;
  } else if (tf == 0.0) {
    mcrsprd = 0.0;
  }
  tf = fabs(tf);
  if (mcrsprd < 0.0) {
    dth -= 6.2831853071795862;
  }
  /*  left-branch */
  leftbranch = m;
  if (m < 0.0) {
    leftbranch = -1.0;
  } else if (m > 0.0) {
    leftbranch = 1.0;
  } else if (m == 0.0) {
    leftbranch = 0.0;
  }
  m = fabs(m);
  /*  define constants */
  c = sqrt((r1 * r1 + r2 * r2) - 2.0 * r1 * r2 * cos(dth));
  s = ((r1 + r2) + c) / 2.0;
  T = sqrt(8.0 * muC / rt_powd_snf(s, 3.0)) * tf;
  q_tmp = r1 * r2;
  q = sqrt(q_tmp) / s * cos(dth / 2.0);
  /*  general formulae for the initial values (Gooding) */
  /*  ------------------------------------------------- */
  /*  some initial values */
  T0 = LancasterBlanchard(0.0, q, m);
  Td = T0 - T;
  x_tmp = q * q;
  b_gamma = 2.0 * rt_atan2d_snf(1.0 - x_tmp, 2.0 * q);
  if (rtIsNaN(b_gamma) || rtIsInf(b_gamma)) {
    phr = rtNaN;
  } else if (b_gamma == 0.0) {
    phr = 0.0;
  } else {
    phr = fmod(b_gamma, 6.2831853071795862);
    rEQ0 = (phr == 0.0);
    if (!rEQ0) {
      mcrsprd = fabs(b_gamma / 6.2831853071795862);
      rEQ0 = !(fabs(mcrsprd - floor(mcrsprd + 0.5)) >
               2.2204460492503131E-16 * mcrsprd);
    }
    if (rEQ0) {
      phr = 0.0;
    } else if (b_gamma < 0.0) {
      phr += 6.2831853071795862;
    }
  }
  /*  initial output is pessimistic */
  V1[0] = rtNaN;
  V2[0] = rtNaN;
  V1[1] = rtNaN;
  V2[1] = rtNaN;
  V1[2] = rtNaN;
  V2[2] = rtNaN;
  /*  extremal_distances = [NaN, NaN]; */
  /*  single-revolution case */
  guard1 = false;
  if (m == 0.0) {
    if (Td > 0.0) {
      leftbranch = T0 * Td / 4.0 / T;
    } else {
      crsprod_idx_2 = Td / (4.0 - Td);
      crsprod_idx_0 =
          crsprod_idx_2 + 1.7 * sqrt(2.0 - phr / 3.1415926535897931);
      if (crsprod_idx_0 >= 0.0) {
        mcrsprd = crsprod_idx_2;
      } else {
        mcrsprd =
            crsprod_idx_2 + rt_powd_snf(-crsprod_idx_0, 0.0625) *
                                (-sqrt(-Td / (T + T0 / 2.0)) - crsprod_idx_2);
      }
      leftbranch = ((mcrsprd * (crsprod_idx_2 + 1.0) / 2.0 + 1.0) -
                    0.03 * (mcrsprd * mcrsprd) * sqrt(crsprod_idx_2 + 1.0)) *
                   mcrsprd;
    }
    /*  this estimate might not give a solution */
    if (leftbranch < -1.0) {
      *exitflag = -1.0;
    } else {
      /*  multi-revolution case */
      guard1 = true;
    }
  } else {
    /*  determine minimum Tp(x) */
    mcrsprd = 4.0 / (9.42477796076938 * (2.0 * m + 1.0));
    if (phr < 3.1415926535897931) {
      xM = mcrsprd * rt_powd_snf(phr / 3.1415926535897931, 0.125);
    } else if (phr > 3.1415926535897931) {
      xM = mcrsprd * (2.0 - rt_powd_snf(2.0 - phr / 3.1415926535897931, 0.125));
      /*  EMLMEX requires this one */
    } else {
      xM = 0.0;
    }
    /*  use Halley's method */
    Tp = rtInf;
    iterations = 0;
    do {
      exitg2 = 0;
      if (fabs(Tp) > 1.0E-12) {
        /*  iterations */
        iterations++;
        /*  compute first three derivatives */
        b_gamma = xM;
        /*  protection against idiotic input */
        /*  Lancaster & Blanchard's function, and three derivatives thereof */
        if (xM < -1.0) {
          /*  impossible; negative eccentricity */
          b_gamma = fabs(xM) - 2.0;
        } else if (xM == -1.0) {
          /*  impossible; offset x slightly */
          b_gamma = -0.99999999999999978;
        }
        /*  compute parameter E */
        sigma = b_gamma * b_gamma;
        /*  T(x), T'(x), T''(x) */
        if (b_gamma == 1.0) {
          /*  exactly parabolic; solutions known exactly */
          /*  T(x) */
          /*  T'(x) */
          Tp = 0.8 * (rt_powd_snf(q, 5.0) - 1.0);
          /*  T''(x) */
          Tpp = Tp + 1.7142857142857142 * (1.0 - rt_powd_snf(q, 7.0));
          /*  T'''(x) */
          mcrsprd = 3.0 * (Tpp - Tp) +
                    2.2222222222222223 * (rt_powd_snf(q, 9.0) - 1.0);
        } else if (fabs(b_gamma - 1.0) < 0.01) {
          /*  near-parabolic; compute with series */
          /*  evaluate sigma */
          /*  preload the factors [an] */
          /*  (25 factors is more than enough for 16-digit accuracy) */
          /*  series approximation to T(x) and its derivatives */
          /*  (used for near-parabolic cases) */
          /*  powers of y */
          /*  sigma itself */
          /*  dsigma / dx (derivative) */
          /*  d2sigma / dx2 (second derivative) */
          /*  d3sigma / dx3 (third derivative) */
          crsprod_idx_1 = -(sigma - 1.0) * q * q;
          /*  preload the factors [an] */
          /*  (25 factors is more than enough for 16-digit accuracy) */
          /*  series approximation to T(x) and its derivatives */
          /*  (used for near-parabolic cases) */
          /*  powers of y */
          for (k = 0; k < 25; k++) {
            powers[k] =
                rt_powd_snf(-(sigma - 1.0), (((double)k + 1.0) - 1.0) + 1.0);
            b_powers[k] =
                rt_powd_snf(crsprod_idx_1, (((double)k + 1.0) - 1.0) + 1.0);
          }
          /*  sigma itself */
          /*  dsigma / dx (derivative) */
          /*  d2sigma / dx2 (second derivative) */
          /*  d3sigma / dx3 (third derivative) */
          /*  T(x) */
          /*  T'(x) */
          dv[0] = 1.0;
          for (k = 0; k < 24; k++) {
            dv[k + 1] = (((double)k + 1.0) + 1.0) * b_powers[k];
          }
          crsprod_idx_2 = 0.0;
          for (k = 0; k < 25; k++) {
            crsprod_idx_2 += dv[k] * an[k];
          }
          dv[0] = 1.0;
          for (k = 0; k < 24; k++) {
            dv[k + 1] = (((double)k + 1.0) + 1.0) * powers[k];
          }
          crsprod_idx_0 = 0.0;
          for (k = 0; k < 25; k++) {
            crsprod_idx_0 += dv[k] * an[k];
          }
          Tp = 2.0 * b_gamma *
               (rt_powd_snf(q, 5.0) * crsprod_idx_2 - crsprod_idx_0);
          /*  T''(x) */
          crsprod_idx_2 = 1.0 / -(sigma - 1.0);
          dv[0] = (double)iv[0] * crsprod_idx_2;
          dv[1] = iv[1];
          for (k = 0; k < 23; k++) {
            dv[k + 2] = (double)iv[k + 2] * powers[k];
          }
          crsprod_idx_0 = 0.0;
          for (k = 0; k < 25; k++) {
            crsprod_idx_0 += dv[k] * an[k];
          }
          dv[0] = (double)iv[0] * (1.0 / crsprod_idx_1);
          dv[1] = iv[1];
          for (k = 0; k < 23; k++) {
            dv[k + 2] = (double)iv[k + 2] * b_powers[k];
          }
          mcrsprd = 0.0;
          for (k = 0; k < 25; k++) {
            mcrsprd += dv[k] * an[k];
          }
          Tpp_tmp = Tp / b_gamma;
          Tpp = Tpp_tmp +
                4.0 * sigma * (crsprod_idx_0 - rt_powd_snf(q, 7.0) * mcrsprd);
          /*  T'''(x) */
          dv[0] = (double)b_iv[0] * (1.0 / crsprod_idx_1 / crsprod_idx_1);
          dv[1] = (double)b_iv[1] * (1.0 / crsprod_idx_1);
          dv[2] = b_iv[2];
          for (k = 0; k < 22; k++) {
            dv[k + 3] = (double)b_iv[k + 3] * b_powers[k];
          }
          crsprod_idx_0 = 0.0;
          for (k = 0; k < 25; k++) {
            crsprod_idx_0 += dv[k] * an[k];
          }
          dv[0] = (double)b_iv[0] * (crsprod_idx_2 / -(sigma - 1.0));
          dv[1] = (double)b_iv[1] * crsprod_idx_2;
          dv[2] = b_iv[2];
          for (k = 0; k < 22; k++) {
            dv[k + 3] = (double)b_iv[k + 3] * powers[k];
          }
          crsprod_idx_2 = 0.0;
          for (k = 0; k < 25; k++) {
            crsprod_idx_2 += dv[k] * an[k];
          }
          mcrsprd = 3.0 * (Tpp - Tpp_tmp) / b_gamma +
                    8.0 * b_gamma * b_gamma *
                        (rt_powd_snf(q, 9.0) * crsprod_idx_0 - crsprod_idx_2);
        } else {
          /*  all other cases */
          /*  compute all substitution functions */
          crsprod_idx_1 = sqrt(fabs(sigma - 1.0));
          z = sqrt(x_tmp * (sigma - 1.0) + 1.0);
          mcrsprd = crsprod_idx_1 * (z - q * b_gamma);
          crsprod_idx_2 = b_gamma * z - q * (sigma - 1.0);
          /*  BUGFIX: (Simon Tardivel) this line is incorrect for E==0 and
           * f+g==0 */
          /*  d  = (E < 0)*(atan2(f, g) + pi*m) + (E > 0)*log( max(0, f + g) );
           */
          /*  it should be written out like so: */
          /*  T(x) */
          if (sigma - 1.0 < 0.0) {
            crsprod_idx_0 =
                rt_atan2d_snf(mcrsprd, crsprod_idx_2) + 3.1415926535897931 * m;
          } else if (sigma - 1.0 == 0.0) {
            crsprod_idx_0 = 0.0;
          } else {
            crsprod_idx_0 = log(fmax(0.0, mcrsprd + crsprod_idx_2));
          }
          crsprod_idx_1 = 2.0 *
                          ((b_gamma - q * z) - crsprod_idx_0 / crsprod_idx_1) /
                          (sigma - 1.0);
          /*   T'(x) */
          mcrsprd = rt_powd_snf(q, 3.0);
          crsprod_idx_2 = 4.0 * mcrsprd;
          Tp = ((4.0 - crsprod_idx_2 * b_gamma / z) -
                3.0 * b_gamma * crsprod_idx_1) /
               (sigma - 1.0);
          /*  T''(x) */
          Tpp_tmp = z * z;
          crsprod_idx_0 = 1.0 - x_tmp * sigma / Tpp_tmp;
          Tpp = ((-4.0 * mcrsprd / z * crsprod_idx_0 - 3.0 * crsprod_idx_1) -
                 3.0 * b_gamma * Tp) /
                (sigma - 1.0);
          /*  T'''(x) */
          mcrsprd = ((crsprod_idx_2 / Tpp_tmp *
                          (crsprod_idx_0 +
                           2.0 * x_tmp * b_gamma / Tpp_tmp * (z - b_gamma)) -
                      8.0 * Tp) -
                     7.0 * b_gamma * Tpp) /
                    (sigma - 1.0);
        }
        /*  new value of xM */
        crsprod_idx_2 = xM;
        xM -= 2.0 * Tp * Tpp / (2.0 * (Tpp * Tpp) - Tp * mcrsprd);
        /*  escape clause */
        if (fmod(iterations, 7.0) != 0.0) {
          xM = (crsprod_idx_2 + xM) / 2.0;
        }
        /*  the method might fail. Exit in that case */
        if (iterations > 25) {
          *exitflag = -2.0;
          exitg2 = 1;
        }
      } else {
        /*  xM should be elliptic (-1 < x < 1) */
        /*  (this should be impossible to go wrong) */
        exitg2 = 2;
      }
    } while (exitg2 == 0);
    if (exitg2 != 1) {
      if ((xM < -1.0) || (xM > 1.0)) {
        *exitflag = -1.0;
      } else {
        /*  corresponding time */
        mcrsprd = LancasterBlanchard(xM, q, m);
        /*  T should lie above the minimum T */
        if (mcrsprd > T) {
          *exitflag = -1.0;
        } else {
          /*  find two initial values for second solution (again with
           * lambda-type patch) */
          /*  --------------------------------------------------------------------------
           */
          /*  some initial values */
          crsprod_idx_2 = T - mcrsprd;
          b_LancasterBlanchard(xM, q, m, &crsprod_idx_1, &Tp, &Tpp);
          /*  first estimate (only if m > 0) */
          if (leftbranch > 0.0) {
            leftbranch =
                sqrt(crsprod_idx_2 /
                     (Tpp / 2.0 + crsprod_idx_2 / ((1.0 - xM) * (1.0 - xM))));
            crsprod_idx_0 = xM + leftbranch;
            crsprod_idx_0 = 4.0 * crsprod_idx_0 / (crsprod_idx_2 + 4.0) +
                            (1.0 - crsprod_idx_0) * (1.0 - crsprod_idx_0);
            leftbranch =
                leftbranch *
                    (1.0 - ((m + 1.0) + (dth - 0.5)) / (0.15 * m + 1.0) *
                               leftbranch *
                               (crsprod_idx_0 / 2.0 +
                                0.03 * leftbranch * sqrt(crsprod_idx_0))) +
                xM;
            /*  first estimate might not be able to yield possible solution */
            if (leftbranch > 1.0) {
              *exitflag = -1.0;
            } else {
              /*  second estimate (only if m > 0) */
              guard1 = true;
            }
          } else {
            if (Td > 0.0) {
              leftbranch =
                  xM -
                  sqrt(mcrsprd / (Tpp / 2.0 -
                                  crsprod_idx_2 * (Tpp / 2.0 / (T0 - mcrsprd) -
                                                   1.0 / (xM * xM))));
            } else {
              mcrsprd = Td / (4.0 - Td);
              crsprod_idx_0 = mcrsprd + 1.7 * sqrt(2.0 * (1.0 - phr));
              if (!(crsprod_idx_0 >= 0.0)) {
                mcrsprd -= sqrt(rt_powd_snf(-crsprod_idx_0, 0.125)) *
                           (mcrsprd + sqrt(-Td / (1.5 * T0 - Td)));
              }
              crsprod_idx_0 = 4.0 / (4.0 - Td);
              leftbranch =
                  mcrsprd * (((m + 1.0) + 0.24 * (dth - 0.5)) /
                                 (0.15 * m + 1.0) * mcrsprd *
                                 (crsprod_idx_0 / 2.0 -
                                  0.03 * mcrsprd * sqrt(crsprod_idx_0)) +
                             1.0);
            }
            /*  estimate might not give solutions */
            if (leftbranch < -1.0) {
              *exitflag = -1.0;
            } else {
              guard1 = true;
            }
          }
        }
      }
    }
  }
  if (guard1) {
    /*  find root of Lancaster & Blancard's function */
    /*  -------------------------------------------- */
    /*  (Halley's method) */
    mcrsprd = rtInf;
    iterations = 0;
    do {
      exitg1 = 0;
      if (fabs(mcrsprd) > 1.0E-12) {
        /*  iterations */
        iterations++;
        /*  compute function value, and first two derivatives */
        b_LancasterBlanchard(leftbranch, q, m, &mcrsprd, &Tp, &Tpp);
        /*  find the root of the *difference* between the */
        /*  function value [T_x] and the required time [T] */
        mcrsprd -= T;
        /*  new value of x */
        crsprod_idx_2 = leftbranch;
        leftbranch -= 2.0 * mcrsprd * Tp / (2.0 * (Tp * Tp) - mcrsprd * Tpp);
        /*  escape clause */
        if (fmod(iterations, 7.0) != 0.0) {
          leftbranch = (crsprod_idx_2 + leftbranch) / 2.0;
        }
        /*  Halley's method might fail */
        if (iterations > 25) {
          *exitflag = -2.0;
          exitg1 = 1;
        }
      } else {
        /*  calculate terminal velocities */
        /*  ----------------------------- */
        /*  constants required for this calculation */
        b_gamma = sqrt(muC * s / 2.0);
        if (c == 0.0) {
          sigma = 1.0;
          mcrsprd = 0.0;
          z = fabs(leftbranch);
        } else {
          sigma = 2.0 * sqrt(q_tmp / (c * c)) * sin(dth / 2.0);
          mcrsprd = (r1 - r2) / c;
          z = sqrt(x_tmp * (leftbranch * leftbranch - 1.0) + 1.0);
        }
        /*  radial component */
        crsprod_idx_1 = q * z;
        crsprod_idx_2 = crsprod_idx_1 - leftbranch;
        crsprod_idx_1 = mcrsprd * (crsprod_idx_1 + leftbranch);
        Tpp_tmp = b_gamma * (crsprod_idx_2 - crsprod_idx_1) / r1;
        crsprod_idx_0 = -b_gamma * (crsprod_idx_2 + crsprod_idx_1) / r2;
        /*  tangential component */
        crsprod_idx_1 = sigma * b_gamma * (z + q * leftbranch);
        crsprod_idx_2 = crsprod_idx_1 / r1;
        mcrsprd = crsprod_idx_1 / r2;
        /*  Cartesian velocity */
        V1[0] = crsprod_idx_2 * th1unit_idx_0 + Tpp_tmp * r1unit_idx_0;
        V2[0] = mcrsprd * th2unit_idx_0 + crsprod_idx_0 * r2unit_idx_0;
        V1[1] = crsprod_idx_2 * th1unit_idx_1 + Tpp_tmp * r1unit_idx_1;
        V2[1] = mcrsprd * th2unit_idx_1 + crsprod_idx_0 * r2unit_idx_1;
        V1[2] = crsprod_idx_2 * th1unit_idx_2 + Tpp_tmp * r1unit_idx_2;
        V2[2] = mcrsprd * th2unit_idx_2 + crsprod_idx_0 * r2unit_idx_2;
        /*  exitflag */
        *exitflag = 1.0;
        /*  (success) */
        /*  also determine minimum/maximum distance */
        /*      a = s/2/(1 - x^2); % semi-major axis */
        /*      extremal_distances = minmax_distances(r1vec, r1, r1vec, r2, dth,
         * a, V1, V2, m, muC); */
        exitg1 = 1;
      }
    } while (exitg1 == 0);
  }
}

/*
 * Arguments    : double u0
 *                double u1
 * Return Type  : double
 */
static double rt_atan2d_snf(double u0, double u1)
{
  double y;
  int b_u0;
  int b_u1;
  if (rtIsNaN(u0) || rtIsNaN(u1)) {
    y = rtNaN;
  } else if (rtIsInf(u0) && rtIsInf(u1)) {
    if (u0 > 0.0) {
      b_u0 = 1;
    } else {
      b_u0 = -1;
    }
    if (u1 > 0.0) {
      b_u1 = 1;
    } else {
      b_u1 = -1;
    }
    y = atan2(b_u0, b_u1);
  } else if (u1 == 0.0) {
    if (u0 > 0.0) {
      y = RT_PI / 2.0;
    } else if (u0 < 0.0) {
      y = -(RT_PI / 2.0);
    } else {
      y = 0.0;
    }
  } else {
    y = atan2(u0, u1);
  }
  return y;
}

/*
 * Arguments    : double u0
 *                double u1
 * Return Type  : double
 */
static double rt_powd_snf(double u0, double u1)
{
  double d;
  double d1;
  double y;
  if (rtIsNaN(u0) || rtIsNaN(u1)) {
    y = rtNaN;
  } else {
    d = fabs(u0);
    d1 = fabs(u1);
    if (rtIsInf(u1)) {
      if (d == 1.0) {
        y = 1.0;
      } else if (d > 1.0) {
        if (u1 > 0.0) {
          y = rtInf;
        } else {
          y = 0.0;
        }
      } else if (u1 > 0.0) {
        y = 0.0;
      } else {
        y = rtInf;
      }
    } else if (d1 == 0.0) {
      y = 1.0;
    } else if (d1 == 1.0) {
      if (u1 > 0.0) {
        y = u0;
      } else {
        y = 1.0 / u0;
      }
    } else if (u1 == 2.0) {
      y = u0 * u0;
    } else if ((u1 == 0.5) && (u0 >= 0.0)) {
      y = sqrt(u0);
    } else if ((u0 < 0.0) && (u1 > floor(u1))) {
      y = rtNaN;
    } else {
      y = pow(u0, u1);
    }
  }
  return y;
}

/*
 * lambertMR.m - Lambert's problem solver for all possible transfers
 *    (multi-revolution transfer included).
 *
 *  PROTOTYPE:
 *    [A,P,E,ERROR,VI,VF,TPAR,THETA] =
 * lambertMR(RI,RF,TOF,MU,orbitType,Nrev,Ncase,optionsLMR)
 *
 *  DESCRIPTION:
 *    Lambert's problem solver for all possible transfers:
 *        1- zero-revolution (for all possible types of orbits: circles,
 * ellipses, parabolas and hyperbolas) 2- multirevolution case 3- inversion of
 * the motion
 *
 *    1- ZERO-REVOLUTION LAMBERT'S PROBLEM
 *
 *    For the solution of Lambert's problem with number of revolution = 0 the
 *    subroutine by Chris D'Souza is included here.
 *    This subroutine is a Lambert algorithm which given two radius vectors
 *    and the time to get from one to the other, it finds the orbit
 *    connecting the two. It solves the problem using a new algorithm
 *    developed by R. Battin. It solves the Lambert problem for all possible
 *    types of orbits (circles, ellipses, parabolas and hyperbolas).
 *    The only singularity is for the case of a transfer angle of 360 degrees,
 *    which is a rather obscure case.
 *    It computes the velocity vectors corresponding to the given radius
 *    vectors except for the case when the transfer angle is 180 degrees
 *    in which case the orbit plane is ambiguous (an infinite number of
 *    transfer orbits exist).
 *
 *    2- MULTIREVOLUTION LAMBERT'S PROBLEM
 *
 *    For the solution of Lambert's problem with Nrev>0 number of revolution,
 *    Battin's formulation has been extended to accomodate N-revolution
 *    transfer orbits, by following the paper: "Using Battin Mathod to obtain
 *    Multiple-revolution Lambert's Solutions" by Shen and Tsiotras.
 *
 *    When Nrev>0 the possible orbits are just ellipses.
 *    If 0<=Nrev<=Nmax, there are two Nrev-revolution transfer orbits.
 *    These two transfer orbits have different semi-major axis and they may
 *    be all combinations of large-e and small-e transfer orbits.
 *    The Original Successive Substitution Method by Battin converges to one
 *    of the two possible solution with a viable initial guest, however it
 *    diverges from the other one. Then a Reversed Successive Substitution is
 *    used to converge to the second solution.
 *    A procedure is implemented in order to guarantee to provide initial
 *    guesses in the convergence region. If Nrew exceeds the maximum number
 *    of revolution an ERROR is given:
 *    warning('off','lambertMR:SuccessiveSubstitutionDiverged') to take out
 *    the warnings or use optionsLMR(1) = 0.
 *
 *    3- INVERSION OF THE MOTION
 *
 *    Direct or retrograde option can be selected for the transfer.
 *
 *    The algorithm computes the semi-major axis, the parameter (semi-latus
 *    rectum), the eccentricity and the velocity vectors.
 *
 *    NOTE: If ERROR occurs or the 360 or 180 degree transfer case is
 *    encountered.
 *
 *  INPUT:
 *  RI[3]           Vector containing the initial position in Cartesian
 *                    coordinates [L].
 *  RF[3]           Vector containing the final position vector in
 *                    Cartesian coordinates [L].
 *  TOF[1]          Transfer time, time of flight [T].
 *    MU[1]           Planetary constant of the planet (mu = mass * G) [L^3/T^2]
 *  orbitType[1]    Logical variable defining whether transfer is
 *                        0: direct transfer from R1 to R2 (counterclockwise)
 *                        1: retrograde transfer from R1 to R2 (clockwise)
 *  Nrev[1]         Number of revolutions.
 *                    if Nrev = 0 ZERO-REVOLUTION transfer is calculated
 *                    if Nrev > 0 two transfers are possible. Ncase should be
 *                           defined to select one of the two.
 *  Ncase[1]        Logical variable defining the small-a or large-a option
 *                    in case of Nrev>0:
 *                        0: small-a option
 *                        1: large-a option
 *  optionsLMR[1] lambertMR options:
 *                     optionsLMR(1) = display options:
 *                                     0: no display
 *                                     1: warnings are displayed only when
 *                                        the algorithm does not converge
 *                                     2: full warnings displayed
 *
 *  OUTPUT:
 *  A[1]        Semi-major axis of the transfer orbit [L].
 *   P[1]        Semi-latus rectum of the transfer orbit [L].
 *    E[1]        Eccentricity of the transfer orbit.
 *  ERROR[1] Error flag
 *                    0: No error
 *                    1: Error, routine failed to converge
 *                    -1: 180 degrees transfer
 *                    2:  360 degrees transfer
 *                    3:  the algorithm doesn't converge because the number
 *                        of revolutions is bigger than Nrevmax for that TOF
 *                    4:  Routine failed to converge, maximum number of
 *                        iterations exceeded.
 *  VI[3]       Vector containing the initial velocity vector in Cartesian
 *                coordinates [L/T].
 *  VT[1]  Vector containing the final velocity vector in Cartesian
 *                coordinates [L/T].
 *  TPAR[1]  Parabolic flight time between RI and RF [T].
 *  THETA[1] Transfer angle [radians].
 *
 *  NOTE: The semi-major axis, positions, times, and gravitational parameter
 *        must be in compatible units.
 *
 *  CALLED FUNCTIONS:
 *    qck, h_E (added at the bottom of this file)
 *
 *  FUTURE DEVELOPMENT:
 *    - 180 degrees transfer indetermination
 *    - 360 degrees transfer singularity
 *    - Nmax number of max revolution for a given TOF:
 *      work in progress - Camilla Colombo
 *
 *  -------------------------------------------------------------------------
 *
 * Arguments    : const double RI[3]
 *                const double RF[3]
 *                double TOF
 *                double MU
 *                double Nrev
 *                double Ncase
 *                double VI[3]
 *                double VF[3]
 * Return Type  : void
 */
void lambertMR_vA(const double RI[3], const double RF[3], double TOF, double MU,
                  double Nrev, double Ncase, double VI[3], double VF[3])
{
  double b_RF[3];
  double b_RI[3];
  double C;
  double CR_idx_2;
  double CTH;
  double L;
  double L1_tmp;
  double LAMBDA;
  double M;
  double RFM;
  double RFM2;
  double RIM;
  double RIM2;
  double S;
  double S11;
  double absxk;
  double d;
  double scale;
  double t;
  int CHECKFEAS;
  int GAMMA_tmp;
  int N;
  int N1;
  if (!isInitialized_lambertMR_vA) {
    lambertMR_vA_initialize();
  }
  if (Nrev == 0.0) {
    /*  ZERO REVOLUTIONS */
    /*  Maximum number of iterations for loops */
    /*  Reset */
    /*  ---------------------------------- */
    /*  Compute the vector magnitudes and various cross and dot products */
    RIM2 = (RI[0] * RI[0] + RI[1] * RI[1]) + RI[2] * RI[2];
    RFM2 = (RF[0] * RF[0] + RF[1] * RF[1]) + RF[2] * RF[2];
    RIM = sqrt(RIM2);
    RFM = sqrt(RFM2);
    C = RIM * RFM;
    CTH = ((RI[0] * RF[0] + RI[1] * RF[1]) + RI[2] * RF[2]) / C;
    CR_idx_2 = RI[0] * RF[1] - RF[0] * RI[1];
    scale = 3.3121686421112381E-170;
    absxk = fabs(RI[1] * RF[2] - RF[1] * RI[2]);
    if (absxk > 3.3121686421112381E-170) {
      S11 = 1.0;
      scale = absxk;
    } else {
      t = absxk / 3.3121686421112381E-170;
      S11 = t * t;
    }
    absxk = fabs(RF[0] * RI[2] - RI[0] * RF[2]);
    if (absxk > scale) {
      t = scale / absxk;
      S11 = S11 * t * t + 1.0;
      scale = absxk;
    } else {
      t = absxk / scale;
      S11 += t * t;
    }
    absxk = fabs(CR_idx_2);
    if (absxk > scale) {
      t = scale / absxk;
      S11 = S11 * t * t + 1.0;
      scale = absxk;
    } else {
      t = absxk / scale;
      S11 += t * t;
    }
    S11 = scale * sqrt(S11);
    t = S11 / C;
    if (CR_idx_2 < 0.0) {
      /*  always direct transfer */
      t = -t;
    }
    scale = rt_atan2d_snf(t, CTH);
    C = scale;
    if (scale < 0.0) {
      C = -1.0;
    } else if (scale > 0.0) {
      C = 1.0;
    } else if (scale == 0.0) {
      C = 0.0;
    }
    if (!(0.0 > C)) {
      C = 0.0;
    }
    scale -= 6.2831853071795862 * (trunc(scale / 6.2831853071795862) + C);
    if ((scale == 6.2831853071795862) || (scale == 0.0)) {
      VI[0] = 0.0;
      VF[0] = 0.0;
      VI[1] = 0.0;
      VF[1] = 0.0;
      VI[2] = 0.0;
      VF[2] = 0.0;
    } else {
      if (t < 0.0) {
        t = -1.0;
      } else if (t > 0.0) {
        t = 1.0;
      } else if (t == 0.0) {
        t = 1.0;
      }
      /*  ---------------------------------- */
      /*  Compute the chord and the semi-perimeter */
      C = sqrt((RIM2 + RFM2) - 2.0 * RIM * RFM * CTH);
      S = ((RIM + RFM) + C) / 2.0;
      S11 = S - C;
      C = S11 / S;
      LAMBDA = t * sqrt(C);
      d = 4.0 * TOF * LAMBDA;
      if ((d == 0.0) || (fabs(C) < 1.0E-14)) {
        VI[0] = 0.0;
        VF[0] = 0.0;
        VI[1] = 0.0;
        VF[1] = 0.0;
        VI[2] = 0.0;
        VF[2] = 0.0;
      } else {
        /*  ---------------------------------- */
        /*  Compute L carefully for transfer angles less than 5 degrees */
        if (scale * 180.0 / 3.1415926535897931 <= 5.0) {
          absxk = sin(scale / 4.0);
          C = tan(2.0 *
                  (atan(rt_powd_snf(RFM / RIM, 0.25)) - 0.78539816339744828));
          C = absxk * absxk + C * C;
          L = C / (C + cos(scale / 2.0));
        } else {
          absxk = (1.0 - LAMBDA) / (LAMBDA + 1.0);
          L = absxk * absxk;
        }
        M = 8.0 * MU * (TOF * TOF) /
            (rt_powd_snf(S, 3.0) * rt_powd_snf(LAMBDA + 1.0, 6.0));
        L1_tmp = (1.0 - L) / 2.0;
        CHECKFEAS = 0;
        /*  ---------------------------------- */
        /*  Initialize values of y, n, and x */
        RIM2 = 1.0;
        N = 0;
        N1 = 0;
        if (TOF - sqrt(2.0 / MU) / 3.0 *
                      (rt_powd_snf(S, 1.5) - t * rt_powd_snf(S11, 1.5)) <=
            0.001) {
          RFM2 = 0.0;
        } else {
          RFM2 = L;
        }
        CTH = -1.0E+8;
        /*  ---------------------------------- */
        /*  Begin iteration */
        while ((fabs(RFM2 - CTH) >= fabs(CTH) * 1.0E-14 + 1.0E-14) &&
               (N <= 2000)) {
          N++;
          CTH = RFM2;
          C = sqrt(RFM2 + 1.0);
          C = RFM2 / ((C + 1.0) * (C + 1.0));
          CHECKFEAS = 1;
          /*  ---------------------------------- */
          /*  Compute x by means of an algorithm devised by */
          /*  Gauticci for evaluating continued fractions by the */
          /*  'Top Down' method */
          scale = 1.0;
          t = 1.0;
          absxk = 1.0;
          N1 = 3;
          while ((fabs(t) > 1.0E-14) && (N1 - 3 <= 2000)) {
            N1++;
            GAMMA_tmp = N1 * N1;
            scale = 1.0 / ((double)GAMMA_tmp / (4.0 * (double)GAMMA_tmp - 1.0) *
                               C * scale +
                           1.0);
            t *= scale - 1.0;
            absxk += t;
          }
          S11 = 8.0 * (sqrt(RFM2 + 1.0) + 1.0) /
                (1.0 / ((C + 5.0) + 9.0 * C / 7.0 * absxk) + 3.0);
          /*  ---------------------------------- */
          /*  Compute H1 and H2 */
          if (N == 1) {
            absxk = L + RFM2;
            C = ((2.0 * RFM2 + 1.0) + L) *
                ((3.0 * S11 + RFM2 * S11) + 4.0 * RFM2);
            CR_idx_2 = absxk * absxk * ((S11 + 1.0) + 3.0 * RFM2) / C;
            C = M * ((S11 + RFM2) - L) / C;
          } else {
            C = sqrt(L1_tmp * L1_tmp + M / (RIM2 * RIM2));
            absxk = C - L1_tmp;
            C = 2.0 * C * ((3.0 * S11 + RFM2 * S11) + 4.0 * RFM2);
            CR_idx_2 = absxk * absxk * ((S11 + 1.0) + 3.0 * RFM2) / C;
            C = M * ((S11 + RFM2) - L) / C;
          }
          C = 27.0 * C / (4.0 * rt_powd_snf(CR_idx_2 + 1.0, 3.0));
          S11 = sqrt(C + 1.0);
          t = -C / (2.0 * (S11 + 1.0));
          /*  ---------------------------------- */
          /*  Compute the continued fraction expansion K(u) */
          /*  by means of the 'Top Down' method */
          scale = 1.0;
          C = 1.0;
          absxk = 1.0;
          N1 = 0;
          while ((N1 < 2000) && (fabs(C) >= 1.0E-14)) {
            if (N1 == 0) {
              scale = 1.0 / (1.0 - 0.14814814814814814 * t * scale);
              C *= scale - 1.0;
              absxk += C;
            } else {
              GAMMA_tmp = N1 << 2;
              scale =
                  1.0 /
                  (1.0 - (double)(((3 * N1 + 1) << 1) * (6 * N1 - 1)) /
                             (double)(9 * (GAMMA_tmp - 1) * (GAMMA_tmp + 1)) *
                             t * scale);
              C *= scale - 1.0;
              absxk += C;
              scale =
                  1.0 /
                  (1.0 - (double)(((3 * N1 + 2) << 1) * (6 * N1 + 1)) /
                             (double)(9 * ((N1 << 2) + 1) * (GAMMA_tmp + 3)) *
                             t * scale);
              C *= scale - 1.0;
              absxk += C;
            }
            N1++;
          }
          absxk /= 3.0;
          RIM2 = (CR_idx_2 + 1.0) / 3.0 *
                 (S11 / (1.0 - 2.0 * t * (absxk * absxk)) + 2.0);
          /*  Y = Ycami */
          RFM2 = sqrt(L1_tmp * L1_tmp + M / (RIM2 * RIM2)) - (L + 1.0) / 2.0;
        }
        /*  ---------------------------------- */
        /*  Compute the velocity vectors */
        if (CHECKFEAS == 0) {
          VI[0] = 0.0;
          VF[0] = 0.0;
          VI[1] = 0.0;
          VF[1] = 0.0;
          VI[2] = 0.0;
          VF[2] = 0.0;
        } else if ((N1 >= 2000) || (N >= 2000)) {
          VI[0] = 0.0;
          VF[0] = 0.0;
          VI[1] = 0.0;
          VF[1] = 0.0;
          VI[2] = 0.0;
          VF[2] = 0.0;
        } else {
          C = (LAMBDA + 1.0) * (LAMBDA + 1.0);
          CR_idx_2 = C / d;
          S11 = RIM2 * (RFM2 + 1.0);
          scale = M * S * C / S11;
          absxk = S11 * (RI[0] - RF[0]);
          VI[0] = -CR_idx_2 * (absxk - scale * RI[0] / RIM);
          t = S11 * (RI[1] - RF[1]);
          VI[1] = -CR_idx_2 * (t - scale * RI[1] / RIM);
          C = S11 * (RI[2] - RF[2]);
          VI[2] = -CR_idx_2 * (C - scale * RI[2] / RIM);
          VF[0] = -CR_idx_2 * (absxk + scale * RF[0] / RFM);
          VF[1] = -CR_idx_2 * (t + scale * RF[1] / RFM);
          VF[2] = -CR_idx_2 * (C + scale * RF[2] / RFM);
        }
      }
    }
  } else {
    /*  MULTIREVOLUTIONS */
    if (Ncase == 0.0) {
      RIM2 = -Nrev;
    } else {
      RIM2 = Nrev;
    }
    b_RI[0] = RI[0];
    b_RI[1] = RI[1];
    b_RI[2] = RI[2];
    b_RF[0] = RF[0];
    b_RF[1] = RF[1];
    b_RF[2] = RF[2];
    lambert(b_RI, b_RF, TOF, RIM2, MU, VI, VF);
  }
}

/*
 * preload the factors [an]
 *  (25 factors is more than enough for 16-digit accuracy)
 *
 * Arguments    : void
 * Return Type  : void
 */
void sigmax_init(void)
{
  static const double dv[25] = {0.4,
                                0.2142857142857143,
                                0.0462962962962963,
                                0.006628787878787879,
                                0.00072115384615384609,
                                6.36574074074074E-5,
                                4.7414799253034548E-6,
                                3.0594063283208018E-7,
                                1.74283640925506E-8,
                                8.8924773311095776E-10,
                                4.1101115319865317E-11,
                                1.7367093848414581E-12,
                                6.7597672400414259E-14,
                                2.4391233866140258E-15,
                                8.2034116145380068E-17,
                                2.583771576869575E-18,
                                7.6523313279767163E-20,
                                2.138860629743989E-21,
                                5.6599594511655524E-23,
                                1.4221048338173659E-24,
                                3.4013984832723061E-26,
                                7.7625443047741554E-28,
                                1.693916882090479E-29,
                                3.54129500676686E-31,
                                7.1053361878044024E-33};
  memcpy(&an[0], &dv[0], 25U * sizeof(double));
}

/*
 * File trailer for lambertMR_vA.c
 *
 * [EOF]
 */
