function [eta, visited, DV] = computeHeuristic_BS(as, tas, Vsc_Asteroid, astREACH)

muSun  = astroConstants(4);
muMars = 42828.0184128135;
RMars  = 3389.92;

astVIS = [as tas Vsc_Asteroid].*ones(size(astREACH,1), 5);

if as < 1e98 || tas < 1e98

[rr, vv] = EphSS_car(as, tas);

DV      = zeros(size(astREACH,1), 1);
tempVis = zeros(size(astREACH,1), 6);

for indi = 1:size(astREACH,1)

    % Arrival
    [sA(1:3), sA(4:6)] = EphSS_car(astREACH(indi,1), astREACH(indi,2));

    % Options
    multirev = 0;
    energy = 0;
    [~, ~, ~, ~, vI, vF, ~, ~] = ...
        lambertMR(rr, sA(1:3), (astREACH(indi,2)-tas)*86400, muSun, 0, multirev, energy, 0);

    DV(indi,1) = norm(vI - Vsc_Asteroid);

    Vsc_AsteroidNEW = vF;
    
    if astREACH(indi,1) == 4

        % Applying SwingBy Manoeuvre at Mars
        % Mars Swing-by

        VArr2Mars = vF;
        vinf1     = VArr2Mars-sA(4:6);

        % As Rosetta, CASTAway should aim at a 250 km altitude fly-by as a maximum
        % close encounter.
        rpFB   = RMars + 250;

        n_r = cross(vinf1,sA(4:6)); % Reference vector
        n_r = n_r/norm(n_r);

        gamma = 0;

        vinf2 = swingby(vinf1, rpFB, muMars, gamma, n_r)';

        vDepSW_mars = vinf2 + sA(4:6);

        % Departure conditions after Mars Swing By
        Vsc_AsteroidNEW = vDepSW_mars;

    end

    tempVis(indi,:) = [astREACH(indi,1) astREACH(indi,2) Vsc_AsteroidNEW DV(indi,1)];
    
end

eta = 1./DV;

visited = [astVIS tempVis];

else
    
    eta     = [];
    DV      = [];
    visited = [];
    
end

end