function [OUTPUT] = generateSCORES(INPUT)

disp('Generating the triplets and solving the Lambert arcs...');

EPH      = INPUT.EPH;

muSun    = 132712440018; % --> gravitational parameter of the Sun (km3/s2)

astLISTe = INPUT.astLISTe;
COUPLES  = INPUT.COUPLES;
tripNum  = INPUT.tripletsNumVinf;
VDEP     = INPUT.VDS;

% --> generate the big matrix
SCORES   = 1e99.*ones(size(COUPLES,1),size(astLISTe,1));
TRIPLETS = zeros(tripNum,6);
VDS      = zeros(tripNum,6);
VAS      = zeros(tripNum,6);
DV       = zeros(tripNum,1);
ind      = 1;

tic
for indi = 1:size(COUPLES,1)
    
%     indi/size(COUPLES,1)*100
        
    asp = COUPLES(indi,1);
    tp  = COUPLES(indi,2);
    
    vdp = VDEP(indi,:);
    
    va1 = COUPLES(indi,3:5);
    as1 = COUPLES(indi,6);
    t1  = COUPLES(indi,7);
        
    rr1 = EPH(astLISTe(:,1) == as1,3:5);
    vv1 = EPH(astLISTe(:,1) == as1,6:8);

    for indj = 1:size(astLISTe,1)
                
        as2 = astLISTe(indj,1);
        t2  = astLISTe(indj,2);
        
        if as2 ~= asp && as2 ~= as1 && t2 > t1 % --> is a new visited asteroid
        
            rr2 = EPH(astLISTe(:,1) == as2,3:5); % --> extract the ephemerides for the asteroid

            % --> solve the Lambert problem (zero revs)
            [vd1, va2] = lambertMR_vA(rr1, rr2, (t2 - t1)*86400, muSun, 0, 0);

            if as1 == 4
                dv = find_DV_defect(va1 - vv1, vd1 - vv1, as1);
            else
                dv = norm(vd1 - va1);
            end

            SCORES(indi,indj) = dv;                     % --> save the scores info (from all to all)
            TRIPLETS(ind,:)   = [asp tp as1 t1 as2 t2]; % --> save the triplet info
            VDS(ind,:)        = [vdp vd1];              % --> departing velocities (km/s)
            VAS(ind,:)        = [va1 va2];              % --> arrival velocities (km/s)
            DV(ind,:)         = dv;                     % --> dvs (km/s)
            ind               = ind + 1;
        
        end
        
    end
end
t2 = toc; % --> how long does it take to run the Lambert arcs?

TRIPLETS = TRIPLETS(~all(TRIPLETS == 0, 2),:); % --> eliminate rows all equal to zero
VDS      = VDS(~all(VDS == 0, 2),:);           % --> eliminate rows all equal to zero
VAS      = VAS(~all(VAS == 0, 2),:);           % --> eliminate rows all equal to zero
DV       = DV(~all(DV == 0, 2),:);             % --> eliminate rows all equal to zero

% --> save the OUTPUT
OUTPUT.SCORES           = SCORES;
OUTPUT.VDS              = VDS;
OUTPUT.VAS              = VAS;
OUTPUT.DV               = DV;
OUTPUT.TRIPLETS         = TRIPLETS;
OUTPUT.COUPLES          = COUPLES;
OUTPUT.EPH              = EPH;
OUTPUT.astLISTe         = astLISTe;

OUTPUT.Time_SCORES_Mins = t2/60;    % --> how long does it take to run the Lambert arcs?

OUTPUT.TripletsNumTot  = INPUT.tripletsNumTot;
OUTPUT.TripletsNumVinf = INPUT.tripletsNumVinf;
OUTPUT.TripletsNumDVp  = size(TRIPLETS,1);

OUTPUT.tols = INPUT.tols;

disp('Done!!!');

end