function [dv, vvin2] = nextLegs_Seqs(as1, vvin, as2, EPH, OptionsMultiRev)

% This function computes successive legs not considering Mars as another
% asteroid
% 
% INPUT : 
% - as1  : ID of the first asteroid
% - vvin : incoming velocity vector at the first asteroid
% - as2  : ID of the second asteroid
% - EPH  : ephemerides matrix
% 
% OUTPUT :
% - dv    : DV between the two asteroids
% - vvin2 : incoming velocity at the next asteroid

muSun = 132712440018; % --> grav. param. of the Sun

idas1 = find(EPH(:,1) == as1);
idas2 = find(EPH(:,1) == as2);
idm   = find(EPH(:,1) == 4);

t1  = EPH(idas1, 2);
t2  = EPH(idas2, 2);

rr1 = EPH(idas1, 3:5);
rr2 = EPH(idas2, 3:5);

if idm < idas1 || idm > idas2 % --> simple Lambert arc between the two asteroids
    
    [dv, ~, vvin2] = lambert_MR_opts(vvin, rr1, rr2, (t2 - t1)*86400, muSun, OptionsMultiRev);
    
else % --> DV defect (i.e. Mars flyby)
    
    tM  = EPH(idm, 2);
    rrm = EPH(idm, 3:5);
    vvm = EPH(idm, 6:8);
    
    % --> from 1st asteroid to Mars --> only 1 feasible solution
    [dv1, ~, vvinm] = lambert_MR_opts(vvin, rr1, rrm, (tM - t1)*86400, muSun, OptionsMultiRev);
        
    % --> from Mars to 2nd asteroid --> only 1 feasible solution
    [dv2, ~, vvin2] = lambert_MR_opts_flyby(vvinm, vvm, 4, rrm, rr2, (t2 - tM)*86400, muSun, OptionsMultiRev);
        
    dv = dv1 + dv2;
    
end

end
