function [sol_p2, fval_p2] = optimize_AstSeq_GA(INPUT, fval_p1, inds, folder)

st               = INPUT.st;
tE               = INPUT.tE;
tM               = INPUT.tM;
MatrixSummary_BC = INPUT.MatrixSummary_BC;
astMax           = INPUT.astMax;

muSun         = 132712440018;

Times         = findTimes_seq(st, tE, tM, MatrixSummary_BC);
CurrentSearch = astMax - 1;
Sequence      = st;

% --> cost function
y = @(x)Transfer_CASTAway_dsmEM_MarsFB(Sequence,... 
    x(1), x(2:CurrentSearch+2), x(CurrentSearch+3:CurrentSearch+5), muSun);

% --> lower/upper bounds
tdepEarth = Times(1);
TOFs      = diff(Times);
LB        = [tdepEarth-50 (TOFs-50).*((TOFs-50)>=0) 0  1.06 0];
UB        = [tdepEarth+50  TOFs+100                2*pi 10 0.5];
nres      = length(LB); % --> number of variables to be optimized

% --> options for GA
PopulationSize    = 600;
% InitialPopulation = initialPopulation(PopulationSize, nres, tdepEarth, TOFs);
InitialPopulation = [];
GenLimit          = 800;
StallGenLimit_VAL = 20;
maxtime           = 300;
tolfun            = 1e-6;
optionsga         = options_GA(GenLimit, PopulationSize, InitialPopulation, ...
                        tolfun, StallGenLimit_VAL, maxtime);

% --> optimization with GA
[sol_p2, fval_p2] = ga(@(x)y(x), nres, [], [], [], [], LB, UB, [], [], optionsga);

struc.sol_p2  = sol_p2;
struc.fval_p2 = fval_p2;
struc.fval_p1 = fval_p1;
struc.inds    = inds;
struc.seq     = st;

% --> create the folder for saving the results
if nargin > 3 && ~isempty(folder) % --> then the folder is specified
    if exist(folder(2:end), 'dir') == 7 % --> then the folder exists on the current path
        name2 = [folder '\optimized_' num2str(inds) '.mat'];
    else % --> then the folder does not exist on the current path
        mkdir(folder(2:end)); % --> create the folder in the current path
        name2 = [folder '\optimized_' num2str(inds) '.mat'];
    end
else % --> then the folder is not specified --> save in '\results'
    if exist('results', 'dir') == 7 % --> then the folder '\results' exists on the current path
        name2 = ['\results\optimized_' num2str(inds) '.mat'];
    else % --> then the folder '\results' does not exist on the current path
        mkdir('results');
        name2 = ['\results\optimized_' num2str(inds) '.mat'];
    end
end
name = [pwd name2];

save(name, 'struc');

end