function [OUTPUT] = pruneDSMp(OUTPUT)

disp('Pruning w.r.t. the partial DV (i.e. on a single leg)...');

muSun    = 132712440018;

tols     = OUTPUT.tols;
tolDSMp  = tols(3);

TRIPLETS = OUTPUT.TRIPLETS;
VAS      = OUTPUT.VAS;
VDS      = OUTPUT.VDS;
DV       = OUTPUT.DV;
EPH      = OUTPUT.EPH;

% --> prune those with too high DV
TRIPLETS(DV > tolDSMp,:) = [];
VDS(DV > tolDSMp,:)      = [];
VAS(DV > tolDSMp,:)      = [];
DV(DV > tolDSMp,:)       = [];

% --> prune the dead ends (i.e. after the Earth departure, those not having any asteroid available)
LEGS        = TRIPLETS(TRIPLETS(:,1) == 3, :); % --> extract the ones departing at Earth
indx_to_del = zeros(size(LEGS,1),1);
for indi = 1:size(LEGS,1)
    as1 = LEGS(indi,3); % --> middle asteroid
    as2 = LEGS(indi,5); % --> current asteroid
    if isempty(find(TRIPLETS(:,1) == as1 & TRIPLETS(:,3) == as2)) 
        indx_to_del(indi) = indi; % --> delete the dead ends
    end
end
indx_to_del = indx_to_del(~all(indx_to_del == 0, 2),:); % --> eliminate rows all equal to zero

% --> save the output
OUTPUT.VDS              = VDS;
OUTPUT.VAS              = VAS;
OUTPUT.DV               = DV;
OUTPUT.TRIPLETS         = TRIPLETS;

% --> eliminate the dead ends
OUTPUT.TRIPLETS(indx_to_del,:) = [];
OUTPUT.VDS(indx_to_del,:)      = [];
OUTPUT.VAS(indx_to_del,:)      = [];
OUTPUT.DV(indx_to_del,:)       = [];

% --> save the OUTPUT
OUTPUT.TripletsNumTot      = OUTPUT.TripletsNumTot;
OUTPUT.TripletsNumVinf     = OUTPUT.TripletsNumVinf;
OUTPUT.TripletsNumDVp      = size(TRIPLETS,1);
OUTPUT.TripletsNumDeadEnds = size(OUTPUT.TRIPLETS,1);

% --> extract the ones departing at Earth
TRIPLETS = OUTPUT.TRIPLETS;
DV       = OUTPUT.DV;
LEGS     = TRIPLETS(TRIPLETS(:,1) == 3, :);
DVS      = DV(TRIPLETS(:,1) == 3, :);

OUTPUT.DEP = LEGS;
dv         = zeros(size(LEGS,1),1);
for indi = 1:size(LEGS,1)
   
    as1 = LEGS(indi,1);
    t1  = LEGS(indi,2);
    
    as2 = LEGS(indi,3);
    t2  = LEGS(indi,4);
    
    rr1 = EPH(EPH(:,1) == as1, 3:5);
    vv1 = EPH(EPH(:,1) == as1, 6:8);
    
    rr2 = EPH(EPH(:,1) == as2, 3:5);
    
    % --> solve the Lambert problem
    [vd1] = lambertMR_vA(rr1, rr2, (t2 - t1)*86400, muSun, 0, 0);
    
    dv(indi,1) = norm(vd1 - vv1);

end

OUTPUT.vinfD = dv;

LEGS(:,2)   = OUTPUT.vinfD; % --> save the DV (rather than the TOF)
LEGS(:,4)   = DVS;          % --> save the DV (rather than the TOF)
LEGS(:,end) = [];

OUTPUT.DEP  = LEGS;

% out = OUTPUT;
% 
% % --> re-arrange the OUTPUT
% OUTPUT.SCORES   = out.SCORES;
% OUTPUT.VDS      = out.VDS;
% OUTPUT.VAS      = out.VAS;
% OUTPUT.DV       = out.VDS;
% OUTPUT.TRIPLETS = out.TRIPLETS;
% OUTPUT.COUPLES  = out.COUPLES;
% 
% OUTPUT.Time_SCORES_Mins    = out.Time_SCORES_Mins;
% OUTPUT.TripletsNumTot      = out.TripletsNumTot;
% OUTPUT.TripletsNumVinf     = out.TripletsNumVinf;
% OUTPUT.TripletsNumDVp      = out.TripletsNumDVp;
% OUTPUT.TripletsNumDeadEnds = out.TripletsNumDeadEnds;
% 
% OUTPUT.EPH      = out.EPH;
% OUTPUT.astLISTe = out.astLISTe;
% OUTPUT.tols     = out.tols;
% OUTPUT.DEP      = out.DEP;
% OUTPUT.vinfD    = out.vinfD;

disp('Done!!!');

end