function [INPUT, triplets, COUPLES] = pruneVinfDep_Triplets(INPUT)

disp('Pruning w.r.t. the departing infinity velocity...');

muSun    = 132712440018;
astLISTe = INPUT.astLISTe;
tols     = INPUT.tols;
tolVINFD = tols(1);
EPH      = INPUT.EPH;

couples   = nchoosek(astLISTe(:,1),2);    % --> find all the possible couples
couples   = [couples zeros(size(couples,1),3)];
triplets  = nchoosek(astLISTe(:,1),3); % --> find all the possible triplets

INPUT.tripletsNumTot = size(triplets,1);

% --> eliminate those with too high departing vinf
idxs_to_del = zeros(size(couples,1),1);
T1          = zeros(size(couples,1),1);
T2          = zeros(size(couples,1),1);
VDS         = zeros(size(couples,1),3);
tic
for indi = 1:size(couples,1)
   
    as1 = couples(indi,1);
    as2 = couples(indi,2);
    
    ind1 = find(astLISTe(:,1) == as1);
    ind2 = find(astLISTe(:,1) == as2);
        
    T1(indi,1) = EPH(ind1,2);
    T2(indi,1) = EPH(ind2,2);
    
    rr1 = EPH(ind1,3:5);
    vv1 = EPH(ind1,6:8);
    rr2 = EPH(ind2,3:5);
        
    % --> solve the Lambert problem (zero revs)
    [vI, vF] = lambertMR_vA(rr1, rr2, (T2(indi,1) - T1(indi,1))*86400, muSun, 0, 0);

    if as1 == 3
        vinfd  = norm(vI - vv1); % --> departing infinity velocity
        if vinfd > tolVINFD
           idxs_to_del(indi,1) = indi; 
        end
    end
    
    couples(indi,3:end) = vF;
    VDS(indi,:)         = vI;

end
idxs_to_del            = idxs_to_del(~all(idxs_to_del == 0, 2),:); % --> eliminate rows all equal to zero
couples_to_del         = couples(idxs_to_del,:);
couples(idxs_to_del,:) = [];
T1(idxs_to_del,:)      = [];
T2(idxs_to_del,:)      = [];
t2 = toc;

% --> save the couples info
COUPLES = [couples(:,1) T1 couples(:,3:end) couples(:,2) T2];

A       = triplets(:,1:2);
B       = couples_to_del(:,1:2);
C       = intersect(A,B,'rows');
index_A = find(ismember(A,C,'rows'));

triplets(index_A,:) = [];

INPUT.COUPLES             = COUPLES;
INPUT.tripletsNumVinf     = size(triplets,1);
INPUT.VDS                 = VDS;
INPUT.Time_PruneVinf_Mins = t2/60;

disp('Done!!!');

end