function [Tours] = seriesMethod(ASTEROIDS, tolerances, tE)

% compute the series method for the MAR problem given some tolerances
% it is a Beam Search with Beam Width = 1

vInfDep_TOL = tolerances(1);
DSM_TOL     = tolerances(2);

[B,I]     = sort(ASTEROIDS(:,2));
astLIST   = ASTEROIDS(I,:);

ephNEO('load','ephNEO_CATABC.txt');

% check all the asteroids
bw   = 1;

asSAVE = [];

INDSTR = 0;

% perform the Series Method search
for indj = 2:size(ASTEROIDS,1)

as  = ASTEROIDS(indj,1);
tas = ASTEROIDS(indj,2);

% compute the first leg
[Vsc_Asteroid, dv, ~] = firstLeg([3 as], [tE tas]);

% prune infinity velocity at the departure
if dv < vInfDep_TOL

% check all the reachable asteroids
[astREACH] = generateAllReachablePoints(as, tas, astLIST);

tour = [as tas Vsc_Asteroid dv];

val = 0;

for indi = 1:12

    if val == 0

        % compute the heuristic and the visited segments
        [~, visited, ~] = computeHeuristic(as, tas, Vsc_Asteroid, astREACH);

        % compute the next point
        [asNext, tasNext, Vsc_Asteroid_Next, dv_Next, val] = computeNextPoint(visited, bw);

        % build the tour
        tour = [tour; [asNext, tasNext, Vsc_Asteroid_Next dv_Next]];
        
        % compute the new reachable asteroids
        as           = asNext;
        tas          = tasNext;
        Vsc_Asteroid = Vsc_Asteroid_Next;
        [astREACH]   = generateAllReachablePoints(as, tas, astLIST);

    else
        tour(end,:) = [];
        tour = [[3 tE 0 0 0 0] ; tour];
    break

    end

end

if sum(tour(3:end,6)) < DSM_TOL

INDSTR = INDSTR + 1; 
    
asSAVE = [asSAVE; ASTEROIDS(indj,1)];

Tours(:,INDSTR).tour    = tour;
Tours(:,INDSTR).NAster  = length(find(tour(:,1)>4));
Tours(:,INDSTR).VinfDep = tour(2,6);
Tours(:,INDSTR).DSM     = sum(tour(3:end,6));
Tours(:,INDSTR).TOF     = (tour(end,2) - tour(1,2))/365.25;
checkMarsFlyby = find(tour(:,1)==4);
if isempty(checkMarsFlyby)
    Tours(:,INDSTR).Mars_Flyby = 'No';
else
    Tours(:,INDSTR).Mars_Flyby = 'Yes';
end

% save the tour
TITLE_var  = ['C:\Users\Andrea Bellome\Desktop\BS for CASTPath\tours\dep_ast_' num2str(asSAVE(end)) '.txt'];
fileID     = fopen(TITLE_var, 'w');

fprintf(fileID, '\n');

for indk = 1:size(tour,1)
fprintf(fileID, '%f %f %f %f %f %f \n', [tour(indk,:)]);
end

fclose(fileID);

else
% the sum of the DSM is bigger than the tolerance

end

else
% the departing infinity velocity is bigger than the tolerance

end

indj

end

save asSAVE asSAVE;

end
