function [MAT, EPH, minDist] = MOID_leg(rrd, vvd, t0, tf, MOIDThreshold, astCata, parallel)

try
    ephNEO('load','ephNEO_CATABC.txt');
catch
end

% --> constants
AU = 149597870.7;
mu = 132724487690;

% --> propagate
tt      = [0:10*86400:(tf - t0)*86400];
tt      = [ tt (tf - t0)*86400 ];
tt      = unique(tt);
[tt,yy] = propagateKepler(rrd, vvd, tt, mu);
tt      = tt./86400 + t0;

if parallel == 0 % --> USE SEQUENTIAL

    minDist = zeros(length(astCata),1);
    MAT     = zeros( length(astCata) , 4);
    EPH     = zeros( length(astCata) , 6);
    for indA = 1:length(astCata) 

        indA/length(astCata)*100;

        indexAsteroid = astCata(indA);

        rra  = zeros(length(tt), 3);
        vva  = zeros(length(tt), 3);
        dist = zeros(length(tt), 1);
        for indt = 1:length(tt)
            [rra(indt,:), vva(indt,:)] = EphSS_car(indexAsteroid, tt(indt));
            dist(indt,:)               = norm(yy(indt,1:3) - rra(indt,:));
        end

        [minDist(indA,:), row] = min(dist);
        minDist(indA,:)        = minDist(indA,:) / AU;
        MAT(indA,:)            = [ indexAsteroid 0 0 tt(row) ];
        EPH(indA,:)            = [rra(row,:) vva(row,:)];

    end

else % --> USE PARALLEL
    
    STRUC = struct('minDist', [], 'MAT', [], 'EPH', []);
    parfor indA = 1:length(astCata) % --> parallelize here
        indA/length(astCata)*100;
        STRUC(indA) = wrap_MOID(astCata, indA, yy, tt);
    end
    minDist = cell2mat({STRUC.minDist}');
    MAT     = cell2mat({STRUC.MAT}');
    EPH     = cell2mat({STRUC.EPH}');
    
end

indexes            = find(minDist > MOIDThreshold);
minDist(indexes,:) = [];
MAT(indexes,:)     = [];
EPH(indexes,:)     = [];

if ~isempty(MAT)
    MAT        = [MAT [1:size(MAT,1)]'];
    MAT        = sortrows(MAT, 4);
    EPH        = EPH(MAT(:,end),:);
    minDist    = minDist(MAT(:,end),:);
    MAT(:,end) = [];
end

end
