%{
Script_Generate_SearchGrid_ScoreMatrix_MCB.m
---------------------------------------------------------------------------
IRP
17/06/2021

Maria Carrillo Barrenechea
Student ID: s334328
---------------------------------------------------------------------------
--------------------Search grid & Score Matrix generator-------------------
---------------------------------------------------------------------------
This subscript generates the search space for ACO and GA algorithms.

It also generates a matrix of delta_v scores for triplets of asteroids.
The final matrix has the following structure, where An is the n-th asteroid
ID and the 'from' rows represent a pair of asteroids. Asteroid 0 represents
Earth. Each element contains the delta_v cost (dvabc) for the leg b-c
coming from asteroid a. The lower diagonal is all NaN.

ScoreMatrix_LambertArcs:
        TO |   A2     A3     ..   A158
    FROM   |
___________|____________________________________
    A0-A1  | dv012   dv013   ..   dv12.158
    A0-A2  |  NaN    dv023   ..   dv13.158
    A0-A3  |  NaN     NaN    ..   dv14.158
    ..     |  ..       ..    ..    ..
A156-A157  |  NaN     NaN    ..   dv156.157.158
___________|____________________________________

Version history:
    - 15/07/2021 Maria:
        - Added cleaning non-feasible pairs because of length of sequence
        - Changed way of finding the inidices of asteroid_triplets in Pairs
    - 01/08/2021 Maria:
        - Calculated 3 ScoreMatrix:
            - ScoreMatrix: total without filter (for GA, diagonal and lower
            diagonal with NaNs)
            - ScoreMatrix_filter: filtered by delta_v restriction
            - ScoreMatrix_semifilter: same size as ScoreMatrix_filter but
            does not have NaNs where the delta_v restriction is not met
%}
%% Initialization

close all; clear all; clc; format short g;

% load('IAC2021_TestCase_[11315 800 1827]_MOID0.05_158asteroids.mat')
% load('IAC2021_TestCase_[11315 800 1827]_MOID0.04_98asteroids.mat')
load('IAC2021_TestCase_[11315 800 1827]_MOID0.03_49asteroids.mat')

% Clearing unnecessary variables
% clear_except('MatrixSummary_BC','tE','tM')
% Loading ephemeris

ephNEO('load','ephNEO_CATABC.txt');
P1_DvThresholdMargin_leg    = 9;
P1_DvThresholdMargin_1stleg = 5;
CurrentSearch               = 12;
nMenu                       = length(MatrixSummary_BC);

%%

% load('ScoreMatrix_[11315 800 1827.0]_MOID0.05_158asteroids.mat')
asteroids       = 0:nMenu;
Pairs_tot       = nchoosek(asteroids, 2);
num_pairs       = nchoosek(nMenu + 1, 2);
Pairs_cell_tot  = cell(nMenu,1);  % Create a cell of 158 (0-157) possible first asteroids of pairs (158 is not included because it is the last one)
i = 1;
counter = 0;
for j = 1:nMenu
    while i <= num_pairs && Pairs_tot(i,1) == j-1
        Pairs_cell_tot{j}(end+1, :) = Pairs_tot(i,:);
        i = i+1;
        counter = counter + 1;
    end
end
initialNodes          = Pairs_cell_tot{1};
niniNodes             = length(initialNodes);
Score_initialNode_tot = NaN(1, niniNodes);

for iiniNode=1:niniNodes
    Score_initialNode_tot(iiniNode) = wrapper_combina_CASTPath_MARSSW(initialNodes(iiniNode,2), MatrixSummary_BC, tE, tM);
end

%% Script_Generate_SearchGrid_ScoreMatrix_MCB.m
tic

% Generate search grid of pairs of asteroids
nMenu     = length(MatrixSummary_BC(:,1));
asteroids = 0:nMenu;

num_pairs       = nchoosek(nMenu + 1, 2);   % number of pairs in 158 asteroids + Earth     12,561
num_triplets    = nchoosek(nMenu + 1, 3);   % number of triplets in 158 asteroids + Earth  657,359

Pairs           = nchoosek(asteroids, 2);   % returns a matrix containing all the possible pair combinations of asteroids
Triplets        = nchoosek(asteroids, 3);   % returns a matrix containing all the possible triplet combinations of asteroids

% Generate Score Matrix
ScoreMatrix        = NaN(num_pairs, nMenu);
ScoreMatrix_filter = ScoreMatrix;
ScoreMatrix_notNaN = [];        % Values kept for doing mean value

for i = 1:num_triplets
    i
    asteroid_triplet = Triplets(i,:);
    if asteroid_triplet(1) ~= 0     % If first "asteroid" is Earth don't take into account for the function
        tour_segment = [asteroid_triplet(1), asteroid_triplet(2), asteroid_triplet(3)];
    else
        tour_segment = [asteroid_triplet(2), asteroid_triplet(3)];
    end

    ScoreMatrix_aux = wrapper_ScoreMatrix_CASTPath_MARSSW_MR(tour_segment, MatrixSummary_BC, tE, tM);
    
    if ScoreMatrix_aux <= P1_DvThresholdMargin_leg
        ScoreMatrix_filter((Pairs(:,1)==asteroid_triplet(1)) & (Pairs(:,2)==asteroid_triplet(2)), asteroid_triplet(3)) = ScoreMatrix_aux;
        ScoreMatrix_notNaN(end+1) = ScoreMatrix_aux;
    end
    ScoreMatrix((Pairs(:,1)==asteroid_triplet(1)) & (Pairs(:,2)==asteroid_triplet(2)), asteroid_triplet(3)) = ScoreMatrix_aux;
end
ScoreMatrix_mean       = mean(ScoreMatrix_notNaN);    % For ACO pheromone initialisation
ScoreMatrix_semifilter = ScoreMatrix;
TT_scoreMatrix         = toc;

%% Save all the variables without cleaning
save('ScoreMatrix_[11315 800 1827]_MOID0.04_98asteroids_NoCleaning_9kms.mat',...
    'MatrixSummary_BC','tE','tM','nMenu','ScoreMatrix','ScoreMatrix_filter','ScoreMatrix_semifilter','ScoreMatrix_mean','Pairs','Triplets','TT_scoreMatrix')

%% Load all the variables without cleaning
% load('ScoreMatrix_[11315 800 1827]_MOID0.03_49asteroids_NoCleaning_9kms.mat')
% load('ScoreMatrix_[11315 800 1827]_MOID0.04_98asteroids_NoCleaning_9kms.mat')

%% Cleaning of search space
j = all(isnan(ScoreMatrix_filter), 2);
index_row = find(j==1);

ScoreMatrix_filter(j, :) = [];
ScoreMatrix_semifilter(j, :) = [];
Pairs(j, :) = [];

num_pairs = length(Pairs);                  % number of pairs after cleaning     11,944
% num_triplets = length(ScoreMatrix_notNaN);  % number of triplets after cleaning 604,292

Pairs_cell = cell(nMenu,1);  % Create a cell of 158 (0-157) possible first asteroids of pairs (158 is not included because it is the last one)
i = 1;
counter = 0;
for j = 1:nMenu
    while i <= num_pairs && Pairs(i,1) == j-1
        Pairs_cell{j}(end+1, :) = Pairs(i,:);
        i = i+1;
        counter = counter + 1;
    end
end

%% Check that Pairs_cell contains all the asteroids in Pairs
% k=0;
% for j=1:length(Pairs_cell)
%     for i = 1:size(Pairs_cell{j},1)
%         k = k+1;
%         if Pairs(k,:) ~= Pairs_cell{j}(i,:)
%             disp('ay')
%         end
%     end
% end

%% Cleaning non-feasible pairs because of length of sequence
for j = 1:nMenu
    i = 1;
    if ~isempty(Pairs_cell{j})
        ast = Pairs_cell{j}(i,2);
        while ast < nMenu-CurrentSearch+j && i <= size(Pairs_cell{j},1)
            ast = Pairs_cell{j}(i,2);
            i = i+1;
        end
        if i <= size(Pairs_cell{j},1)
            num2remove = size(Pairs_cell{j}(i:end,:),1);
            k = (Pairs(:,1)==j-1) & (Pairs(:,2)==Pairs_cell{j}(i,2));
            index = find(k==1);
            disp(['index: ' num2str(index) ' x: ' num2str(j-1) ' y: ' num2str(Pairs_cell{j}(i,2))])
            ScoreMatrix_filter      (index:index+num2remove-1, :) = [];
            ScoreMatrix_semifilter  (index:index+num2remove-1, :) = [];
            Pairs               (index:index+num2remove-1, :) = [];
            Pairs_cell{j}(i:end,:) = [];
        end
    end
end
%%
num_pairs = length(Pairs);     % 11889

% Code to know how many triplets are left
num_triplets = 0;
for i = 1:num_pairs
    for j = 1:nMenu
        if ~isnan(ScoreMatrix_filter(i,j))
            num_triplets = num_triplets + 1;    % 604,151
        end
    end
end

% Score Vector of initial Node (i.e. Pair with a zero)
initialNodes = Pairs_cell{1};
niniNodes = length(initialNodes);
Score_initialNode = NaN(1, niniNodes);
iiniNode_i = 0;
iiniNode_indices = [];

for iiniNode=1:niniNodes
    iiniNode_i = iiniNode_i + 1;
    Score_initialNode(iiniNode) = wrapper_combina_CASTPath_MARSSW(initialNodes(iiniNode,2),MatrixSummary_BC, tE, tM);
    if Score_initialNode(iiniNode) > P1_DvThresholdMargin_1stleg
        Pairs_cell{1}(iiniNode_i,:) = [];
        Pairs(iiniNode_i,:) = [];
        iiniNode_indices(end+1) = iiniNode_i;
        iiniNode_i = iiniNode_i - 1;
    end
end
Score_initialNode(iiniNode_indices) = [];

%%
% Save results of the search

save('ScoreMatrix_[11315 800 1827]_MOID0.04_98asteroids_9kms.mat',...
    'MatrixSummary_BC','tE','tM','nMenu','ScoreMatrix','ScoreMatrix_filter','ScoreMatrix_semifilter','ScoreMatrix_mean','Pairs','Pairs_cell','Triplets','Score_initialNode','TT_scoreMatrix')

% save('ScoreMatrix_[11315 800 1827.0]_MOID0.05_158asteroids.mat',...
%     'MatrixSummary_BC','tE','tM','nMenu','ScoreMatrix','ScoreMatrix_filter','ScoreMatrix_semifilter','ScoreMatrix_mean','Score_initialNode','Score_initialNode_tot',...
%     'Pairs','Pairs_tot','Pairs_cell','Pairs_cell_tot','Triplets','TT_scoreMatrix')
%%
clear('layer')
% Empty layers (initialise structure)
layer.visited   = [];   % boolean matrix of visited (1) or not visited (0) asteroids
layer.avoid     = [];

% Layer Matrix
layer = repmat(layer, CurrentSearch, 1); % Structure that saves the visited and avoided asteroids per layer

for i_layer = 1:CurrentSearch
    if i_layer < CurrentSearch
        last_feasible_ast = nMenu - (CurrentSearch - i_layer) - 1;
    else
        last_feasible_ast = nMenu - 1;
    end
    length_ast = last_feasible_ast - (i_layer-1);
    layer(i_layer).visited  = zeros(1, length_ast);
    layer(i_layer).avoid    = zeros(1, length_ast);
end
%%
save('ScoreMatrix_[11315 800 1827]_MOID0.04_98asteroids_9kms.mat',...
    'MatrixSummary_BC','tE','tM','nMenu','ScoreMatrix','ScoreMatrix_filter','ScoreMatrix_semifilter','ScoreMatrix_mean','Pairs','Pairs_cell','Triplets','Score_initialNode','TT_scoreMatrix','layer')
