%% --> set up the design variables

clear all; close all; clc; format short g;

% --> add 'Functions Toolbox' to the path
addpath(genpath([pwd '\Functions Toolbox']));
ephNEO('load','ephNEO_CATABC.txt');

% --> launch window
t0     = date2mjd2000([2035 1 1 0 0 0]); 
tf     = date2mjd2000([2036 12 31 0 0 0]); 
tofMin = 500;
tofMax = 900;

% --> set tresholds
MaxMissionDuration = 7;    % --> [years] max mission duration
MassThreshold      = 900;  % --> [kg]    dry launch mass threshold
MOIDThreshold      = 0.05; % --> [AU]    MOID treshold

% --> set up the tolerances
tols(1) = 5;     % --> (km/s) --> dep. vinf tol.
tols(2) = Inf;   % --> (km/s) --> DSMt tol.
tols(3) = 1;     % --> (km/s) --> DSMp tol.
tols(4) = 9;     % --> (km/s) --> COSTt tol.
astMax  = 12;    % --> number of asteroids in the sequence
bw      = 100e3;  % --> beam width

folder = '\test_case_v2';

%% --> Iterative search through each branch

% --> select departing dates
Points2Search = wrap_BranchSeed_EM(t0, tf, tofMin, tofMax, MassThreshold);

STRUC = struct('MatrixSummary_BC', [], 'tE', [], 'tM', [], 'tocMOID', [], 'SOL', []);
for iSP = 4:length(Points2Search(:,1))
    
    % --> MOID Search
    STRUC(iSP) = wrap_MOID_Search(Points2Search(iSP,1), Points2Search(iSP,2), MOIDThreshold, MaxMissionDuration);
                
    % --> solve the BS
    INPUT          = wrap_Initialization(STRUC(iSP), tols, astMax, bw);
    STRUC(iSP).SOL = BEAM_SEARCH(INPUT, folder, iSP);
    
end









