function [dryMass, KepBase, svDepSW_mars, Car_Baseline_1, dv] =  Transfer_CASTAway_marsSW_vA( struc )

%--------------------------------------------------------------------------

muSun = astroConstants(4);
AU    = astroConstants(2);

t0            = struc.t1;
TOF           = struc.t2 - t0;
flyby         = [struc.rpin struc.kin];
optsMR        = struc.opts;

%--------------------------------------------------------------------------

% Launch Model

t1   = t0 + TOF; % --> arrival date at Mars
vInf = 0;        % km/s

% Departure
idEarth = 3;
[sE(1:3), sE(4:6)] = EphSS_car(idEarth, t0); % Departure

% Arrival
idMars             = 4;
[sA(1:3), sA(4:6)] = EphSS_car(idMars, t1); % Arrival

% --> compute the MRLP
multirev = optsMR(1);
energy   = optsMR(2);
[~, ~, ~, ~, vI, vF, ~, ~] = ...
    lambertMR(sE(1:3), sA(1:3), (t1-t0)*86400, muSun, 0, multirev, energy, 0);

VelocitiesDep(1,:) = vI;
dv(1)              = (norm(vI - sE(4:6)) - vInf)*(norm(vI - sE(4:6)) - vInf >= 0);

% --> check if the declination at launch is respected
% vEscape        = vI - sE(4:6);
% epsilon        = 23.5*pi/180;
% R              = [1 0 0; 0 cos(epsilon) -sin(epsilon); 0 sin(epsilon) cos(epsilon)];
% v_eci          = R*vEscape';
% Dec(1)         = asin(v_eci(3)/norm(v_eci))/RAD;
% indexFeasible = find((dv < vinfLim) & (Dec > -10) & (Dec < 5));

%% What dv are feasible? Dv = 5.5 km/s

% --> perform the swing-by with Mars
rpin   = flyby(1);
kin    = flyby(2);
muPLIN = planetConstants(4);
[~, vDepSW_mars] = swingby_vA(sA(1:3), vF, 4, t1, kin, rpin, muPLIN);

% --> conditions after Mars Swing By
svDepSW_mars     = [sA(1:3) vDepSW_mars];
kepDepSW_mars    = car2kep(svDepSW_mars, muSun);
kepDepSW_mars(1) = kepDepSW_mars(1)/AU;
                  
% --> final dry mass
[dryMass] = wrap_DryMass_A62(dv);

%--------------------------------------------------------------------------

% --> computing Baseline Trajectories

% --> before the swing-by
Car_Baseline_1 = [sE(1:3) VelocitiesDep];
KepBase1       = car2kep(Car_Baseline_1,muSun);
KepBase1(1)    = KepBase1(1)/AU;

% --> after the swing-by
KepBase2       = kepDepSW_mars;

% --> store
KepBase = [KepBase1 t0;  KepBase2 t1];

end
