function [dvSM, dv, vInf, alpha, mass] = checkPath_SM(path, OUTPUT, pruned)

if nargin == 2
    pruned = 0;
elseif nargin == 3
    if isempty(pruned)
        pruned = 0;
    end
end

if pruned == 0

    SM_DV     = OUTPUT.SM_DV;
    SM_VINFA  = OUTPUT.SM_VINFA_trip;
    SM_VINFAc = OUTPUT.SM_VINFA_coup;
    ALPHA     = OUTPUT.SM_ALPHA_trip;
    ALPHAc    = OUTPUT.SM_ALPHA_coup;
    MASS      = OUTPUT.SM_MASS_trip;
    MASSc     = OUTPUT.SM_MASS_coup;

    COUPLES   = OUTPUT.COUPLES;
    MATpls    = OUTPUT.MATpls;

else
    
    SM_DV     = OUTPUT.SM_DVp;
    SM_VINFA  = OUTPUT.SM_VINFAp_trip;
    SM_VINFAc = OUTPUT.SM_VINFAp_coup;
    ALPHA     = OUTPUT.SM_ALPHAp_trip;
    ALPHAc    = OUTPUT.SM_ALPHAp_coup;
    MASS      = OUTPUT.SM_MASSp_trip;
    MASSc     = OUTPUT.SM_MASSp_coup;


    COUPLES   = OUTPUT.COUPLES;
    MATpls    = OUTPUT.MATpls;

end
        

% --> find the cost of the path from the Score Matrix info
seqt        = path(:,1:2);
couplesSeqt = [ seqt(1:end-1,:) seqt(2:end,:) ];

dv    = zeros(size(couplesSeqt,1) - 1,1);
vInf  = zeros(size(couplesSeqt,1) - 1,1);
alpha = zeros(size(couplesSeqt,1) - 1,1);
mass  = zeros(size(couplesSeqt,1) - 1,1);

for indcs = 1:size(couplesSeqt,1) - 1

    couple = couplesSeqt(indcs,:);
    asnt   = couplesSeqt(indcs+1,3:4);

    row    = find( COUPLES(:,1) == couple(1) & COUPLES(:,2) == couple(2) & ...
                   COUPLES(:,3) == couple(3) & COUPLES(:,4) == couple(4) );
    col    = find( MATpls(:,1) == asnt(1) & MATpls(:,2) == asnt(2) );

    dv(indcs,:)    = SM_DV(row, col);
    vInf(indcs,:)  = SM_VINFA(row, col);
    alpha(indcs,:) = ALPHA(row,col);
    mass(indcs,:)  = MASS(row,col);

end

couple = couplesSeqt(1,:);
row    = find( COUPLES(:,1) == couple(1) & COUPLES(:,2) == couple(2) & ...
               COUPLES(:,3) == couple(3) & COUPLES(:,4) == couple(4) );
col    = find( MATpls(:,1) == asnt(1) & MATpls(:,2) == asnt(2) );

vinf1C  = SM_VINFAc(row, col);

couple  = couplesSeqt(end-1,:);
row     = find( COUPLES(:,1) == couple(1) & COUPLES(:,2) == couple(2) & ...
               COUPLES(:,3) == couple(3) & COUPLES(:,4) == couple(4) );
col     = find( MATpls(:,1) == asnt(1) & MATpls(:,2) == asnt(2) );
massEC  = MASSc(row,col);
alphaEC = ALPHAc(row, col);

alpha   = [ alpha; alphaEC ];
vInf    = [ vinf1C; vInf ];
mass    = [ mass; massEC ];

dvSM   = sum(dv);

end
