function [DATA] = makeGuess_LT(output, Nnodes)

if nargin == 1
    Nnodes = 1000;
end

AU  = 149597870.7;
mu  = 132712440018;
leg = output.leg;

DATA = struct('initialState', [], 'targetState', [],...
    'guess', [], 'times', [], 'dv', [], 'accel', [], 'mu', [], 'AU', []);
DATA.mu = mu;
DATA.AU = AU;
for indl = 1:length(leg)
    
    if indl == 1
        
        rr1 = leg(indl).part.x1;
        vv1 = leg(indl).part.v1;
        t1  = leg(indl).part.t1;
        t2  = leg(indl).part.t2;
        
        rr2 = leg(indl).part.x2;
        vv2 = leg(indl).part.v2;
        
        tof = t2 - t1;
        tt  = linspace(0, tof, Nnodes).*86400;
        [~,yy] = propagateKepler(rr1, vv1, tt, mu);
        
        DATA(indl).initialState = [rr1 vv1]';
        DATA(indl).targetState  = [rr2 vv2]';
        DATA(indl).guess        = yy';
        DATA(indl).times        = tt;
        
    else
        
        rr1 = leg(indl).part(1).x1;
        vv1 = leg(indl).part(1).v1;
        t1  = leg(indl).part(1).t1;
        t2  = leg(indl).part(1).t2;
        DATA(indl).initialState = [rr1 vv1]';
        
        tof1    = t2 - t1;
        tt1     = linspace(0, tof1, Nnodes/2).*86400;
        [~,yy1] = propagateKepler(rr1, vv1, tt1, mu);

        rr2 = leg(indl).part(2).x2;
        vv2 = leg(indl).part(2).v2;
        DATA(indl).targetState  = [rr2 vv2]';
        
        rr1 = leg(indl).part(2).x1;
        vv1 = leg(indl).part(2).v1;
        t1  = leg(indl).part(2).t1;
        t2  = leg(indl).part(2).t2;

        tof2    = t2 - t1;
        tt2     = linspace(0, tof2, Nnodes/2).*86400;
        [~,yy2] = propagateKepler(rr1, vv1, tt2, mu);
        
        dv = norm( yy1(end,4:6) - yy2(1,4:6) );

        yy = [yy1; yy2];
        tt = [tt1 tt1(end)+tt2];
        
        DATA(indl).guess = yy';
        DATA(indl).times = tt;
        DATA(indl).dv    = dv;
        DATA(indl).accel = dv / tt(end) ;
        
    end

end

end
