function [V, solarPhase] = photometricModel(scState, asState, H)

AU = 149597870.7;
G  = 0.41;  % according to "Michael Weiler, Heike Rauer, Christiaan Sterken.
            %   Cometary Nuclear Magnitudes from Sky Survey Observations.
            %   Icarus, Elsevier, 2011, 212 (1), pp.351.
            %   <10.1016/j.icarus.2010.12.026>."


rrsc = scState(1:3)./AU;
rras = asState(1:3)./AU;
rrho = rras - rrsc;

solarPhase = acos(dot(rras, rrho)/(norm(rrho)*norm(rras)));       % --> solar phase angle
Phi        = ((1 - G)*exp(-3.33*(tan(solarPhase/2)).^0.63) + G*exp(-1.87*(tan(solarPhase/2)).^1.22));
V          = H + 5*log10(norm(rrho)*norm(rras)) - 2.5*log10(Phi); % --> visual magnitude

end