function plotCatag_traj(CATABC, MatrixSummary, param, twodim)

if nargin == 2
    param.rcMIN = NaN;
    param.rcMAX = NaN;
    twodim      = 0;
elseif nargin == 3
    twodim = 0;
    if isempty(param) || param == 0
        param.rcMIN = NaN;
        param.rcMAX = NaN;
    end
elseif nargin == 4
    if isempty(param) || param == 0
        param.rcMIN = NaN;
        param.rcMAX = NaN;
    end
end

AU = 149597870.7;
mu = 132724487690;
try
    % --> load the whole catalogue
    keps      = CATABC.kep;
catch
    load("CATABC.mat");
end
keps      = CATABC.kep;
keps(:,1) = keps(:,1).*AU;
keps(:,3) = deg2rad(keps(:,3));
keps(:,4) = deg2rad(keps(:,4));
keps(:,5) = deg2rad(keps(:,5));
keps(:,6) = deg2rad(keps(:,6));

STATEs = zeros(size(keps,1),6);
for inds = 1:size(keps,1)
    inds/size(keps,1)*100
    STATEs(inds,:) = kep2car(keps(inds,:), mu);
end

if isempty(MatrixSummary)
else
    STATEm = zeros(size(MatrixSummary,1),6);
    for indm = 1:size(MatrixSummary,1)
        indm/size(MatrixSummary,1)*100
        [rr, vv] = EphSS_car(MatrixSummary(indm,1), MatrixSummary(indm,4));
        STATEm(indm,:) = [rr, vv];
    end
end

hold on; grid on; axis equal;
xlabel('x - km'); ylabel('y - km'); 

if twodim == 0 || isempty(twodim)
    plot3(STATEs(:,1), STATEs(:,2), STATEs(:,3), '.',...
        'Color', [0.5 0.5 0.5], 'MarkerFaceColor', [0.5 0.5 0.5], 'markersize', 3, 'handlevisibility', 'off');
else
    plot(STATEs(:,1), STATEs(:,2), '.',...
        'Color', [0.5 0.5 0.5], 'MarkerFaceColor', [0.5 0.5 0.5], 'markersize', 3, 'handlevisibility', 'off');
end

if isempty(MatrixSummary)
else
    if twodim == 0 || isempty(twodim)
        plot3(STATEm(:,1), STATEm(:,2), STATEm(:,3), '.',...
            'Color', 'Red', 'MarkerFaceColor', 'Red', 'markersize', 15, 'DisplayName', 'Close asteroids');
    else
            plot(STATEm(:,1), STATEm(:,2), '.',...
        'Color', 'Red', 'MarkerFaceColor', 'Red', 'markersize', 15, 'DisplayName', 'Close asteroids');
    end
end

% --> AMB limits
xxMIN = param.rcMIN.*cos([linspace(0, 2*pi)]);
yyMIN = param.rcMIN.*sin([linspace(0, 2*pi)]);
xxMAX = param.rcMAX.*cos([linspace(0, 2*pi)]);
yyMAX = param.rcMAX.*sin([linspace(0, 2*pi)]);

if isnan(xxMIN(1))
    plot(xxMIN , yyMIN ,'k--', 'Linewidth', 2, 'handlevisibility', 'off');
    plot(xxMAX , yyMAX ,'k--', 'Linewidth', 2, 'handlevisibility', 'off');
else
    plot(xxMIN , yyMIN ,'k--', 'Linewidth', 2, 'handlevisibility', 'off');
    plot(xxMAX , yyMAX ,'k--', 'Linewidth', 2, 'DisplayName', 'MAB limits');
end


xlabel('x - km'); ylabel('y - km');

end
