function fig = plotFAMILIES(CATABC, holdon)

if nargin == 1
    fig = figure('Color', [1 1 1]);
elseif nargin == 2
    if holdon == 0
        fig = figure('Color', [1 1 1]);
    else
        fig = gcf;
    end
end

kep = CATABC.kep;

hold on; grid on;
plot(kep(:,1), kep(:,2),...
    'MarkerFaceColor',[0.800000011920929 0.800000011920929 0.800000011920929],...
    'MarkerEdgeColor',[0.800000011920929 0.800000011920929 0.800000011920929],...
    'MarkerSize',5,...
    'Marker','o',...
    'LineStyle','none',...
    'Color',[0.800000011920929 0.800000011920929 0.800000011920929], 'handlevisibility', 'off');
plot(kep(1,1), kep(1,2),...
    'MarkerFaceColor',[0.800000011920929 0.800000011920929 0.800000011920929],...
    'MarkerEdgeColor',[0.800000011920929 0.800000011920929 0.800000011920929],...
    'MarkerSize',5,...
    'Marker','o',...
    'LineStyle','none',...
    'Color',[0.800000011920929 0.800000011920929 0.800000011920929],...
    'DisplayName', 'No family');

[smaFAM, eccFAM] = asteroidsFamilies_Regions();
smatemp = smaFAM; ecctemp = eccFAM;
smaFAM(9,:)  = smatemp(10,:);
eccFAM(9,:)  = ecctemp(10,:);
smaFAM(10,:) = smatemp(9,:);
eccFAM(10,:) = ecctemp(9,:);
colors = {'Green', 'Red', 'Yellow', 'Cyan', 'Magenta', 'Blue',...
    [0.4940 0.1840 0.5560], [0.8500 0.3250 0.0980], ...
    [0.9290 0.6940 0.1250], [0.4660 0.6740 0.1880] };
names = { 'Flora', 'Vesta', 'Nysa', 'Maria', 'Eunomia', 'Gefion', ...
          'Koronis', 'Eos', 'Themis', 'Hygiea'};
for inds = 1:size(smaFAM,1)
    
    smamin = smaFAM(inds,1);
    smamax = smaFAM(inds,2);
    eccmin = eccFAM(inds,1);
    eccmax = eccFAM(inds,2);
    
    indxs = find( kep(:,1) > smamin & kep(:,1) < smamax & ...
                  kep(:,2) > eccmin & kep(:,2) < eccmax );
              
    plot( kep(indxs,1), kep(indxs,2), 'o', 'MarkerSize', 5, ...
        'MarkerEdgeColor', 'Black', 'MarkerFaceColor', colors{inds},...
        'DisplayName', names{inds} );
end

xlim([1.6 4.2]);
ylim([0 0.5]);

vline(2);
vline(2.5);
vline(2.8);
vline(3.3);
vline(3.7);
vline(4.53);

text('FontWeight','bold','Rotation',90,'String','Hungaria',...
    'Position',[1.8 0.387523364485981 1.4210854715202e-14]);

text('FontWeight','bold','Rotation',90,'String','Inner Belt',...
    'Position',[2.24042357274401 0.389859813084112 1.4210854715202e-14]);

text('FontWeight','bold','Rotation',90,...
    'String','Middle Belt',...
    'Position',[2.65 0.381682242990654 1.4210854715202e-14]);

text('FontWeight','bold','Rotation',90,'String','Outer Belt',...
    'Position',[3.07605893186004 0.394532710280374 1.4210854715202e-14]);

text('FontWeight','bold','Rotation',90,'String','Cybele',...
    'Position',[3.5 0.405046728971963 1.4210854715202e-14]);

text('FontWeight','bold','Rotation',90,'String','Hylda',...
    'Position',[3.95563535911602 0.395700934579439 1.4210854715202e-14]);

xlabel('Semi-major axis - AU'); ylabel('Eccentricity');

lgd = legend('Location','Bestoutside');
lgd.NumColumns = 1;

end