function plotRefTraj(STRUC, inds, color, twodim)

if nargin == 2
    twodim = 0;
    color = 'b';
elseif nargin == 3
    twodim = 0;
end
mu     = 132724487690;

seq    = STRUC(1).seq;
legs   = [[seq(1:end-1)]' [seq(2:end)]'];
epochs = STRUC(inds).epochs;

% --> plot planets
plts  = seq;
tplts = epochs;
plotPLTS(plts, tplts);

tofs   = diff(epochs);
epochs = [[epochs(1:end-1)]' [epochs(2:end)]'];
stated = STRUC(inds).stated;
flyby  = [STRUC(inds).rpin STRUC(inds).kin];

for ind = 1:size(stated,1)
    
    rr  = stated(ind,1:3);
    vv  = stated(ind,4:6);
    if length(seq) == 1
        kepd = car2kep(stated(ind,:), mu);
        tof  = 2*pi*sqrt(kepd(1)^3/mu);
    else
        tof = tofs(ind)*86400;
    end
    
    tt     = [0:5*86400:tof];
    [~,yy] = propagateKepler(rr, vv, tt, mu);
    
    if twodim == 0 || isempty(twodim)
        hold on;
        plot3(yy(:,1), yy(:,2), yy(:,3), color, 'linewidth', 2, 'handlevisibility', 'off');
    else
        hold on;
        plot(yy(:,1), yy(:,2), color, 'linewidth', 2, 'handlevisibility', 'off');
    end
    
    if length(seq) == 1
        break
    end

end

if length(seq) > 1

    % --> perform the last flyby
    rrd          = stated(end,1:3);
    vvd          = stated(end,4:6);
    tof          = tofs(end)*86400;
    plin         = legs(end,end);
    tin          = epochs(end,end);
    rpin         = flyby(1);
    kin          = flyby(2);
    [rrin, vvin] = FGKepler_dt(car2kep([rrd vvd], mu), tof, mu);
    muPLIN       = planetConstants(plin);
    [rrOU, vvOU] = swingby_vA(rrin, vvin, plin, tin, kin, rpin, muPLIN);

    kepOU = car2kep([rrOU, vvOU], mu);
    TOU   = 2*pi*sqrt(kepOU(1)^3 / mu);

    tt     = [0:5*86400:TOU];
    [~,yy] = propagateKepler(rrOU, vvOU, tt, mu);

    if twodim == 0 || isempty(twodim)
        hold on;
        plot3(yy(:,1), yy(:,2), yy(:,3), color, 'linewidth', 2, 'handlevisibility', 'off');
    else
        hold on;
        plot(yy(:,1), yy(:,2), color, 'linewidth', 2, 'handlevisibility', 'off');
    end
    
end

xlabel('x - km'); ylabel('y - km'); zlabel('z - km');
fig = gcf;
fig.Color = [ 1 1 1 ];

end
