function plotTime_AMB(t0, TOF, flyby, pl1, pl2, rcMIN, rcMAX, optsMR)

mu = 132724487690; % --> gravitational parameter of the Sun (km3/s2)
AU = 149597870.7;  % --> Astronomical Unit (km)

tf         = t0 + TOF;
[rr1, vv1] = EphSS_car(pl1, t0);
[rr2, vv2] = EphSS_car(pl2, tf);

[~, ~, ~, ~, vvd, vva] = lambert_MR_opts(vv1, rr1, rr2, TOF*86400, mu, optsMR);
norm(vvd - vv1)

% --> AMB limits
xxMIN = rcMIN.*cos([linspace(0, 2*pi)]);
yyMIN = rcMIN.*sin([linspace(0, 2*pi)]);
xxMAX = rcMAX.*cos([linspace(0, 2*pi)]);
yyMAX = rcMAX.*sin([linspace(0, 2*pi)]);

figure; 
hold on; grid on; axis equal;
xlabel('x - AU'); ylabel('y - AU'); 

% --> plot Sun texture
plot_sun(0.3, [0 0 0]);

% --> plot Earth texture
plot_earth(0.2, [rr1(1) rr1(2) rr1(3)]./AU);
kepE = [AU 0.0167 0 0 deg2rad(102.94719) 0];
plotEllipse_SC(kepE);

if pl2 == 4
    % --> plot Mars texture
    plot_mars(0.2, [rr2(1) rr2(2) rr2(3)]./AU);
    kepM = [227.923e6 0.0935 0 0 deg2rad(336.04084) 0];
    plotEllipse_SC(kepM);
end

% --> time in the AMB for the first phase
[~, ~, yyAMB1, yypruned1] = time_AMB(rr1, vvd, rcMIN, rcMAX, TOF*86400);

plot3(yypruned1(:,1)./AU, yypruned1(:,2)./AU, yypruned1(:,3)./AU, 'b', 'linewidth', 2, 'handlevisibility', 'off');
plot3(yyAMB1(:,1)./AU, yyAMB1(:,2)./AU, yyAMB1(:,3)./AU, 'r', 'linewidth', 2, 'handlevisibility', 'off');

plot(xxMIN./AU , yyMIN./AU ,'k--', 'Linewidth', 2, 'handlevisibility', 'off');
plot(xxMAX./AU , yyMAX./AU ,'k--', 'Linewidth', 2, 'DisplayName', 'AMB limits');

% --> perform the flyby
rpin = flyby(1);
kin  = flyby(2);

muPLIN       = planetConstants(pl2);
[rrOU, vvOU] = swingby_vA(rr2, vva, pl2, tf, kin, rpin, muPLIN);

[~, ~, yyAMB2, yypruned2] = time_AMB(rrOU, vvOU, rcMIN, rcMAX);

plot3(yypruned2(:,1)./AU, yypruned2(:,2)./AU, yypruned2(:,3)./AU, 'b', 'linewidth', 2, 'handlevisibility', 'off');
plot3(yyAMB2(:,1)./AU, yyAMB2(:,2)./AU, yyAMB2(:,3)./AU, 'r', 'linewidth', 2,...
    'DisplayName', 'Trajectory in the AMB');

legend('Location', 'Best');

end



