function [SOLUTION] = postProcess_SOLUTION_vInfMass(SOLUTION, INPUT, opttoload)

if nargin == 2
    opttoload = 'DP';
end

ls = length(SOLUTION);
parfor inds = 1:length(SOLUTION)

    inds/ls*100

    % --> load the catalogue for all the cores that you are using
    try
        ephNEO('load','ephNEO_CATABC.txt');
    catch
    end

    LEGS   = SOLUTION(inds).Sol.LEGS;
    seq    = SOLUTION(inds).seq;
    epochs = SOLUTION(inds).epochs;
    MAT    = SOLUTION(inds).MAT;
    EPH    = generateEPH_BS(seq, epochs, MAT);
    
    nsequences = size(LEGS,1);            % --> number of sequences
    nasts      = size(LEGS(:,2:2:end),2); % --> number of asteroids in one sequence
    
    MASSES = zeros( nsequences*nasts , 1 );
    VINFS  = zeros( nsequences*nasts , 1 );
    ind    = 1;
    for indl = 1:size(LEGS,1)
        path = constructPath_BS(LEGS(indl,:), EPH, INPUT.OptionsMultiRev);
        
        vinfs           = path(:,4);
        masses          = path(:,5);
        indxs           = find(masses == 0);
        masses(indxs,:) = [];
        vinfs(indxs,:)  = [];
        
        MASSES(ind:ind-1+size(masses,1)) = masses;
        VINFS(ind:ind-1+size(masses,1))  = vinfs;
        ind                              = ind + size(masses,1);
    end
    
    SOLUTION(inds).MASSES = MASSES;
    SOLUTION(inds).VINFS  = VINFS;

end

% --> save the SOLUTION
epochs = SOLUTION(1).epochs;
t0     = mjd20002date(epochs(1));
tofys  = round(max([SOLUTION.bestTOFy]'));
if ~isempty(SOLUTION)
    seq        = SOLUTION(1).seq;
    nametosave = [ 'SOLUTION_' opttoload '_vInfMasses_' sprintf('%d', t0(1)) '_' sprintf('%d', tofys) '_' sprintf('%d', seq) '.mat'];
    save(nametosave, 'SOLUTION', '-v7.3');
else
    seq        = info.seq;
    nametosave = [ 'SOLUTION_' opttoload '_vInfMasses_' sprintf('%d', t0(1)) '_' sprintf('%d', tofys) '_' sprintf('%d', seq) '.mat'];
    save(nametosave, 'SOLUTION', '-v7.3');
end


end