function [struc] = processResults_ASTRA(STRUC_NEW, param)

mu    = 132724487690; % --> gravitational parameter of the Sun

rcMIN           = param.rcMIN;
rcMAX           = param.rcMAX;
maxDur          = param.maxDur;
MOIDThreshold   = param.MOIDThreshold;
OptionsMultiRev = param.OptionsMultiRev;

struc = struct('pl1', [], 'pl2', [], 't1', [], 't2', [], 'opts', [],...
            'rpin', [], 'kin', [], 'dtAMB', [], 'MOIDThreshold', [], 'maxDur', []);
for inds = 1:length(STRUC_NEW)

    pl1 = STRUC_NEW(inds).pl1;
    pl2 = STRUC_NEW(inds).pl2;

    t0  = STRUC_NEW(inds).tDEP;
    tf  = STRUC_NEW(inds).tIN;
    tof = tf - t0;
        
    [rr1, vv1] = EphSS_car(pl1, t0);
    [rr2, ~]   = EphSS_car(pl2, tf);
    
    % --> solve the MR-LP
    [~, ~, ~, dv, vvd, vva] = lambert_MR_opts(vv1, rr1, rr2, tof*86400, mu, OptionsMultiRev);
    [~, row]                = min(abs(dv - STRUC_NEW(inds).vInfDep));
    vvd                     = vvd(row,:);
    vva                     = vva(row,:);
    opts                    = OptionsMultiRev(row,:);
    dtAMB_1                 = time_AMB(rr1, vvd, rcMIN, rcMAX, tof*86400); % --> time in the AMB on the first leg
    
    % --> perform the swing-by and compute the orbit after the swing-by
    rpin         = STRUC_NEW(inds).rpin;
    kin          = STRUC_NEW(inds).kin;
    muPLIN       = planetConstants(pl2);
    [rrOU, vvOU] = swingby_vA(rr2, vva, pl2, tf, kin, rpin, muPLIN);
    [dtAMB_2, T] = time_AMB(rrOU, vvOU, rcMIN, rcMAX); % --> time in the AMB on the second leg
    
    % --> time within the AMB on the two phases
    dtAMB = ((maxDur - tof) / T * dtAMB_2) + dtAMB_1; 
    
    % --> save the results
    struc(inds).pl1   = pl1;
    struc(inds).pl2   = pl2;
    struc(inds).t1    = t0;
    struc(inds).t2    = tf;
    struc(inds).opts  = opts;
    struc(inds).rpin  = rpin;
    struc(inds).kin   = kin;
    struc(inds).dtAMB = dtAMB;
    struc(inds).MOIDThreshold = MOIDThreshold;
    struc(inds).maxDur        = maxDur;
    
end

end
