function [DVTotal, dv, output] = transfer_AMB_GA_mr(seq, t0, tofs, planetsFB, alphasASTS, options, multirev)

if nargin == 5
    options(1) = 0; % if 0, the journey starts at s(1) with a deep space flight,
%                       with departure velocity v0. No swing-by is
%                       performed at body s(1).
    options(2) = 0; % if 0, the journey ends at the encounter of the last planet,
%                       s(end) without doing the swing-by of it.
    options(3) = 1; % if 1, v0 input is relative to the first planet, in
%                       cartesian coordinates.
%                       This case can be used with v0 = [0 0 0], and in
%                       conjunction with alpha1=0, to create a trajectory
%                       in which there is no real DSM in the first leg. In
%                       fact, the DSM is moved to emulate launch. Note that
%                       in this case, the first element of the output dv 
%                       will still be considered as a DSM.
    options(4) = 0; % if 0, No plot
    options(5) = 0; % if 0, output structure not generated
elseif nargin == 6
    multirev = [];
end

muSun    = 132712440018;
v0       = [0 0 0];
% multirev = [];

nfbpl  = length(seq(seq < 11)) - 1;

SEQ    = seq';
pltsFB = reshape(planetsFB' , [3 nfbpl])';
astsFB = [ 0.*ones(length(alphasASTS),1) 1000.*ones(length(alphasASTS),1) alphasASTS' ];
indxs1 = find(SEQ(:,1) < 11);
indxs1 = indxs1(2:end);
indxs2 = find(SEQ(:,1) >= 11);
indxs2 = indxs2(1:end-1);

FBS           = zeros( size(pltsFB,1)+size(astsFB,1) , 3 );
FBS(indxs1,:) = pltsFB;
FBS(indxs2,:) = astsFB;
FBS(1,:)      = [];

SEQ(:,2:5)           = 0;
SEQ(1,5)             = tofs(1);
SEQ(2:end-1,2:end-1) = FBS;
SEQ(2:end-1,end)     = tofs(2:end);

T(1) = 0;
T(2) = SEQ(1,end);
for inds = 2:size(SEQ,1)-1
    T = [T SEQ(inds,2:end)];
end

sys.mu             = muSun;
sys.mu_planets     = zeros(1,max(seq));  % Default: Solar System
sys.R_planets      = 10*ones(1,max(seq)); % Default: Solar System
sys.eph_handle     = @EphSS_car_m; % Default: Solar System
sys.eph_kep_handle = @EphSS_kep_m; % Default: Solar System


sys.mu_planets(1:9) = astroConstants(11:19);
sys.R_planets(1:9) = astroConstants(21:29);

[dv, vin, error, xp2, vp2, output] = ...
    mimga(t0, T, seq, multirev, v0, options ,sys);

vInf  = 0;                            % --> km/s
dv(1) = (dv(1)-vInf)*(dv(1)-vInf>=0); % --> km/s

DVTotal = sum(dv); % --> km/s


end