function [Points2Search, fig] = wrap_BranchSeed_EM(t0, tf, tofMin, tofMax, MassThreshold, vinfLim, OptionsMultiRev)

nNodes        = 100;
step          = 5;

ToFVector     = linspace(tofMin, tofMax, nNodes);
tLaunchVector = linspace(t0,  tf,  nNodes);

raMatrix      = NaN*zeros(length(tLaunchVector),length(ToFVector));
raP2Matrix    = NaN*zeros(length(tLaunchVector),length(ToFVector));
dryMassMatrix = NaN*zeros(length(tLaunchVector),length(ToFVector));
for itL = 1:length(tLaunchVector)  
    for iT = 1:length(ToFVector)       
        [raE, raP2, dryMass] = ...
            Transfer_CASTAway_marsSW_rA_A62( tLaunchVector(itL), ToFVector(iT),...
                vinfLim, OptionsMultiRev);
        if raE ~= 0
            raMatrix(itL,iT)      = raE;
            raP2Matrix(itL,iT)    = raP2;
            dryMassMatrix(itL,iT) = dryMass;
        end
    end
end

% --> more constrained search
tlW           = t0:step:tf;
ToFw          = linspace(tofMin, tofMax, nNodes);
indpts        = 1;
Points2Search = zeros(length(tlW)*length(ToFw), 3);
for iT = 1:length(tlW)
    tL = tlW(iT);
    for itof = 1:length(ToFw)
        ToF = ToFw(itof);
        [~, ~, dryMass] = ...
            Transfer_CASTAway_marsSW_rA_A62(tL ,ToF, vinfLim, OptionsMultiRev);
        if (dryMass > MassThreshold)
            Points2Search(indpts,:) = [ tL ToF dryMass ];
            indpts                  = indpts + 1;
        end
    end
end
indxs                  = find(Points2Search(:,1) == 0);
Points2Search(indxs,:) = [];
Points2Search          = [Points2Search [1:size(Points2Search,1)]'];
Points2Search(:,3)     = -Points2Search(:,3);
Points2Search          = sortrows(Points2Search, [1 3]); % --> sort by MAX mass
Points2Search(:,3)     = -Points2Search(:,3);

% --> save only the Dep. Date that delivers the highest mass
c = unique(Points2Search(:,1));
ind_to_save = zeros(size(c,1),1);
for indc = 1:size(c,1)
    indxs = find(Points2Search(:,1) == c(indc));
    ind_to_save(indc,:) = indxs(1);
end
Points2Search = Points2Search(ind_to_save,:);

% --> plot the options
if nargout == 2
    fig = figure;  hold on;
    contourf(tLaunchVector, ToFVector, dryMassMatrix');
    plot(Points2Search(:,1), Points2Search(:,2), '.');
end

end