function INPUT = wrap_Initialization(STRUC, tols, astMax, bw, OptionsMultiRev)

if nargin == 4
    OptionsMultiRev = [0 0];
end

if ~isempty(STRUC.MatrixSummary_BC)

    MatrixSummary_BC = STRUC.MatrixSummary_BC;
    tE               = STRUC.tE;
    tM               = STRUC.tM;
    
    try
        ephNEO('load','ephNEO_CATABC.txt');
    catch
    end

    % --> gravitational parameter of the Sun
    muSun = 132712440018; 

    MatrixSummary_BC(:,1) = MatrixSummary_BC(:,1) + 11;

    ASTEROIDS_LIST = MatrixSummary_BC(:,1);
    MOIDS_EPOCHS   = MatrixSummary_BC(:,4);

    ASTEROIDS = [ASTEROIDS_LIST, MOIDS_EPOCHS];
    ASTEROIDS = [[4, tM]; ASTEROIDS]; % --> include Mars in the asteroids list
    [B,I]     = sort(ASTEROIDS(:,2));
    astLIST   = ASTEROIDS(I,:);
    astLISTe  = [[3 tE]; astLIST]; % --> include Earth in the asteroid list

    % --> generate the ephemerides
    [EPH] = generateEph(astLISTe);

    % --> run the first legs
    as1 = 3;
    t1  = EPH(astLISTe(:,1) == as1, 2);
    rr1 = EPH(astLISTe(:,1) == as1, 3:5);
    vv1 = EPH(astLISTe(:,1) == as1, 6:8);

    dv = zeros(size(astLISTe,1),1);
    for inda = 2:size(astLISTe,1)
        as2 = astLISTe(inda,1);
        t2  = EPH(astLISTe(:,1) == as2, 2);
        rr2 = EPH(astLISTe(:,1) == as2, 3:5);
        
        % --> solve the MRLP and only keep the best DV solution
        [dv(inda,1)] = lambert_MR_opts(vv1, rr1, rr2, (t2 - t1)*86400, muSun, OptionsMultiRev);
        
    end
    ind       = 1:1:size(astLISTe,1);
    LIST      = [ind' astLISTe dv];
    LIST(1,:) = [];
    LIST( LIST(:,end) > tols(1) , :) = [];
    indASTs   = LIST(:,1:2);

    INPUT = writeINPUT_BS(astLISTe, EPH, tols, astMax, bw, indASTs);
    INPUT.OptionsMultiRev = OptionsMultiRev;

else
    INPUT.astLISTe        = [];
    INPUT.EPH             = [];
    INPUT.tols            = [];
    INPUT.astMax          = [];
    INPUT.bw              = [];
    INPUT.indASTs         = [];
    INPUT.OptionsMultiRev = [];
end

end