function [SOLUTION] = wrap_MODP_ATMGA(SEQ, years, dtmax, optimiz, folder_to_scan, INPUT)

addpath(genpath([pwd '\' folder_to_scan]));
folder_to_search = [ '\' folder_to_scan '\INFO\INFO - ' dtmax 'y\info_' dtmax 'y_' SEQ '_' years];
fold_to_save     = [ '\' folder_to_scan '\SOLUTION\' optimiz '\' dtmax 'y\DP_RESULTS_' dtmax 'y_' SEQ '_' years];

d    = dir([[pwd folder_to_search], '\*.mat']);
n    = length(d);

SOLUTION = struct('Sol', [], 'MAT', [], 'seq', [], 'epochs', []); 
for indi = 1:n
    
    % --> load the info
    fld  = d(indi,:).folder;
    name = d(indi,:).name;
    name = [fld '\' name];
    load(name);
    MAT      = info.MAT;
    [~,ia]   = unique(MAT(:,1), 'stable');
    MAT      = MAT(ia,:);
    info.MAT = MAT;
    
    % --> update the INPUT
    INPUT.MAT    = info.MAT;        % --> potentially reachable asteroids
    INPUT.seq    = info.seq;        % --> sequence of planetary flybys
    INPUT.epochs = info.epochs;     % --> epochs of planetary flybys

    % --> solve the problem with MODP
    SOL = wrap_MODP(INPUT, indi, fold_to_save);
    SOL.cost_best_path
    
    % --> save the solution
    SOLUTION(indi).Sol    = SOL;
    SOLUTION(indi).MAT    = info.MAT;
    SOLUTION(indi).seq    = info.seq;
    SOLUTION(indi).epochs = info.epochs;
    
end

% --> post-process
[SOLUTION] = postProcess_SOLUTION(SOLUTION, INPUT);

% --> save the results
fld  = d(1,:).folder;
name = d(1,:).name;
name = [fld '\' name];
load(name);
t0    = mjd20002date(info.epochs(1));
tofys = round(max([SOLUTION.bestTOFy]'));

if ~isempty(SOLUTION)
    seq        = SOLUTION(1).seq;
    nametosave = [ 'SOLUTION_MODP_' sprintf('%d', t0(1)) '_' sprintf('%d', tofys) '_' sprintf('%d', seq) '.mat'];
    save(nametosave, 'SOLUTION', '-v7.3');
else
    seq        = info.seq;
    nametosave = [ 'SOLUTION_MODP_' sprintf('%d', t0(1)) '_' sprintf('%d', tofys) '_' sprintf('%d', seq) '.mat'];
    save(nametosave, 'SOLUTION', '-v7.3');
end

end
