function [LEGSn, VASn] = wrap_MODP_st2(INPUT, n, EPH, LEGS, VAS)

Nasts           = INPUT.astMax;
MAT             = INPUT.MAT;
OptionsMultiRev = INPUT.OptionsMultiRev;
tols            = INPUT.tols;

fprintf('Leg # %d \n', n);

states = findNextStates(n-1, Nasts, MAT, LEGS );

STRUC = struct('LEGSn', cell(1,size(states,1)), 'VASn', cell(1,size(states,1)));
if INPUT.parallel == 1 % --> use parallel

    parfor idc = 1:size(states,1) % --> parallelize here

        as1     = states(idc,1);
        as2     = states(idc,2);

        indxs   = find(LEGS(:,end) == as1);
        legprev = LEGS(indxs,:);
        vasprev = VAS(indxs,:);
        
        dv  = zeros(size(legprev,1),1);
        vvf = zeros(size(legprev,1),3);
        for indlp = 1:size(legprev,1)
            vvin = vasprev(indlp,:);
            [dv(indlp,:), vvf(indlp,:)] = nextLegs_Seqs_v2(as1, vvin, as2, EPH, OptionsMultiRev);        
        end
        legn = [ legprev [dv as2.*ones(size(dv,1),1)]];
        
        % --> PRUNING w.r.t. total DV and partial DV
        indxs          = find(legn(:,end-1) > tols(3));
        legn(indxs,:)  = [];
        vvf(indxs,:)   = [];
        costTOT        = DVseq(legn);
        indxs          = find(costTOT > tols(end));
        legn(indxs,:)  = [];
        vvf(indxs,:)   = [];

        % --> apply MODP (DV/MASS)
        if ~isempty(legn)

            costTOTn = DVseq(legn);
%             J        = legs2Jscore(legn);
%             COSTmat  = [ 1./J costTOTn ];
            
            masstot  = legs2MassTot(legn);
            COSTmat  = [ 1./masstot costTOTn ];
            
            pf       = paretoFront_MODP( COSTmat );
            row      = pf(:,3); % --> MODP
            
            STRUC(idc).LEGSn = legn(row,:);
            STRUC(idc).VASn  = vvf(row,:);
            
        end

    end

else % --> do not use parallel
    
    for idc = 1:size(states,1) % --> parallelize here

        as1     = states(idc,1);
        as2     = states(idc,2);

        indxs   = find(LEGS(:,end) == as1);
        legprev = LEGS(indxs,:);
        vasprev = VAS(indxs,:);
        
        dv  = zeros(size(legprev,1),1);
        vvf = zeros(size(legprev,1),3);
        for indlp = 1:size(legprev,1)
            vvin = vasprev(indlp,:);
            [dv(indlp,:), vvf(indlp,:)] = nextLegs_Seqs_v2(as1, vvin, as2, EPH, OptionsMultiRev);        
        end
        legn = [ legprev [dv as2.*ones(size(dv,1),1)]];

        % --> PRUNING w.r.t. total DV and partial DV
        indxs          = find(legn(:,end-1) > tols(3));
        legn(indxs,:)  = [];
        vvf(indxs,:)   = [];
        costTOT        = DVseq(legn);
        indxs          = find(costTOT > tols(end));
        legn(indxs,:)  = [];
        vvf(indxs,:)   = [];
        
        % --> apply MODP
        if ~isempty(legn)
            costTOTn = DVseq(legn);
            masstot  = legs2MassTot(legn);
            COSTmat  = [ 1./masstot costTOTn ];
            pf       = paretoFront_MODP( COSTmat );
            row      = pf(:,3); % --> MODP
            
            STRUC(idc).LEGSn = legn(row,:);
            STRUC(idc).VASn  = vvf(row,:);
        end
        
        STRUC(idc).LEGSn = legn(row,:);
        STRUC(idc).VASn  = vvf(row,:);

    end

end

LEGSn = cell2mat({STRUC.LEGSn}');
VASn  = cell2mat({STRUC.VASn}');

if ~isempty(LEGSn)
    % --> PRUNING w.r.t. total DV and partial DV
    costTOT        = DVseq(LEGSn);
    indxs          = find(costTOT > tols(end));
    LEGSn(indxs,:) = [];
    VASn(indxs,:)  = [];
    indxs          = find(LEGSn(:,end-1) > tols(3));
    LEGSn(indxs,:) = [];
    VASn(indxs,:)  = [];
end

end
