function wrap_MOID_ATMGA(SEQ, years, dtmax, MOIDth, folder_to_scan)

% --> add 'Functions Toolbox' to the path
warning('off','all');
currentPath = pwd;
rmpath(genpath(currentPath));
addpath(genpath([pwd '\Functions Toolbox']));
addpath(genpath([pwd '\' folder_to_scan]));
ephNEO('load','ephNEO_CATABC.txt');

% --> parameters
param.AU            = 149597870.7;
param.maxDur        = str2double(dtmax) * 365.25;
param.rcMIN         = 1.8*param.AU;
param.rcMAX         = 3.5*param.AU;
param.MOIDThreshold = MOIDth;

% --> asteroids catalogue
nAst          = 101993;
astCata       = [1:nAst] + 11;

% --> define paths to save/load variables
name_to_load   = ['STRUC_' years '_' dtmax '_new_' SEQ '.mat'];
folder_to_save = [ folder_to_scan '\INFO\INFO - ' dtmax 'y\info_' dtmax 'y_' SEQ '_' years ];
load(name_to_load);
STRUC          = strucNew;
clear strucNew;

% --> scan all the available options
for inds = 1:length(STRUC)

    fprintf('Computing %d of %d \n', [inds length(STRUC)]);
    
    % --> find asteroids close to the reference trajectory
    parallel           = 1; % --> if 1, use parallel, else put 0
    [MAT, seq, epochs] = wrap_MOID_seq(STRUC, inds, param, param.MOIDThreshold, astCata, parallel);

    % --> save the results
    [~,ia]       = unique(MAT(:,1), 'stable');
    MAT          = MAT(ia,:);
    info.MAT     = MAT;
    info.seq     = seq;
    info.epochs  = epochs;
    if exist(folder_to_save, 'dir') == 7 % --> then the folder exists on the current path
    else % --> then the folder does not exist on the current path
        mkdir(folder_to_save); % --> create the folder in the current path
    end
    name_to_save = ['info_seq_' sprintf('%d', seq) '_inds_' num2str(inds) '.mat'];
    name2        = [folder_to_save '\' name_to_save];
    save(name2, 'info', '-v7.3');

end

end