function MAT = wrap_MOID_leg_PAU(rr, vv, t0, tf, param, astCata, parallel)

try
    ephNEO('load','ephNEO_CATABC.txt');
catch
end

if nargin == 6
    parallel = 0;
end

AU = 149597870.7;
mu = 132724487690;

kep    = car2kep([rr, vv], mu);
kep(1) = kep(1)/AU;

STRUC = struct( 'MOID_vector', cell(1, length(astCata)), 'E1_vector', cell(1, length(astCata)), 'E2_vector', cell(1, length(astCata)));
if parallel == 0
    for indA = 1:length(astCata)
        STRUC(indA) = wrap_MOID_PAU(astCata, indA, kep, param);        
    end
    MOID_vector = cell2mat({STRUC.MOID_vector}');
    E1_vector   = cell2mat({STRUC.E1_vector}');
    E2_vector   = cell2mat({STRUC.E2_vector}');
else
    parfor indA = 1:length(astCata)
        STRUC(indA) = wrap_MOID_PAU(astCata, indA, kep, param);
    end
    MOID_vector = cell2mat({STRUC.MOID_vector}');
    E1_vector   = cell2mat({STRUC.E1_vector}');
    E2_vector   = cell2mat({STRUC.E2_vector}');
end
AstIndList = find(MOID_vector < param.MOIDThreshold);

tA  = @(ecc,E) 2*atan(sqrt((1+ecc)/(1-ecc))*tan(E/2));
MAT = [];

for iT = 1:length(AstIndList)

    indexAsteroid = AstIndList(iT) + 11;

    Ast1          = ephSS_kep(indexAsteroid,t0);
    Ast1(1)       = Ast1(1)/AU;
    MOID          = MOID_vector(AstIndList(iT));
    E1            = E1_vector(AstIndList(iT));
    E2            = E2_vector(AstIndList(iT));

    SV1 = kep2car([kep(1:5)   tA(kep(2),E1)] ,   mu/AU^3);
    SV2 = kep2car([Ast1(1:5)   tA(Ast1(2),E2)] , mu/AU^3);

    minDist = norm(SV1(1:3)-SV2(1:3));

    error = abs(MOID-minDist)/MOID;
    if error < 10
        % First epoch at which the asteroid is at its MOID point
        Dt_sec  = kepEq_t(tA(Ast1(2),E2), Ast1(1), Ast1(2), mu/AU^3, Ast1(6), 0);
        Dt_days = Dt_sec/3600/24;
        PA      = 2*pi*sqrt(Ast1(1)^3/(mu/AU^3))/3600/24;
        if Dt_days < 0
            Dt_days = Dt_days + PA;
        end
        % Generate Matrix summary
        MAT = [MAT; [AstIndList(iT) tA(Ast1(2),E2) tA(kep(2),E1) t0+Dt_days PA]];
    end

end

if ~isempty(MAT)

    tFB1     = t0;
    indexDEL = find(MAT(:,4) < tFB1);
    if ~isempty(indexDEL)
        MAT(indexDEL,:) = [];
    end
    
    indexDEL = find(MAT(:,4) > tf);
    if ~isempty(indexDEL)
        MAT(indexDEL,:) = [];
    end
    
    nSize                         = size(MAT);
    MatrixSummary_2               = zeros(nSize(1),nSize(2)+1);
    MatrixSummary_2(:,1:nSize(2)) = MAT;
    nIter                         = length(MAT(:,1));
    
    for iItr = 1:nIter
        
        Epoch = t0;
        SCKep = kep;
    
        indexAT   = MAT(iItr,1) + 11;
        AsteroidT = ephNEO(t0, indexAT);

        % Position Asteroid MOID point
        SV_MOID = kep2car([AsteroidT(1)/AU AsteroidT(2:5) MAT(iItr,2)] ,mu/AU^3);
        % Encounter Opportunities
        T1      = MAT(iItr,4);
        PA      = MAT(iItr,5);
        TOpList = [T1:PA:tf];
        % Compute distance for each of these opportunities
        
        inSV = kep2car(SCKep, mu/AU^3);
        dt   = (TOpList - Epoch)*3600*24;
        out  = zeros(length(dt),6);
        for kT = 1:length(dt)
            [out(kT,:)] = kepPro(inSV,dt(kT),mu/AU^3);
        end
        
        distL = sqrt((SV_MOID(1) - out(:,1)).^2 + (SV_MOID(2) - out(:,2)).^2 + (SV_MOID(3) - out(:,3)).^2);
           
        [Min_distL, indMin]              = min(distL);
        MatrixSummary_2(iItr,nSize(2)+1) = Min_distL;
        MatrixSummary_2(iItr,4)          = TOpList(indMin);
    end
    
    % --> clean encounters a too much distance
    MatrixSummary_2(MatrixSummary_2(:,6)>param.MOIDThreshold,:) = [];
    
    [~,inSort]      = sort(MatrixSummary_2(:,4));
    MatrixSummary_3 = [MatrixSummary_2(inSort,:) MatrixSummary_2(inSort,4)-Epoch];
    
    MAT        = MatrixSummary_3(:,1:4);
    MAT(:,1)   = MAT(:,1) + 11;
    MAT(:,2:3) = 0;

end

end
