function [MAT, seq, times] = wrap_MOID_seq_PAU(STRUC, inds, param, astCata)

fprintf('Computing potentially reachable asteroids ... \n');

mu   = 132724487690;

seq  = STRUC(1).seq;
if length(seq) > 1 % --> MGA sequence

    legs   = [[seq(1:end-1)]' [seq(2:end)]'];
    epochs = STRUC(inds).epochs; times = epochs;
    tofs   = diff(epochs);
    epochs = [[epochs(1:end-1)]' [epochs(2:end)]'];
    stated = STRUC(inds).stated;
    flyby  = [STRUC(inds).rpin STRUC(inds).kin];
    tMax   = epochs(1,1) + param.maxDur;
    
    rcMIN = param.rcMIN;
    rcMAX = param.rcMAX;
    
    % --> before the last flyby
    dtAMB = zeros(size(stated,1),1);
    MAT   = [];
    for ind = 1:size(stated,1)
       
        rr  = stated(ind,1:3);
        vv  = stated(ind,4:6);
        t0  = epochs(ind,1);
        tf  = epochs(ind,2);
        tof = tofs(ind)*86400;
        
        dtAMB(ind,1) = time_AMB(rr, vv, rcMIN, rcMAX, tof);
        
        % --> check for potential asteroids to flyby
        if dtAMB(ind,1) ~= 0
            MATt = wrap_MOID_leg_PAU(rr, vv, t0, tf, param, astCata);
            MAT  = [MAT; MATt];
        end
        
    end
    
    % --> perform the last flyby
    rrd          = stated(end,1:3);
    vvd          = stated(end,4:6);
    tof          = tofs(end)*86400;
    plin         = legs(end,end);
    tdep         = epochs(1,1);
    tin          = epochs(end,end);
    rpin         = flyby(1);
    kin          = flyby(2);
    [rrin, vvin] = FGKepler_dt(car2kep([rrd vvd], mu), tof, mu);
    muPLIN       = planetConstants(plin);
    [rrOU, vvOU] = swingby_vA(rrin, vvin, plin, tin, kin, rpin, muPLIN);
    
    dtAMBp        = sum(dtAMB);
    [dtAMBend, T] = time_AMB(rrOU, vvOU, rcMIN, rcMAX);
    
    tofr  = param.maxDur - (tin - tdep);
    dtAMB = (tofr/T)*dtAMBend + dtAMBp;
    
    if dtAMBend == 0
        MATt = [];
    else
        t0   = tin;
        tf   = tin + tofr;
        MATt = wrap_MOID_leg_PAU(rrOU, vvOU, t0, tf, param, astCata);
    end
    MAT  = [MAT; MATt];
    if ~isempty(MAT)
        MAT        = [MAT [1:size(MAT,1)]'];
        MAT        = sortrows(MAT, 4);
        MAT(:,end) = [];
    end

else % --> direct launch from Earth

    times = STRUC(inds).tDEP;
    rr    = STRUC(inds).stated(1:3);
    vv    = STRUC(inds).stated(4:6);
    t0    = STRUC(inds).tDEP;
    tf    = t0 + param.maxDur;
    MAT   = wrap_MOID_leg_PAU(rr, vv, t0, tf, param, astCata);

end

fprintf('Done! \n');

end
