function [MAT, seq, times] = wrap_MOID_seq_PAU_v2(STRUC, inds, param, MOIDThreshold, astCata, parallel)

fprintf('Computing potentially reachable asteroids ... \n');

param.MOIDThreshold = MOIDThreshold;

if nargin == 5
    parallel = 0;
end

mu  = 132724487690;
seq = STRUC(1).seq;

if length(seq) == 1 % --> direct launch from Earth

    % --> compute the MOID on the given leg
    rrd               = STRUC(inds).stated(1:3);
    vvd               = STRUC(inds).stated(4:6);
    t0                = STRUC(inds).tDEP;
    tf                = t0 + param.maxDur;
    MAT               = wrap_MOID_leg_PAU(rrd, vvd, t0, tf, param, astCata, parallel);

else

    legs   = [[seq(1:end-1)]' [seq(2:end)]'];
    epochs = STRUC(inds).epochs; times = epochs;
    tofs   = diff(epochs);
    epochs = [[epochs(1:end-1)]' [epochs(2:end)]'];
    stated = STRUC(inds).stated;
    flyby  = [STRUC(inds).rpin STRUC(inds).kin];
    
    rcMIN = param.rcMIN;
    rcMAX = param.rcMAX;
    
    % --> before the last flyby
    dtAMB   = zeros(size(stated,1),1);
    MAT     = [];
    for ind = 1:size(stated,1)
       
        rr  = stated(ind,1:3);
        vv  = stated(ind,4:6);
        t0  = epochs(ind,1);
        tf  = epochs(ind,2);
        tof = tofs(ind)*86400;
        
        [dtAMB(ind,1)] = time_AMB(rr, vv, rcMIN, rcMAX, tof);
        
        % --> check for potential asteroids to flyby
        if dtAMB(ind,1) ~= 0
            MATt = wrap_MOID_leg_PAU(rr, vv, t0, tf, param, astCata, parallel);
            MAT  = [MAT; MATt];
        end
        
    end

    if ~isnan(flyby(1))

        % --> perform the last flyby
        rrd          = stated(end,1:3);
        vvd          = stated(end,4:6);
        tof          = tofs(end)*86400;
        plin         = legs(end,end);
        tdep         = epochs(1,1);
        tin          = epochs(end,end);
        rpin         = flyby(1);
        kin          = flyby(2);
        [rrin, vvin] = FGKepler_dt(car2kep([rrd vvd], mu), tof, mu);
        muPLIN       = planetConstants(plin);
        [rrOU, vvOU] = swingby_vA(rrin, vvin, plin, tin, kin, rpin, muPLIN);
        
        dtAMBend = time_AMB(rrOU, vvOU, rcMIN, rcMAX);
        
        tofr  = param.maxDur - (tin - tdep);
        
        if dtAMBend == 0
            MATt     = [];
        else
            MATt = wrap_MOID_leg_PAU(rrOU, vvOU, tin, tin + tofr, param, astCata, parallel);
        end
        
        MAT     = [MAT; MATt];
        if ~isempty(MAT)
            MAT        = [MAT [1:size(MAT,1)]'];
            MAT        = sortrows(MAT, 4);
            MAT(:,end) = [];
        end

    end

end

if ~isempty(MAT)
    % --> save the results
    [~,ia]       = unique(MAT(:,1), 'stable');
    MAT          = MAT(ia,:);
    fprintf('Done! \n');
else
    disp( 'The SC does not cross the MAB' );
end

end
