function [figure1] = wrap_Plot_Traj(Seq, Times, optMR, plotAxis)

if nargin == 2
    optMR = zeros( length(Seq)-1 , 2 );
    plotAxis = 0;
elseif nargin == 3
    plotAxis = 0;
end

try
    ephNEO('load','ephNEO_CATABC.txt');%'AMBDatabase.txt');
catch
end

AU       = 149597870.7;
muSun    = 132724487690;

figure1 = figure('Color',[1 1 1]);
hold on; grid on;
xlabel('x - km'); ylabel('y - km'); zlabel('z - km');

% --> plot Sun
drawPlanet('Sun',[0 0 0],figure1,25);

% --> plot planets
indxs = find(Seq < 11);
plts  = Seq( indxs );
tplts = Times(indxs);

for indpl = 1:length(plts)
   
    keppl = uplanet(0, plts(indpl));
    
    if plts(indpl) == 3
        
        plotOrbit(gca,keppl,muSun,'LineWidth',1, 'LineStyle','-');
            
        [sE(1:3), sE(4:6)] = EphSS_car(plts(indpl), tplts(indpl)); % Departure
            drawPlanet('Earth',sE(1:3),figure1,3000);
        
    elseif plts(indpl) == 4
        
        plotOrbit(gca,keppl,muSun,'LineWidth',1,'LineStyle','-');
            
        [sM(1:3), sM(4:6)] = EphSS_car(plts(indpl), tplts(indpl)); % Departure
            drawPlanet('Mars',sM(1:3),figure1,3000);    

    elseif plts(indpl) == 2
        
        plotOrbit(gca,keppl,muSun,'LineWidth',1, 'LineStyle','-');

        [sV(1:3), sV(4:6)] = EphSS_car(plts(indpl), tplts(indpl)); % Departure
            drawPlanet('Venus',sV(1:3),figure1,3000);

    elseif plts(indpl) == 5

        plotOrbit(gca,keppl,muSun,'LineWidth',1, 'LineStyle', '-');

        [sJ(1:3), sJ(4:6)] = EphSS_car(plts(indpl), tplts(indpl)); % Departure
            drawPlanet('Jupiter',sJ(1:3),figure1,500);

    elseif plts(indpl) == 6

        plotOrbit(gca,keppl,muSun,'LineWidth',1, 'LineStyle', '-');

        [sJ(1:3), sJ(4:6)] = EphSS_car(plts(indpl), tplts(indpl)); % Departure
            drawPlanet('Saturn',sJ(1:3),figure1,500);
        
    end
    
end

% Working out Colour Tags for different legs of the trajectory
nLegs     = length(Seq);
colorTags = pink(nLegs);

ninK          = 1;
EarthatEvents = [];
EventPoints   = [];

nFB = length(Seq);
for iFB = 1:nFB-1
   
    [sA(1:3), sA(4:6)]   = EphSS_car(Seq(iFB), Times(iFB));     % Departure
    [sA2(1:3), sA2(4:6)] = EphSS_car(Seq(iFB+1), Times(iFB+1)); % Arrival
    
    [~, ~, ~, ~, vI, ~, ~, ~] = ...
        lambertMR(sA(1:3), sA2(1:3), (Times(iFB+1)-Times(iFB))*86400, muSun, 0, optMR(iFB,1), optMR(iFB,2), 0);

    KepnLEG              = car2kep([sA(1:3) vI], muSun);
    KepSCallLegs(ninK,:) = [KepnLEG Times(iFB) Times(iFB+1)];
    
    ninK = ninK + 1;
    
    r0  = sA(1:3);
    v0  = vI;
    tof = (Times(iFB+1) - Times(iFB))*86400;
    
    ode45options = odeset('abstol',1e-11,'reltol',1e-9);
    [~, y]       = ode45(@dyn_2BP,[0, tof],[r0,v0],ode45options,muSun);
    
    plot3( y(:,1), y(:,2), y(:,3), 'LineWidth',1,'LineStyle','-', 'Color', [0 0 0]);
    EventPoints     = [EventPoints; [y(end,1), y(end,2), y(end,3)]];
    [sEarthatEvent] = EphSS_car(3, Times(iFB+1));
    EarthatEvents   = [EarthatEvents; sEarthatEvent];
    
    if iFB~=(indxs-1)
                [~,y] = ode45(@dyn_2BP,[0 -50*86400;],sA2,ode45options,muSun);
                [~,y] = ode45(@dyn_2BP,[0 100*86400;],y(end,:),ode45options,muSun);
                
                plot3( y(:,1), y(:,2), y(:,3), 'LineWidth',1,'LineStyle','-','Color',[0 0.447058826684952 0.74117648601532])
                %--------------------------------------------------------------------------
                p1=y(end,1:3); v1=y(end,4:6);
                H=gca;
                xr=get(H,'xlim');
                yr=get(H,'ylim');
                zr=get(H,'zlim');
                s=norm([xr(2)-xr(1),yr(2)-yr(1),zr(2)-zr(1)]);
                
                r=s/500; % radius
                h=10*r; % height
                n=20; m=20; % grid spacing
                [x,y,z]=cylinder(linspace(0,r,n),m);
                
                H=surf(x+p1(1),y+p1(2),z*h+p1(3));
                set(H,'FaceColor',[0 0.447058826684952 0.74117648601532],...
                    'EdgeColor',[0 0.447058826684952 0.74117648601532])
%                 P=p1; % position vector
%                 U=P/norm(P); % unit vector
                V=v1/norm(v1); % unit vector
                D=cross(V,[0,0,1]); % rotation axis
                if norm(D)<eps, D=[1,0,0]; end
                A=acos(dot(V,[0 0 1])); % rotation angle
                rotate(H,D,(pi-A)*180/pi,p1)
                %               hobj = plotOrbit(axes1,Kep1Ast,muSun,...
                %          'LineWidth',1,'Color',[0.749019622802734 0 0.749019622802734]);
                %--------------------------------------------------------------------------
    end
    
    
end

hold on
% 3 has been removed so not to plot the DSM
for iP=1:size(EventPoints,1)
              plot(EventPoints(iP,1),EventPoints(iP,2),...
                  'MarkerFaceColor',colorTags(iP,:),'MarkerEdgeColor',[0 0 0],...
                  'Marker','o',...
                  'LineStyle','none');
end
try
              plot(EventPoints(9,1),EventPoints(9,2),'MarkerFaceColor',[0.9045    0.9045    0.7538],...
    'MarkerEdgeColor',[0 0 0],...
    'Marker','o',...
    'LineStyle','none');
              plot(EventPoints(10,1),EventPoints(10,2),'MarkerFaceColor',[0.9374    0.9374    0.8439],...
    'MarkerEdgeColor',[0 0 0],...
    'Marker','o',...
    'LineStyle','none');
catch
end


if plotAxis == 1
% Axis
%--------------------------------------------------------------------------
% X Axis   
   CMPos=[0 0 0];   
   p1=[0.75*AU 0 0];
%    p2=[xEarth-0.3 0 0];
   line([ CMPos(1) p1(1)],[ CMPos(2) p1(2)],[ CMPos(3) p1(3)],'Color',[0 0 0])
%--------------------------------------------------------------------------
% Arrow head
% scale factor
H=gca;
xr=get(H,'xlim');
yr=get(H,'ylim');
zr=get(H,'zlim');
s=norm([xr(2)-xr(1),yr(2)-yr(1),zr(2)-zr(1)]);

r=s/750; % radius
h=6*r; % height
n=20; m=20; % grid spacing
[x,y,z]=cylinder(linspace(0,r,n),m);

H=surf(x+p1(1),y+p1(2),z*h+p1(3));
set(H,'FaceColor','k','EdgeColor','k')
P=p1-CMPos; % position vector
U=P/norm(P); % unit vector
D=cross([0,0,1],-U); % rotation axis
if norm(D)<eps, D=[1,0,0]; end
A=acos(dot([0,0,1],-U)); % rotation angle
rotate(H,D,A*180/pi,p1)
%--------------------------------------------------------------------------
% Y axis
 CMPos=[0 0 0];   
   py=[0 0.75*AU 0];
%    p2=[xEarth-0.3 0 0];
   line([ CMPos(1) py(1)],[ CMPos(2) py(2)],[ CMPos(3) py(3)],'Color',[0 0 0])
% Arrow head Y
% scale factor
% H=gca;
% xr=get(H,'xlim');
% yr=get(H,'ylim');
% zr=get(H,'zlim');
% s=norm([xr(2)-xr(1),yr(2)-yr(1),zr(2)-zr(1)]);

% r=s/750; % radius
% h=6*r; % height
% n=20; m=20; % grid spacing
[x,y,z]=cylinder(linspace(0,r,n),m);

H=surf(x+py(1),y+py(2),z*h+py(3));
set(H,'FaceColor','k','EdgeColor','k')
P=py-CMPos; % position vector
U=P/norm(P); % unit vector
D=cross([0,0,1],-U); % rotation axis
if norm(D)<eps, D=[1,0,0]; end
A=acos(dot([0,0,1],-U)); % rotation angle
rotate(H,D,A*180/pi,py)
%--------------------------------------------------------------------------
% Z axis
 CMPos=[0 0 0];   
   pz=[0 0  0.75*AU];
%    p2=[xEarth-0.3 0 0];
   line([ CMPos(1) pz(1)],[ CMPos(2) pz(2)],[ CMPos(3) pz(3)],'Color',[0 0 0])
% Arrow head Y
% scale factor
% H=gca;
% xr=get(H,'xlim');
% yr=get(H,'ylim');
% zr=get(H,'zlim');
% s=norm([xr(2)-xr(1),yr(2)-yr(1),zr(2)-zr(1)]);

% r=s/750; % radius
% h=6*r; % height
% n=20; m=20; % grid spacing
[x,y,z]=cylinder(linspace(0,r,n),m);

H=surf(x+pz(1),y+pz(2),z*h+pz(3));
set(H,'FaceColor','k','EdgeColor','k')
P=pz-CMPos; % position vector
U=P/norm(P); % unit vector
D=cross([0,0,1],-U); % rotation axis
if norm(D)<eps, D=[1,0,0]; end
A=acos(dot([0,0,1],-U)); % rotation angle
rotate(H,D,A*180/pi,pz)
%--------------------------------------------------------------------------
% view(axes1,[0 90]);
% hold(axes1,'all');
%--------------------------------------------------------------------------
% Some extra analysis on the orbit
% TotalTOF=(Times(end)-Times(1))/365.25; 
end

axis equal;
xlabel('x - km'); ylabel('y - km'); zlabel('z - km');

end