function wrap_Plot_Traj_Opt(seq, output, sol)

try
    ephNEO('load','ephNEO_CATABC.txt');
catch
end

mu = 132712440018; muSun = mu;

leg = output.leg;

nfbpl     = length(seq(seq < 11)) - 1;
alphaasts = sol(length(seq)+nfbpl*3+1:end);
alasts    = norm(alphaasts);

indxs = find(seq < 11);
plts  = seq( indxs );
tofs  = sol(2:length(seq));
times = zeros(1, length(seq));
times(1) = sol(1);
for ind = 1:length(tofs)
   times(ind+1) = times(ind) + tofs(ind); 
end
tplts = times(indxs);

% --> plot planets
figure('Color', [1 1 1]);
plotPLTS(plts, tplts);

% --> plot trajectory
EventPoints = []; count = 0;
for indl = 1:length(leg)

    if indl == 1
        
        rr1 = leg(indl).part.x1;
        vv1 = leg(indl).part.v1;
        
        t1 = leg(indl).part.t1;
        t2 = leg(indl).part.t2;
        
        tof    = t2 - t1;
        tt     = linspace(0, tof).*86400;
        [~,yy] = propagateKepler(rr1, vv1, tt, mu);
        
        hold on;
        plot3(yy(:,1), yy(:,2), yy(:,3), 'b', 'linewidth', 1, 'handlevisibility', 'off');
        
    else
        
        rr1 = leg(indl).part(1).x1;
        vv1 = leg(indl).part(1).v1;
        t1  = leg(indl).part(1).t1;
        t2  = leg(indl).part(1).t2;

        tof = t2 - t1;
        tt  = linspace(0, tof).*86400;
        [~,yy] = propagateKepler(rr1, vv1, tt, mu);

        hold on;
        
        if leg(indl).part(1).body1 >= 11
        
            if alasts ~= 0
                if indl == 2
                    plot3(yy(end,1), yy(end,2), yy(end,3), 'kx', 'markersize', 8, 'linewidth', 2, 'DisplayName', 'DSM');
                else
                    plot3(yy(end,1), yy(end,2), yy(end,3), 'kx', 'markersize', 8, 'linewidth', 2, 'handlevisibility', 'off');
                end
                plot3(yy(:,1), yy(:,2), yy(:,3), 'b', 'linewidth',1, 'handlevisibility', 'off');
                
                rr1 = leg(indl).part(2).x1;
                vv1 = leg(indl).part(2).v1;
                t1  = leg(indl).part(2).t1;
                t2  = leg(indl).part(2).t2;

                tof = t2 - t1;
                tt  = linspace(0, tof).*86400;
                [tt,yy] = propagateKepler(rr1, vv1, tt, mu);

                plot3(yy(:,1), yy(:,2), yy(:,3), 'b', 'linewidth', 1, 'handlevisibility', 'off');
            else
                plot3(yy(:,1), yy(:,2), yy(:,3), 'b', 'linewidth',1, 'handlevisibility', 'off');
            end
        
        else
            
            if count == 0
                plot3(yy(end,1), yy(end,2), yy(end,3), 'kx', 'markersize', 8, 'linewidth', 2, 'DisplayName', 'DSM');
                count = 1;
            else
                plot3(yy(end,1), yy(end,2), yy(end,3), 'kx', 'markersize', 8, 'linewidth', 2, 'handlevisibility', 'off');
            end
            plot3(yy(:,1), yy(:,2), yy(:,3), 'b', 'linewidth',1, 'handlevisibility', 'off');

            rr1 = leg(indl).part(2).x1;
            vv1 = leg(indl).part(2).v1;
            t1  = leg(indl).part(2).t1;
            t2  = leg(indl).part(2).t2;

            tof = t2 - t1;
            tt  = linspace(0, tof).*86400;
            [tt,yy] = propagateKepler(rr1, vv1, tt, mu);

            plot3(yy(:,1), yy(:,2), yy(:,3), 'b', 'linewidth', 1, 'handlevisibility', 'off');
            
        end
        
    end
    
    EventPoints = [ EventPoints; [yy(end,1), yy(end,2), yy(end,3)] ];
    
end
if alasts == 0
else
    legend('Location', 'Best');
end
% --> plot asts. traj
ode45options = odeset('abstol',1e-11,'reltol',1e-9);
for ind = 1:length(seq)
    
    as = seq(ind);
    ta = times(ind);
    
    if as >= 11
       
        [sA2(1:3), sA2(4:6)] = EphSS_car(as, ta);
        [~,y] = ode45(@dyn_2BP,[0 -50*86400;],sA2,ode45options,muSun);
        [~,y] = ode45(@dyn_2BP,[0 100*86400;],y(end,:),ode45options,muSun);
        
        plot3(gca, y(:,1), y(:,2), y(:,3), 'LineWidth',1,'LineStyle','-','Color',[0 0.447058826684952 0.74117648601532], 'handlevisibility', 'off')
        
            %--------------------------------------------------------------------------
            p1=y(end,1:3); v1=y(end,4:6);
            H=gca;
            xr=get(H,'xlim');
            yr=get(H,'ylim');
            zr=get(H,'zlim');
            s=norm([xr(2)-xr(1),yr(2)-yr(1),zr(2)-zr(1)]);

            r=s/500; % radius
            h=10*r; % height
            n=20; m=20; % grid spacing
            [x,y,z]=cylinder(linspace(0,r,n),m);

            H=surf(x+p1(1),y+p1(2),z*h+p1(3));
            set(H,'FaceColor',[0 0.447058826684952 0.74117648601532],...
                'EdgeColor',[0 0.447058826684952 0.74117648601532], 'handlevisibility', 'off')
            V=v1/norm(v1); % unit vector
            D=cross(V,[0,0,1]); % rotation axis
            if norm(D)<eps, D=[1,0,0]; end
            A=acos(dot(V,[0 0 1])); % rotation angle
            rotate(H,D,(pi-A)*180/pi,p1)
            %--------------------------------------------------------------------------

        
    end
    
    
end

% --> plot event points
hold on
% 3 has been removed so not to plot the DSM
nLegs=length(seq);
colorTags=pink(nLegs);

for iP=1:size(EventPoints,1)
              plot(EventPoints(iP,1),EventPoints(iP,2),...
                  'MarkerFaceColor',colorTags(iP,:),'MarkerEdgeColor',[0 0 0],...
                  'Marker','o',...
                  'LineStyle','none', 'handlevisibility', 'off');
end
              plot(EventPoints(9,1),EventPoints(9,2),'MarkerFaceColor',[0.9045    0.9045    0.7538],...
    'MarkerEdgeColor',[0 0 0],...
    'Marker','o',...
    'LineStyle','none', 'handlevisibility', 'off');
              plot(EventPoints(10,1),EventPoints(10,2),'MarkerFaceColor',[0.9374    0.9374    0.8439],...
    'MarkerEdgeColor',[0 0 0],...
    'Marker','o',...
    'LineStyle','none', 'handlevisibility', 'off');

xlabel('x - km'); ylabel('y - km');

legend('Location', 'Best');

end