function [SOLUTION_ref] = wrap_REFINEMENT_ATMGA(SOLUTION, maxit, manAsts, vInf, fold_to_save)

SOLUTION_ref = struct('minPATH', [], 'fval_p1', [], 'fval_p2', [], 'sol_p2', []);
for inds = 1:length(SOLUTION)
    
    minPATH = SOLUTION(inds).Sol.path_best_DV;
    if SOLUTION(inds).Nasts == 0
        
    else
        if minPATH(end,1) < 11
            minPATH(end,:) = [];
        end

        seq      = minPATH(:,1)';
        t0       = minPATH(1,2);
        epochs   = minPATH(:,2)';
        tofs     = diff(epochs);
        fval_p1  = sum(minPATH(:,end));
        multirev = findMultiRevOpts_firstLeg(minPATH);

        % --> define lower/upper bounds
        [LB, UB, nfbpl, nres] = generateLBUB(seq, t0, tofs, manAsts);

        % --> define the cost function
        y = @(x) transfer_AMB_GA(seq, x(1), x(2:length(seq)),...
           x(length(seq)+1:(length(seq))+nfbpl*3), x(length(seq)+nfbpl*3+1:end),...
           vInf, multirev);

        fprintf( ' Solution being optimized : %d of %d \n', [inds length(SOLUTION)] );
        fprintf( ' P1 cost : %f \n', fval_p1 );

        fval_p2 = 1e99;
        it      = 0;

        sol_p2  = zeros(maxit, length(LB));
        FVAL_P2 = zeros(maxit, 1);
        while fval_p1 < fval_p2 && it <= maxit

            % --> optimization with GA
            optionsga = optGA();
            [sol_p2(it+1,:), fval_p2] = ga(@(x) y(x), nres, [], [], [], [], LB, UB, [], [], optionsga);
            close all; 

            FVAL_P2(it+1,1) = fval_p2;

            it = it + 1;

        end
        indxs = find(sol_p2(:,1) == 0);
        FVAL_P2(indxs,:) = [];
        sol_p2(indxs,:)  = [];

        [minFval_p2, row] = min(FVAL_P2);
        minSol_p2         = sol_p2(row,:);

        fprintf( ' P2 cost : %f \n', minFval_p2 );

        SOLUTION_ref(inds).minPATH = minPATH;
        SOLUTION_ref(inds).fval_p1 = fval_p1;
        SOLUTION_ref(inds).fval_p2 = minFval_p2;
        SOLUTION_ref(inds).sol_p2  = minSol_p2;

        SOLref.minPATH = minPATH;
        SOLref.fval_p1 = fval_p1;
        SOLref.fval_p2 = minFval_p2;
        SOLref.sol_p2  = minSol_p2;
        saveSOL_ref(fold_to_save, inds, seq, SOLref);
        
    end

    
end

% --> post-process
[SOLUTION_ref] = postProcess_REF(SOLUTION_ref, vInf);

path = SOLUTION_ref(1).minPATH;
seq  = path(:,1)';
seq  = seq(seq<11);
tof  = round((SOLUTION_ref(1).minPATH(end,2) - SOLUTION_ref(1).minPATH(1,2))/365.25);
t0   = mjd20002date(SOLUTION_ref(1).minPATH(1,2));

nametosave = ['SOLUTION_REF_' num2str(t0(1)) '_' num2str(tof) '_' sprintf('%d', seq)  ];
save(nametosave, 'SOLUTION_ref', '-v7.3');

end
