function [OUTPUT] = wrap_SM(INPUT)

mu     = 132712440018;

% --> extract the input
OptsMR = INPUT.OptionsMultiRev;
MAT    = INPUT.MAT;
seq    = INPUT.seq;
epochs = INPUT.epochs;

EPH    = generateEPH_BS(seq, epochs, MAT);

MATpls = EPH(:,1:2);

ids     = 1:size(MATpls,1);
couples = nchoosek(ids,2);

COUPLES = zeros(size(couples,1), 4);
for indc = 1:size(couples,1)
    COUPLES(indc,:) = [ EPH(couples(indc,1),1) EPH(couples(indc,1),2) ...
                        EPH(couples(indc,2),1) EPH(couples(indc,2),2)  ];
end

SM_DV           = 1e99.*ones( size(COUPLES,1), size(MATpls,1) );
SM_VINFA_trip   = 1e99.*ones( size(COUPLES,1), size(MATpls,1) );
SM_VINFA_coup   = 1e99.*ones( size(COUPLES,1), size(MATpls,1) );
SM_ALPHA_trip   = 1e99.*ones( size(COUPLES,1), size(MATpls,1) );
SM_ALPHA_coup   = 1e99.*ones( size(COUPLES,1), size(MATpls,1) );
SM_MASS_trip    = NaN.*ones( size(COUPLES,1), size(MATpls,1) );
SM_MASS_coup    = NaN.*ones( size(COUPLES,1), size(MATpls,1) );

ind_to_del_vDep = NaN.*zeros( size(COUPLES,1), 1 );

% --> generate the SM
nlp = 0;
nd  = 0;

for indc = 1:size(COUPLES,1)

    indc/size(COUPLES,1)*100

    as1  = COUPLES(indc,1);
    t1   = COUPLES(indc,2);
    as2  = COUPLES(indc,3);
    t2   = COUPLES(indc,4);
    tof1 = (t2 - t1) * 86400 ;

    rr1 = EPH( EPH(:,1) == as1 & EPH(:,2) == t1 , 3:5 );
    vv1 = EPH( EPH(:,1) == as1 & EPH(:,2) == t1 , 6:8 );
    rr2 = EPH( EPH(:,1) == as2 & EPH(:,2) == t2 , 3:5 );
    vv2 = EPH( EPH(:,1) == as2 & EPH(:,2) == t2 , 6:8 );

    % --> solve the LP --> solve as many times as of the MR options
    [ vvd12, vva12 ] = lambert_MRopts(rr1, rr2, tof1, mu, OptsMR);
    nlp = nlp + 1;

    if as1 == 3 && t1 == INPUT.epochs(1)
        dvc = vecnorm( [vvd12 - vv1]' )';
        if min(dvc) > INPUT.tols(1)
            ind_to_del_vDep(indc,:) = indc;
        end
    else
        dvc = zeros( size(vvd12,1), 1 );
    end

    for indm = 1:size(MATpls,1)

        as3  = MATpls(indm,1);
        t3   = MATpls(indm,2);
        rr3  = EPH( EPH(:,1) == as3 & EPH(:,2) == t3 , 3:5 );
        vv3  = EPH( EPH(:,1) == as3 & EPH(:,2) == t3 , 6:8 );
        tof2 = (t3 - t2) * 86400;
        
        if length(unique([as1 as2 as3])) == 3 && length(unique([t1 t2 t3])) == 3 && t3 > t2 && t3 > t1

            [ vvd23, vva23 ] = lambert_MRopts(rr2, rr3, tof2, mu, OptsMR);
            nlp = nlp + 1;

            DVT = zeros( size(vvd12,1), size(vvd23,1) );
            for inddv1 = 1:size(vvd12,1)
                vva_as2 = vva12(inddv1,:);
                for inddv2 = 1:size(vvd23,1)
                    vvd_as2 = vvd23(inddv2,:);
                    if as2 < 11 % --> defect
                        dv = find_DV_defect(vva_as2 - vv2, vvd_as2 - vv2, as2);
                    else
                        dv = norm( vvd_as2 - vva_as2 );
                    end
                    DVT(inddv1,inddv2) = dvc(inddv1) + dv;
                end
            end
            [row, col] = find(DVT == min(min(DVT)));
            nd = nd + 1;

            DVT    = DVT(row, col);
            vinfAc = norm( vva12(row,:) - vv2 );
            vinfAt = norm( vva23(col,:) - vv3 ); % --> arrival infinity velocity at the third asteroid

            alphaC = solarPhaseAngle(rr2, vva12(row,:) - vv2); % --> solar phase angle (COUPLE)
            alphaT = solarPhaseAngle(rr3, vva23(col,:) - vv3); % --> solar phase angle (TRIPLET)

            massC  = wrapMass(as2);
            massT  = wrapMass(as3);

        else

            DVT    = 1e99;
            vinfAc = 1e99;
            vinfAt = 1e99;
            alphaC = 1e99;
            alphaT = 1e99;
            massC  = NaN;
            massT  = NaN;

        end

        SM_DV(indc,indm)         = DVT;
        SM_VINFA_trip(indc,indm) = vinfAt;
        SM_VINFA_coup(indc,indm) = vinfAc;
        SM_ALPHA_trip(indc,indm) = alphaC;
        SM_ALPHA_coup(indc,indm) = alphaT;

        SM_MASS_trip(indc,indm) = massC;
        SM_MASS_coup(indc,indm) = massT;
        
    end
end

% --> save the OUTPUT
OUTPUT.SM_DV           = SM_DV;

OUTPUT.SM_VINFA_trip   = SM_VINFA_trip;
OUTPUT.SM_VINFA_coup   = SM_VINFA_coup;

OUTPUT.SM_ALPHA_trip   = SM_ALPHA_trip;
OUTPUT.SM_ALPHA_coup   = SM_ALPHA_coup;

OUTPUT.SM_MASS_trip   = SM_MASS_trip;
OUTPUT.SM_MASS_coup   = SM_MASS_coup;

OUTPUT.COUPLES         = COUPLES;
OUTPUT.MATpls          = MATpls;
OUTPUT.ind_to_del_vDep = ind_to_del_vDep;

OUTPUT.NLP = nlp;
OUTPUT.ND  = nd;

end
