function [SOLUTION] = wrap_refinement_ASTRA_ATMGA(INPUT, saveOptions)

% --> load the solution and generate the saving folder
folder_to_scan  = saveOptions{1};
SEQ             = saveOptions{2};
years           = saveOptions{3};
dtmax           = saveOptions{4};
optimiz         = saveOptions{5};
name            = [ pwd folder_to_scan '\SOLUTION\' optimiz '\' dtmax 'y\SOLUTION_DP_' years '_' dtmax '_' seqName2seq(SEQ) '.mat' ];
load(name);
fold_to_save = [ folder_to_scan '\SOLUTION\SOLUTION_REF_ASTRA_' optimiz '\' dtmax 'y\REF_ASTRA_RESULTS_' dtmax 'y_' seqName2seq(SEQ) '_' years  ];
if exist(fold_to_save(2:end), 'dir') == 7
else
    mkdir(fold_to_save(2:end));
end

% --> extract the info from INPUT
t0days  = INPUT.t0days;
tofdays = INPUT.tofdays;
dt      = INPUT.dt;
vdep    = INPUT.vdep;

for inds = 1:length(SOLUTION)

    fprintf( ' Solution being optimized : %d of %d \n', [inds length(SOLUTION)] );

    warning('off','all');
    currentPath = pwd;
    rmpath(genpath(currentPath));
    addpath(genpath([pwd '\Functions Toolbox']));

    if SOLUTION(inds).Nasts== 0 || SOLUTION(inds).Nasts < INPUT.astMax
        path_p2   = NaN;
        bestDV_p2 = NaN;
    else
    
        sol  = SOLUTION(inds).Sol;
        LEGS = sol.LEGS;
        EPH  = sol.EPH;
        
        [minCost, row]      = min( [sol.costTOT_legs]' );
        
        LEGrow              = LEGS(row,:);
        [path_p1, ~, optMR] = constructPath_BS(LEGrow, EPH, INPUT.OptionsMultiRev);

        if path_p1(end,1) >= 11

            if max(path_p1(3:end,end)) > INPUT.tols(3)
                path_p2   = NaN;
                bestDV_p2 = NaN;
            else

                seq      = path_p1(:,1)';
                t0       = path_p1(1,2);
                tofs     = diff(path_p1(:,2));
                REVS     = revs2RevsOptions(optMR);
                dsmOpts  = [ INPUT.tols(3) 6 ];
                vInfOpts = [ 3 INPUT.tols(1)+0.5 ];
                
                dv_p1 = sum(path_p1(:,6));
                
                t0min   = t0 - t0days;
                t0max   = t0 + t0days;
                tofmin  = [(tofs - tofdays).*((tofs - tofdays)>=0)];
                tofmax  = [tofs + tofdays];
                TOFlims = [tofmin tofmax];
                    
                % --> add ASTRA Toolbox to the current path
                warning('off','all');
                currentPath = pwd;
                rmpath(genpath(currentPath));
                addpath(genpath([pwd '\ASTRA - opt']));
                addpath(genpath([pwd '\Functions Toolbox\CASTPath ToolBox\Toolbox_Giacomo\ephemerides']));
                
                % --> write the INPUT for ASTRA
                inputASTRA.vInfOpts     = vInfOpts;
                inputASTRA.dsmOpts      = dsmOpts;    % --> max defect DSM, and total DV (km/s)
                inputASTRA.bw           = Inf;        % --> beam width (single leg)
                inputASTRA.plot         = [0 0];      % --> plot(1) for pareto front, plot(2) for best traj.
                inputASTRA.parallel     = true;       % --> use parallel
                inputASTRA.tstep        = dt;
                inputASTRA.TOF_LIM      = TOFlims;    % --> TOF limits per leg (days)
                inputASTRA.chosenRevs   = REVS;
                inputASTRA.res          = [];
                inputASTRA.depOpts      = [t0min t0max dt];
                
                % --> specify the functions to be optimized
                inputASTRA.costFunc1    = @(legn, vvf, vinff) costFunction1_DP_vdep(legn, vvf, vinff, vdep, 0);
                inputASTRA.costFunc2    = @(legn, vvf, vinff) costFunction2_DP_onlyDef(legn, vvf, vinff, vdep, 0, 0, 0);
                
                try parpool('local'); catch; end
                try ephNEO('load', 'ephNEO_CATABC.txt'); catch; end
                
                OUTPUT = ASTRA_SODP_v2(inputASTRA, seq);
                
                dv_p2   = OUTPUT.minCOST;
                path_p2 = OUTPUT.minPATH;
            
                path_p2    = [ path_p2(:,7:8) path_p1(:,3:5) [0; path_p2(1,9); path_p2(3:end,10) ]; ];
                bestDV_p2 = dv_p2;
                
                fprintf( ' P1 cost : %f \n', dv_p1 );
                fprintf( ' P2 cost : %f \n', dv_p2 );

            end

        else
            path_p2   = NaN;
            bestDV_p2 = NaN;
        end

    end

    % --> save the solution
    name2save = [ pwd fold_to_save '\SOL_REF_ASTRA_iSP_' num2str(inds) '.mat' ];
    
    SOLUTION(inds).path_p2   = path_p2;
    SOLUTION(inds).bestDV_p2 = bestDV_p2;

    SOLref = SOLUTION(inds);

    save(name2save, 'SOLref', '-v7.3');

end

% --> now save the optimized SOLUTION
nametosave = [ pwd folder_to_scan '\SOLUTION\SOLUTION_REF_ASTRA_' optimiz '\' dtmax 'y\SOLUTION_REF_ASTRA_' years '_' dtmax '_' SEQ ];
save(nametosave, 'SOLUTION', '-v7.3');

warning('off','all');
currentPath = pwd;
rmpath(genpath(currentPath));
addpath(genpath([pwd '\Functions Toolbox']));

end