
% --> add DYNAMIS to the path
add_DYNAMIS;

% --> set-up the INPUT
parallel            = 1;            % --> (1) use parallel, (0) do not use parallel
param.AU            = 149597870.7;  % --> Astronomical Unit (km)
param.rcMIN         = 1.8*param.AU; % --> lower bound for MAB estension (km)
param.rcMAX         = 3.5*param.AU; % --> upper bound for MAB estension (km)
param.maxDur        = 7 * 365.25;   % --> max. duration for the mission (yeaars)
MOIDth   = 0.05;                    % --> MOID threshold (AU)
nAst     = 101993;                  % --> number of asteroids in the catalogue
astCata  = [1:nAst] + 11;           % --> ID for asteroids in the catalogue

%% --> STEP 0: LOAD THE PATH

load('path_EVEEJ.mat');                     % --> take the path from ASTRA
rpinKin = [ NaN NaN ];                      % --> use [NaN NaN] if the tour ends at last planet
STRUC   = path2StrucDYNAMIS(path, rpinKin); % --> convert it for DYNAMIS

%% -- STEP 1: MOID

% --> compute MOID
info = wrap_MOID_seq_DYNAMIS(STRUC, 1, param, MOIDth, astCata, parallel);

%% --> STEP 2: DYNAMIC PROGRAMMING

% --> define the INPUT for DYNAMIC PROGRAMMING
INPUT.tols            = [5 Inf 0.1 9];   % --> tolerances on the DV
INPUT.astMax          = 50;              % --> max. number of asteroids in the sequence
INPUT.bw              = Inf;             % --> Beam Width (only used to initialize the search)
INPUT.OptionsMultiRev = [0 0; 1 0; 1 1]; % --> revolutions options per leg
INPUT.parallel        = 1;               % --> use parallel computing
INPUT.astMaxOpt       = 1;               % --> you want to keep all the solutions
INPUT.MAT             = info.MAT;        % --> potentially reachable asteroids
INPUT.seq             = info.seq;        % --> sequence of planetary flybys
INPUT.epochs          = info.epochs;     % --> epochs of planetary flybys
INPUT.soltokeep       = 1;               % --> modified dynamic programming

% --> save folder and ID
fold_to_save = '\test_jupiter';
indi         = 4;

% --> solve using dynamic programming
SOL = wrap_DynProgramming(INPUT, indi, fold_to_save);

%% --> STEP 3: REFINE USING ASTRA

% --> optimize the best path using ASTRA
optimizeDYNAMISpathUsingASTRA;

%% --> STEP 4: POST-PROCESSING AND PLOT

% --> plot the trajectory with asteroids
wrap_Plot_Traj(path_p2(:,1), path_p2(:,2), optMR);
