
disp( 'Refining using ASTRA...' );

% --> add DYNAMIS to the path
add_DYNAMIS;

t0days  = 15;
tofdays = 15;
dt      = 0.5;

LEGS = SOL.LEGS;
EPH  = SOL.EPH;

[minCost, row]      = min( [SOL.costTOT_legs]' );
LEGrow              = LEGS(row,:);
[path_p1, ~, optMR] = constructPath_BS(LEGrow, EPH, INPUT.OptionsMultiRev);

seq      = path_p1(:,1)';
t0       = path_p1(1,2);
tofs     = diff(path_p1(:,2));
REVS     = revs2RevsOptions(optMR);
dsmOpts  = [ INPUT.tols(3)+0.1 6 ];
vInfOpts = [ 3 INPUT.tols(1)+0.5 ];

t0min   = t0 - t0days;
t0max   = t0 + t0days;
tofmin  = [(tofs - tofdays).*((tofs - tofdays)>=0)];
tofmax  = [tofs + tofdays];
TOFlims = [tofmin tofmax];

% --> add ASTRA Toolbox to the current path
warning('off','all');
currentPath = pwd;
rmpath(genpath(currentPath));
addpath(genpath([pwd '\ASTRA - opt']));
addpath(genpath([pwd '\Functions Toolbox\CASTPath ToolBox\Toolbox_Giacomo\ephemerides']));

% --> write the INPUT for ASTRA
inputASTRA.vInfOpts     = vInfOpts;
inputASTRA.dsmOpts      = dsmOpts;    % --> max defect DSM, and total DV (km/s)
inputASTRA.bw           = Inf;        % --> beam width (single leg)
inputASTRA.plot         = [0 0];      % --> plot(1) for pareto front, plot(2) for best traj.
inputASTRA.parallel     = true;       % --> use parallel
inputASTRA.tstep        = dt;
inputASTRA.TOF_LIM      = TOFlims;    % --> TOF limits per leg (days)
inputASTRA.chosenRevs   = REVS;
inputASTRA.res          = [];
inputASTRA.depOpts      = [t0min t0max dt];
try parpool('local'); catch; end
try ephNEO('load', 'ephNEO_CATABC.txt'); catch; end

% --> optimize using ASTRA
OUTPUT  = ASTRA_SODP_v2(inputASTRA, seq);

path_p2 = OUTPUT.minPATH;
path_p2 = [ path_p2(:,7:8) path_p1(:,3:5) [0; path_p2(1,9); path_p2(3:end,10) ]; ];

% --> add DYNAMIS to the path
warning('off','all');
currentPath = pwd;
rmpath(genpath(currentPath));
addpath(genpath([pwd '\Functions Toolbox']));
